<?xml version="1.0"?>
	<!-- xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="java" -->

<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:java="http://xml.apache.org/xalan/java" 
	xmlns:rap="http://www.nlets.org/rapsheet/3.0" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cch/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2" 
>
	
	<xsl:import href="raputility.xsl"/>
	<xsl:import href="../common.xsl"/>
	<xsl:output method="html" />
	<xsl:param name="from"/>
	<xsl:param name="responseId">
		<xsl:value-of select="doj:CCHResponseDocument/@doj-ext:responseID"/>
	</xsl:param>
	
	<!-- START HERE - root match-->
	<!-- <xsl:template match="/">
		<html>
			<head>
				<title>Rapsheet</title>
				<link href="../../css/rapsheet.css" rel="stylesheet" type="text/css"/>
			</head>
			<body><xsl:apply-templates select="doj:CCHResponseDocument" /></body>
		</html>
	</xsl:template> -->
	
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$from='ebc'">
				<xsl:call-template name="html_main"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="html_head_extension"/>
				<xsl:call-template name="html_body"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="html_title">Rapsheet</xsl:template>
	
	<xsl:template name="html_head_extension">
		<!-- link href="../../css/rapsheet.css" rel="stylesheet" type="text/css"/ -->
	</xsl:template>
	
	<xsl:template name="html_body">
		<xsl:apply-templates select="doj:CCHResponseDocument" />
	</xsl:template>

 	<!-- Main controlling template -->
	<xsl:template match="doj:CCHResponseDocument">
		<div><xsl:call-template name="subheader"/></div>
		<div><xsl:call-template name="title"/></div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/j:Subject | doj:Result/doj:NonAutomated/rap:RapSheet/j:Subject" mode="header_flag_section"/>
		</div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:Introduction | doj:Result/doj:NonAutomated/rap:RapSheet/rap:Introduction"/>
		</div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/j:Subject | doj:Result/doj:NonAutomated/rap:RapSheet/j:Subject" mode="caution_other"/>
		</div>
		<div><xsl:call-template name="header_buttons"/></div>
		<div><hr/></div>
		<a name="identification{$responseId}"></a>
		<div class="identification"><xsl:text>Identification</xsl:text></div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/j:Subject | doj:Result/doj:NonAutomated/rap:RapSheet/j:Subject" mode="caution_death"/>
		</div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/j:Subject | doj:Result/doj:NonAutomated/rap:RapSheet/j:Subject" mode="subject_details"/>
		</div>
		<div><hr/></div>
		<xsl:if test="doj:Result/doj:Automated/rap:RapSheet/rap:Cycle">
			<a name="history{$responseId}"></a>
			<span class="criminal_history">Criminal History</span><p/>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:Cycle"/>
			<div><hr/></div>
		</xsl:if>
		<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/j:Organization"/>
	</xsl:template>
	
	<!-- images under navigation bar -->
	<xsl:template name="subheader">
		<div align="right">
			<img src="../../images/cib3_small.png" alt="ciblogo" width="50" height="50"/>
			<img src="../../images/spacer.gif" alt="" width="100" height="1"/>
		</div>
	</xsl:template>
	
	<!-- Page title and current date -->
	<xsl:template name="title">
		<p/>
		<table width="100%">
		<tr>
			<td class="wisconsin_criminal_history width75percent">Wisconsin Criminal History</td>
			<td class="reported_date">
				<xsl:text>Date:&#32;</xsl:text>
				<xsl:call-template name="currentDate"/>
			</td>
		</tr>
		</table>
		<p/>
	</xsl:template>
	
	<!-- flags -->
	<xsl:template match="j:Subject" mode="header_flag_section">
		<table class="flag">
		<xsl:if test="j:PersonFirearmSalesDisqualifiedIndicator = 'true'">
		<tr>
			<td>
				<xsl:text>&#160;&#160;</xsl:text>
				<img class="flag_img" src="../../images/firearmDisqualifier.jpg" alt="gun" height="32" width="40"/>
				<xsl:text>Firearm&#32;Sale&#32;Disqualified&#32;</xsl:text>
				<xsl:apply-templates select="j:PersonFirearmSalesDisqualifiedIndicator[.='true']" mode="all_attributes"/>
			</td>
		</tr>
		</xsl:if>
		
		<xsl:if test="j:SubjectCautionInformationCaveat = 'Convicted Felon'">
		<tr>
			<td>
				<xsl:text>&#160;&#160;</xsl:text>
				<img class="flag_img" src="../../images/convictedfelon.gif" alt="felon" height="32" width="40"/>
				<xsl:text>Convicted Felon</xsl:text>
				<xsl:apply-templates select="j:SubjectCautionInformationCaveat[.='Convicted Felon']" mode="all_attributes"/>
			</td>
		</tr>
		</xsl:if>
		
		<xsl:if test="j:PersonRegisteredOffenderIndicator = 'true'">
		<tr>
			<td>
				<xsl:text>&#160;&#160;</xsl:text>
				<img class="flag_img" src="../../images/sexOffender.gif" alt="sex_offender" height="32" width="40"/>
				<xsl:text>Registered&#32;Sex&#32;Offender&#32;</xsl:text>
				<xsl:apply-templates select="j:PersonRegisteredOffenderIndicator[.='true']"  mode="all_attributes"/>
			</td>
		</tr>
		</xsl:if>
		
		<xsl:if test="j:PersonBiometricDetails/j:PersonDNA">
		<tr>
			<td>
				<xsl:text>&#160;&#160;</xsl:text>
				<img class="flag_img" src="../../images/dna2.gif" alt="dna" height="32" width="40"/>
				<xsl:choose>
					<xsl:when test="j:PersonBiometricDetails/j:PersonDNA/j:BiometricCaptureOrganization or 
					                j:PersonBiometricDetails/j:PersonDNA/j:BiometricEncodingMethodText">
						<xsl:text>DNA&#32;Available&#32;</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="j:PersonBiometricDetails/j:PersonDNA/j:BiometricDescriptionText"/>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
		</xsl:if>
		</table>
	</xsl:template>
	
	<!-- Introduction -->
	<xsl:template match="rap:Introduction">
		<p/>
		<table border="0">
		<tr>
			<td class="purpose_code width25percent">
				<xsl:text>Purpose Code:</xsl:text>
			</td>
			<td class="purpose_code width75percent">
				<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
				<xsl:value-of select="rap:RapSheetRequest/rap:PurposeCode"/>
			</td>
		</tr>
		<tr>
			<td class="purpose_code width25percent">
				<xsl:text>Attention:</xsl:text>
			</td>
 			<td class="purpose_code width75percent mixedcase">
				<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
				<xsl:value-of select="rap:RapSheetRequest/rap:Attention"/>
			</td>
			<!-- <td class="purpose_code width75percent">
				<xsl:value-of select="rap:RapSheetRequest"/>
			</td> -->
		</tr>
		</table>
		<p/>
		<xsl:apply-templates select="rap:Caveat"/>
	</xsl:template>
	
	<!-- Caveat -->
	<xsl:template match="rap:Caveat">
		<table border="0">
		<tr>
			<td class="caveat"><xsl:value-of select="j:CaveatText"/></td>
		</tr>
		</table>
		<p/>
	</xsl:template>
	
 	<xsl:template match="j:Subject" mode="caution_other">
		<table>
 		<xsl:if test="j:SubjectCautionInformationCaveat != 'Convicted Felon'">
		<tr>
			<td class="caution width10percent" valign="top">
				<xsl:text>CAUTION:</xsl:text>
			</td>
			<td class="caution width75percent" valign="top" colspan="2">
				<xsl:for-each select="j:SubjectCautionInformationCaveat">
					<xsl:value-of select="."/><br/>
				</xsl:for-each>
			</td>
		</tr>
		</xsl:if>
		</table>
	</xsl:template>
	
	<!-- buttons under caveat-->
	<xsl:template name="header_buttons">
		<div align="center">
			<span style="background-color: blue;">
				&#160;<a style="color: white; font-size: medium" href="#identification{$responseId}">Identification</a>&#160;
			</span>
			<xsl:text>&#160;&#160;</xsl:text>
			<xsl:if test="//doj:Result/doj:Automated/rap:RapSheet/rap:Cycle">
				<span style="background-color: blue;">
					&#160;<a style="color: white; font-size: medium" href="#history{$responseId}">Criminal History</a>&#160;
				</span>
				<xsl:text>&#160;&#160;</xsl:text>
			</xsl:if>
			<span style="background-color: blue;">
				&#160;<a style="color: white; font-size: medium" href="#contributing{$responseId}">Contributing Agencies</a>&#160;
			</span>
			<xsl:text>&#160;&#160;</xsl:text>
			<span style="background-color: blue;">
				&#160;<a style="color: white; font-size: medium" href="#request{$responseId}">Your Request</a>&#160;
			</span>
			<xsl:text>&#160;&#160;</xsl:text>
		</div>
	</xsl:template>
	
	<!-- Subject Caution Information and Death Information -->
	<xsl:template match="j:Subject" mode="caution_death">
		<table width="100%">
		<tr>
			<td class="death_living" colspan="2">
				<xsl:for-each select="j:PersonLivingIndicator">
					<xsl:text>Living status:&#160;</xsl:text>
					<xsl:choose>
						<xsl:when test=".='true'">
							<xsl:text>LIVING</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>DECEASED</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates select="." mode="reportedDate"/>
					<xsl:apply-templates select="." mode="reportingOrganizationText"/>
					<xsl:apply-templates select="." mode="commentText"/>
					<br/>
				</xsl:for-each>
				<xsl:for-each select="j:PersonDeathDate">
					<xsl:text>Death date:&#160;</xsl:text>
					<xsl:apply-templates select="." mode="FormatFullDateAsMMDDYYYY"/><br/>
				</xsl:for-each>
			</td>
		</tr>
		</table>
	</xsl:template>
	
	<!-- Controlling template for subject details -->
	<xsl:template match="j:Subject" mode="subject_details">
		<table width="100%">
		<tr>
			<td class="width80percent">
				<table width="100%">
					<xsl:apply-templates select="j:PersonName" mode="subject_name"/>
					<tr>
						<td colspan="2">
							<div class="detailvalue">
								<xsl:apply-templates select="j:PersonPhysicalDetails" mode="gender_race"/>
								<xsl:apply-templates select="j:PersonBirthLocation" mode="birth_location"/>
								<xsl:apply-templates select="j:PersonSocialDetails"/>
								<xsl:apply-templates select="j:PersonBirthDate"/>
								<xsl:apply-templates select="j:PersonPhysicalDetails" mode="height_to_skin"/>
								<xsl:apply-templates select="j:PersonBiometricDetails" mode="blood_type"/>
								<xsl:apply-templates select="j:Residence" mode="subject_residence"/>
							</div>
						</td>
					</tr>
				</table>
			</td>
			<td class="width20percent centered_top" align="right">
				<br/>
					<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonDigitalImage" mode="image" />
			</td>
		</tr>
		<tr>
			<td><br/></td><td></td>
		</tr>
		</table>
		<!-- <xsl:call-template name="SMT_Photo_Links"/> -->
		<xsl:apply-templates select="."  mode="ssn_to_notice"/>
		<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonPhysicalFeature" mode="subject_physical"/>
		<xsl:apply-templates select="." mode="alias_name"/>
		<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonDigitalImage" mode="photo_info"/>
	</xsl:template>
	
	<!-- Matches any element - if element has reportedDate attribute it attaches a phrase -->
	<xsl:template match="*" mode="reportedDate">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="@j:reportedDate">
			<xsl:text>as of&#160;</xsl:text>
			<xsl:apply-templates select="@j:reportedDate" mode="FormatFullDateAsMMDDYYYY"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	<!-- Matches any element - if element has reportingOrganizationText attribute it attaches a phrase -->
	<xsl:template match="*" mode="reportingOrganizationText">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="@j:reportingOrganizationText">
			<xsl:text>reported by&#160;</xsl:text>
			<xsl:value-of select="@j:reportingOrganizationText"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	<!-- Matches any element - if element has commentText attribute it attaches a phrase -->
	<xsl:template  match="*" mode="commentText">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="@j:commentText">
			<xsl:text>--</xsl:text>
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="@j:commentText"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	<!-- an alternate way to display attributes -->
	<xsl:template match="*" mode="all_attributes">
		<xsl:apply-templates select="." mode="reportedDate"/>
		<xsl:apply-templates select="." mode="reportingOrganizationText"/>
		<xsl:apply-templates select="." mode="commentText"/>
	</xsl:template>
	
	<!-- If calling template has match containing person name information, name will print out -->
	<xsl:template name="person_type">
		<xsl:if test="j:PersonPrefixName">
			<xsl:for-each select="j:PersonPrefixName">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		<xsl:if test="j:PersonGivenName">
			<xsl:value-of select="j:PersonGivenName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		<xsl:if test="j:PersonMiddleName">
			<xsl:for-each select="j:PersonMiddleName">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		<xsl:if test="j:PersonSurName">
			<xsl:value-of select="j:PersonSurName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		<xsl:if test="j:PersonSuffixName">
			<xsl:for-each select="j:PersonSuffixName">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		<xsl:if test="j:PersonFullName">
			<xsl:value-of select="j:PersonFullName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	<!-- Elements of type "LocationType" can have their info printed here-->
	<xsl:template match="j:EmploymentLocation | j:Residence | j:PersonBirthLocation | j:OrganizationLocation">
		<xsl:if test="j:LocationName">
			<xsl:apply-templates select="j:LocationName" mode="TitleCase"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:AddressFullText">
			<xsl:apply-templates select="j:LocationAddress/j:AddressFullText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationStreet/j:StreetFullText">
			<xsl:apply-templates select="j:LocationAddress/j:LocationStreet/j:StreetFullText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationSecondaryUnitText">
			<xsl:apply-templates select="j:LocationAddress/j:LocationSecondaryUnitText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:AddressMailDeliveryUnitText">
			<xsl:apply-templates select="j:LocationAddress/j:AddressMailDeliveryUnitText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationCityName">
			<xsl:apply-templates select="j:LocationAddress/j:LocationCityName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationCountyName">
			<xsl:apply-templates select="j:LocationAddress/j:LocationCountyName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationStateName">
			<xsl:value-of select="j:LocationAddress/j:LocationStateName"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationPostalCodeID">
			<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeID"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationCountyName">
			<xsl:value-of select="j:LocationAddress/j:LocationCountryName"/>			
		</xsl:if>
		<xsl:if test="j:LocationContactInformation">
			<xsl:text>Contact information:&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationContactInformation/j:ContactInformationDescriptionText">
			<xsl:value-of select="j:LocationContactInformation/j:ContactInformationDescriptionText"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		<xsl:for-each select="j:LocationContactInformation/j:ContactTelephoneNumber">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_than_separator"/>
		</xsl:for-each>
		<xsl:for-each select="j:LocationContactInformation/j:ContactFacsimileNumber">
			<xsl:if test="position() = 1">
				<xsl:text>Fax:</xsl:text>
			</xsl:if>
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_than_separator"/>
		</xsl:for-each>
		<xsl:for-each select="j:LocationContactInformation/j:ContactEmailID">
		<a href="mailto:{.}"><xsl:value-of select="."/></a>
			<xsl:call-template name="if_not_last_than_separator"/>
		</xsl:for-each>
	</xsl:template>
	
	<!-- name of subject -->
	<xsl:template match="j:PersonName" mode="subject_name">
		<!-- div class="subject_name" -->
		<xsl:if test="position()=1">
			<tr>
				<td class="subject_name">
					<xsl:call-template name="person_type"/>
				</td>
				<td align="center">
					<xsl:if test="../j:PersonAlternateName">
						<a href="#alias{$responseId}"><img border="0" src="../../images/aliasfraudlink.jpg" alt="aliases"/></a>
					</xsl:if>
				</td>
			<br/>
			</tr>
		</xsl:if>
		<!-- /div -->
	</xsl:template>
	
	<!-- gender and race of subject -->
	<xsl:template match="j:PersonPhysicalDetails" mode="gender_race">
		<xsl:for-each select="j:PersonSexText">
			<xsl:value-of select="." />
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
			<xsl:text>/</xsl:text>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>	
		<xsl:for-each select="j:PersonRaceText">
			<xsl:value-of select="." />
			<xsl:call-template name="if_not_last_than_separator"/>
		</xsl:for-each>
		<br/>
	</xsl:template>
	
	<!-- birth location of subject -->
	<xsl:template match="j:PersonBirthLocation" mode="birth_location">
		<xsl:if test="position() = 1">
			<xsl:text>Born in&#160;</xsl:text>
		</xsl:if>
		<xsl:apply-templates select="."/>
		<xsl:if test="position() = 1">
			<xsl:text>;</xsl:text>
		</xsl:if>
		<xsl:call-template name="if_not_last_than_separator"/>
		<xsl:call-template name="if_last_than_separator"/>
	</xsl:template>
	
	<!-- social detials of subject -->
	<xsl:template match="j:PersonSocialDetails">
		<xsl:for-each select="j:PersonCitizenshipText">
			<xsl:if test="position() = 1">
				<xsl:text>Citizen of&#160;</xsl:text>
			</xsl:if>
			<xsl:value-of select="." />
			<xsl:text>&#160;</xsl:text>
			<xsl:apply-templates select="." mode="reportedDate"/>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>
		<xsl:for-each select="j:PersonEthnicityText">
			<xsl:value-of select="." />
			<xsl:text>&#160;</xsl:text>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>
		<xsl:for-each select="j:PersonMaritalStatusText">
			<xsl:value-of select="." />
			<xsl:text>&#160;</xsl:text>
			<xsl:apply-templates select="." mode="reportedDate"/>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>
			<xsl:for-each select="j:PersonReligionText">
			<xsl:value-of select="." />
			<xsl:text>&#160;</xsl:text>
			<xsl:apply-templates select="." mode="reportedDate"/>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_break"/>
		</xsl:for-each>
		<br/>
	</xsl:template>
	
	<!-- birthdate of subject -->
	<xsl:template match="j:PersonBirthDate">
		<xsl:apply-templates select="." mode="FormatFullDateAsMMDDYYYY"/>
		<xsl:call-template name="if_not_last_than_separator"/>
		<xsl:call-template name="if_last_than_break"/>
	</xsl:template>
	
	<!-- height, weight, eye color , hair color, and skin tone of subject -->
	<xsl:template match="j:PersonPhysicalDetails" mode="height_to_skin">
		<xsl:for-each select="j:PersonHeightMeasure">
			<xsl:value-of select="substring(.,1,1)" />
			<xsl:text>'</xsl:text>
			<xsl:value-of select="substring(.,2,2)" />
			<xsl:text>"&#32;</xsl:text>
			<xsl:apply-templates select="." mode="reportedDate"/>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>
		<xsl:for-each select="j:PersonWeightMeasure">
			<xsl:value-of select="." />
			<xsl:text>lbs&#32;</xsl:text>
			<xsl:apply-templates select="." mode="reportedDate"/>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>
		<xsl:for-each select="j:PersonEyeColorText">
			<!-- xsl:if test="position() = 1">
				<xsl:text>Eye Color:&#32;</xsl:text>
			</xsl:if -->
			<xsl:value-of select="." />
			<xsl:text>&#32;</xsl:text>
			<xsl:if test="position() = 1">
				<xsl:text>Eyes&#32;</xsl:text>
			</xsl:if>
			<xsl:apply-templates select="." mode="reportedDate"/>
			<xsl:text>;</xsl:text>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>
		<xsl:for-each select="j:PersonHairColorText">
			<!-- xsl:if test="position() = 1">
				<xsl:text>Hair Color:&#32;</xsl:text>
			</xsl:if -->
			<xsl:value-of select="." />
			<xsl:text>&#32;</xsl:text>
			<xsl:if test="position() = 1">
				<xsl:text>Hair&#32;</xsl:text>
			</xsl:if>
			<xsl:apply-templates select="." mode="reportedDate"/>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>
		<xsl:for-each select="j:PersonSkinToneText">
			<xsl:if test="position() = 1">
				<xsl:text>Skin Tone:&#32;</xsl:text>
			</xsl:if>
			<xsl:value-of select="." />
			<xsl:text>&#32;</xsl:text>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_separator"/>
		</xsl:for-each>
	</xsl:template>
	
	<!-- blood type of subject -->
	<xsl:template match="j:PersonBiometricDetails" mode="blood_type">
		<xsl:for-each select="j:PersonBloodTypeText">
			<xsl:value-of select="." />
			<xsl:text>&#32;</xsl:text>
			<xsl:call-template name="if_not_last_than_separator"/>
			<xsl:call-template name="if_last_than_break"/>
		</xsl:for-each>
	</xsl:template>
	
	<!-- residence of subject -->
	<xsl:template match="j:Residence" mode="subject_residence">
		<br/>
	 <xsl:apply-templates select="."/>
		<xsl:apply-templates select="." mode="reportedDate"/>
		<!-- xsl:call-template name="if_not_last_than_separator"/ -->
	</xsl:template>
	
	<!-- links under state ID and FBI number -->
	<xsl:template name="SMT_Photo_Links">
		<table width="100%">
		<tr>
			<td class="width50percent centered no_decoration">
				<a href="#smt{$responseId}"><img border="0" src="../../images/scarsMarksTattoos.jpg" alt="SMT"/></a>
			</td>
			<td class="width50percent centered no_decoration">
				<a href="#photo{$responseId}"><img border="0" src="../../images/photoInformation.jpg" alt="photo"/></a>
			</td>
		</tr>
		</table>
	</xsl:template>
	
	<!-- SSN, Misc #, Driver License, fingerprint, palm print, AFIS, DNA, Employer, Occupation, Employment, Offender Notice -->
	<xsl:template match="j:Subject"  mode="ssn_to_notice">
		<table>
 		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'FBI:'"/>
				<xsl:with-param name="value">
					<xsl:value-of select="j:PersonAssignedIDDetails/j:PersonFBIID"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<td class="width5percent"></td>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'SOCIAL SECURITY #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonSSNID">
						<xsl:value-of select="substring(j:ID,1,3)"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="substring(j:ID,4,2)"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="substring(j:ID,6,4)"/>
						<xsl:call-template name="if_not_last_than_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</tr>
 		<tr>
			<xsl:if test="j:PersonAssignedIDDetails/j:PersonStateID/j:ID">
				<td class="black_header width20percent">
			    	<xsl:text>STATE ID:</xsl:text>
				</td>
				<td class="detailvalue width25percent" style="white-space: nowrap;">
					<xsl:variable name="sid">
						<xsl:value-of select="j:PersonAssignedIDDetails/j:PersonStateID/j:ID"/>
					</xsl:variable>
					<xsl:value-of select="$sid"/>
			    	<xsl:text>&#32;</xsl:text>
					<!-- Only display the Full Record hyperlink if this is an EBC Ident response -->
					<xsl:if test="$from='ebc' and ancestor::doj:Result/doj:MessageKeyCode='IR'">
						<xsl:variable name="rapSheetRequest" select="ancestor::rap:RapSheet/rap:Introduction/rap:RapSheetRequest" />
						<xsl:variable name="purposeCd" select="$rapSheetRequest/rap:PurposeCode" />
						<xsl:variable name="attention" select="$rapSheetRequest/rap:Attention" />
		    			<xsl:variable name="oboORI" select="/doj:CCHResponseDocument/doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID" />
						<form id="fullRecordRequest_{$sid}" action="/secure/personsearch/buildcchfq.jsp" method="post" style="display:inline">
							<input name="sid" type="hidden" value="{$sid}" />
							<xsl:if test="$purposeCd">
								<input name="pur" type="hidden" value="{$purposeCd}" />
							</xsl:if>
							<xsl:if test="$attention">
								<input name="attn" type="hidden" value="{$attention}" />
							</xsl:if>
							<xsl:if test="$oboORI">
								<input name="ori" type="hidden" value="{$oboORI}" />
							</xsl:if>
							<xsl:if test="/doj:CCHResponseDocument/doj:Result/doj:Automated/rap:RapSheet/j:Subject/j:PersonBiometricDetails/j:PersonDigitalImage/j:BinaryObject.Base64">
								<input name="includeImages" type="hidden" value="yes" />
							</xsl:if>
						</form>
						<a href="javascript:document.getElementById('fullRecordRequest_{$sid}').submit();">Click here to submit Full Record</a>
			    	</xsl:if>
				</td>
			</xsl:if>
			<td class="width5percent"></td>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'MISCELLANEOUS #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonOtherID">
						<xsl:value-of select="j:IDTypeText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="j:IDIssuingAuthorityText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="j:ID"/>
						<xsl:call-template name="if_not_last_than_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width30percent'"/>
			</xsl:call-template>
		</tr>
		</table>
		
		<table>
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'DRIVERS LICENSE #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonDriverLicenseID">
						<xsl:value-of select="j:ID"/>
						<xsl:call-template name="if_not_last_than_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'FINGERPRINT CLASS:'"/>
				<xsl:with-param name="value">
					<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonFingerprintSet/j:BiometricValueText" mode="attributes"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		<xsl:for-each select="j:PersonBiometricDetails/j:PersonPalmPrint">
			<tr>
				<td valign="top" class="black_header width25percent">PALM PRINT, ORI and LITERAL:</td>
				<td class="detailvalue" valign="top">
					<xsl:value-of select="j:BiometricImage/j:BinaryCaptureOrganization/j:OrganizationORIID/j:ID"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="j:BiometricImage/j:BinaryCaptureOrganization/j:OrganizationName"/>
				</td>
				<td valign="top">
					<!-- img src="images/palm" alt=""/ -->
				</td>
			</tr>
		</xsl:for-each>
		<xsl:for-each select="j:PersonBiometricDetails/j:PersonFingerprintSet/j:Fingerprint/j:FingerprintFingerText">
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="'AFIS CLASSIFICATION:'"/>
					<xsl:with-param name="value" select="."/>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		<xsl:for-each select="j:PersonBiometricDetails/j:PersonDNA">
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="'DNA:'"/>
					<xsl:with-param name="value">
						<xsl:if test="j:BiometricEncodingMethodText != 'UNKNOWN'">
							<xsl:text>Method:&#32;</xsl:text>
							<xsl:value-of select="j:BiometricEncodingMethodText"/>
							<xsl:text>,&#32;</xsl:text>
						</xsl:if>
						<xsl:for-each select="j:BiometricDescriptionText">
							<xsl:if test="position()=1">
								<xsl:text>Description:&#32;</xsl:text>
							</xsl:if>
							<xsl:value-of select="."/>
							<xsl:call-template name="if_not_last_than_separator"/>
							<xsl:if test="position() = last()">
								<xsl:text>,</xsl:text>
							</xsl:if>
							<xsl:text>&#32;</xsl:text>
						</xsl:for-each>
						<xsl:if test="j:BiometricCaptureOrganization/j:OrganizationORIID/j:ID">
							<!-- xsl:text>Agency:&#32;</xsl:text -->
							<xsl:value-of select="j:BiometricCaptureOrganization/j:OrganizationORIID/j:ID"/>
							<xsl:text>,&#32;</xsl:text>
						</xsl:if>
						<!-- xsl:text>Name:&#32;</xsl:text -->
						<xsl:value-of select="j:BiometricCaptureOrganization/j:OrganizationName"/>
						<xsl:text>,&#32;</xsl:text>
						<xsl:for-each select="j:DNALocus">
							<xsl:if test="position() = 1">
								<xsl:text>Locus(Type/Value(s)):&#32;</xsl:text>
							</xsl:if>
							<xsl:value-of select="j:DNALocusTypeText"/>
							<xsl:text>/</xsl:text>
							<xsl:for-each select="j:DNALocusValue">
								<xsl:value-of select="."/>
								<xsl:if test="position() != last()">
									<xsl:text>,</xsl:text>
								</xsl:if>
							</xsl:for-each>
							<xsl:text>&#32;</xsl:text>
						</xsl:for-each>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		
		<!--Employment info -->
		<xsl:for-each select="j:Employment">
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="'EMPLOYER:'"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="j:EmploymentEmployerName" mode="TitleCase"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="'OCCUPATION:'"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="j:EmploymentOccupationText" mode="TitleCase"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<!-- xsl:with-param name="label" select="'EMPLOYMENT ADDRESS:'"/ -->
					<xsl:with-param name="value">
						<xsl:apply-templates select="j:EmploymentLocation"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
					</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'OFFENDER NOTICE:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="j:SubjectOffenderNoticeCaveat">
						<xsl:value-of select="."/>
						<xsl:call-template name="if_not_last_than_separator"/>
						<xsl:call-template name="if_last_than_break"/>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		</table>
	</xsl:template>
	
	<!-- SMT of subject -->
	<xsl:template match="j:PersonPhysicalFeature" mode="subject_physical">
		<a name="smt{$responseId}"></a>
		<xsl:if test="position()=1">
			<table width="100%">
			<tr>
				<td class="width100percent">
					<span class="black_header"><xsl:text>SCARS MARKS TATTOOS DATA:&#32;</xsl:text></span><br/>
				</td>
			</tr>
			</table>
		</xsl:if>
		<table width="100%">
		<tr>
			<td class="width75percent detailvalue">
				<xsl:if test="j:PhysicalFeatureCategoryText">
					<xsl:text>Category:&#32;</xsl:text>
					<xsl:value-of select="j:PhysicalFeatureCategoryText"/>
					<xsl:text>&#32;</xsl:text>
				</xsl:if>
				<xsl:if test="j:PhysicalFeatureTypeCode">
					<xsl:apply-templates select="j:PhysicalFeatureTypeCode" mode="TitleCase"/>
					<xsl:text>&#32;</xsl:text>
				</xsl:if>
				<xsl:if test="j:PhysicalFeatureDescriptionText">
					<xsl:text>---</xsl:text>
					<xsl:apply-templates select="j:PhysicalFeatureDescriptionText" mode="TitleCase"/>
					<xsl:text>&#32;</xsl:text>
				</xsl:if>
				<br/>
				<xsl:if test="j:PhysicalFeatureImage/j:BinaryCaptureOrganization/j:OrganizationORIID">
					<xsl:value-of select="j:PhysicalFeatureImage/j:BinaryCaptureOrganization/j:OrganizationORIID/j:ID"/>
					<xsl:text>&#32;</xsl:text>
				</xsl:if>
				<xsl:apply-templates select="j:PhysicalFeatureImage/j:BinaryCaptureOrganization/j:OrganizationName" mode="TitleCase"/>
			</td>
			<td class="width25percent">
				<!-- img src="images/smtimage" alt=""/ -->
			</td>
		</tr>
		</table>
		<xsl:call-template name="if_last_than_break"/>
		<xsl:call-template name="if_last_than_break"/>
	</xsl:template>
	
	<!-- alias names of subject -->
	<xsl:template match="j:Subject" mode="alias_name">
		<xsl:if test="j:PersonAlternateName">
			<table>
			<a name="alias{$responseId}"></a>
			<span class="black_header"><xsl:text>ALIAS NAMES/FRAUDULENT DATA:</xsl:text><br/></span>
			<span class="detailvalue">
				<xsl:call-template name="listAlias"/>
			</span>
			<br/><br/>
			</table>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="listAlias">
		<table>
			<xsl:for-each select="j:PersonAlternateName[position() mod 2 != 0]">
				<xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
				<xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
				<xsl:variable name="startposition" select="((number(position())-1)*2)+1"/>
				<tr>
					<td class="width20percent">
						<xsl:if test="$startposition = 1">
							<xsl:text>Alias Names:</xsl:text>
						</xsl:if>
					</td>
					<xsl:apply-templates select="../j:PersonAlternateName" mode="aliasNames">
					<xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
					<xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
						<xsl:with-param name="startposition" select="$startposition"/>
					</xsl:apply-templates>
					<td class="width20percent" />
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>
	
	<xsl:template match="j:PersonAlternateName" mode="aliasNames">
		<xsl:param name="startposition"/>
		<xsl:if test="position() = number($startposition) or position() = number($startposition)+1">
			<td class="width30percent">
				<xsl:call-template name="person_type"/>
			</td>
		</xsl:if>
	</xsl:template>
	
	<!-- photo information -->
	<xsl:template match="j:PersonDigitalImage" mode="photo_info">
		<a name="photo{$responseId}"></a>
		<xsl:if test="position()=1">
			<table width="100%">
			<tr>
				<td class="width100percent">
					<span class="black_header"><xsl:text>PHOTO INFORMATION:</xsl:text></span><br/>
				</td>
			</tr>
			</table>
		</xsl:if>
		<xsl:if test="not(j:BinaryObject.Base64)">
			<table width="100%" class="detailvalue">
			<tr>
				<td class="width15percent">
					<xsl:apply-templates select="j:BinaryCaptureDate" mode="FormatFullDateAsMMDDYYYY"/>
				</td>
				<td class="width65percent">
					<xsl:value-of select="j:BinaryCaptureOrganization/j:OrganizationORIID/j:ID"/>
					<xsl:text>&#160;&#160;&#160;</xsl:text>
					<xsl:apply-templates select="j:BinaryCaptureOrganization/j:OrganizationName" mode="TitleCase"/>
				</td>
				<td class="width20percent">
					<!-- img src="images/mugshot" alt=""/> -->
				</td>
			</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	<!-- Controlling template for cycle info -->
	<xsl:template match="rap:Cycle">
		<span class="cycle">
			<p/>Cycle<xsl:text>&#32;</xsl:text><xsl:number value="position()"/><br/>
		</span>
		<xsl:if test="rap:CycleEarliestDate">
			<span class="history_black_header">EARLIEST EVENT DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:CycleEarliestDate" mode="FormatLongDate"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="rap:CycleTrackingID/j:ID">
			<span class="history_black_header">ARREST TRACKING NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:CycleTrackingID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:Incident/j:ActivityDate">
			<span class="history_black_header">DATE OF OFFENSE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:Incident/j:ActivityDate" mode="FormatLongDate"/><br/>
			</span>
		</xsl:if>
		<xsl:apply-templates select="j:Arrest"/>
		<xsl:apply-templates select="j:Booking"/>
		<xsl:apply-templates select="j:Arrest/j:ArrestCharge"/>
		<xsl:apply-templates select="rap:Prosecution"/>
		<xsl:apply-templates select="rap:Prosecution/j:ProsecutionCharge"/>
		<xsl:call-template name="CourtAction"/>
		<xsl:apply-templates select="rap:CourtAction/j:CourtCharge"/>
		<xsl:apply-templates select="rap:Sentencing"/>
		<xsl:apply-templates select="rap:Supervision"/>
	</xsl:template>
	
	<!-- Arrest -->
	<xsl:template match="j:Arrest">
		<br/><span class="major_history_header">ARREST DATA</span><br/>
		<xsl:call-template name="indent"/>
		<span class="history_black_header">SUBJECT NAME:&#160;&#160;</span>
		<span class="arrest_name">
			<xsl:apply-templates select="j:ArrestSubject/j:PersonName" mode="Arrest_Prosecution_Court_Supervision"/><br/>
		</span>
		<xsl:if test="j:ActivityTypeText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">TYPE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ActivityTypeText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ActivityDate" mode="FormatLongDate"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ArrestAgencyRecordID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ArrestAgencyRecordID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
 		<xsl:if test="j:ArrestAgency">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">ARREST AGENCY:&#160;&#160;</span>
			<xsl:apply-templates select="j:ArrestAgency" />
		</xsl:if>
		<xsl:if test="j:ArrestSubject/j:SubjectID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LOCAL IDENTIFICATION NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ArrestSubject/j:SubjectID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ActivityCommentText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ActivityCommentText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	<!-- Booking -->
	<xsl:template match="j:Booking">
		<span class="minor_history_header">BOOKING</span><br/>
		<xsl:if test="j:BookingAgencyRecordID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:BookingAgencyRecordID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:BookingAgency/j:OrganizationORIID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">AGENCY:&#160;&#160;</span>
			<xsl:apply-templates select="j:BookingAgency" />
		</xsl:if>
	</xsl:template>
	
	<!--  Arrest/Booking Agency ORI and Name -->
	<xsl:template match="j:ArrestAgency | j:BookingAgency | j:Court | j:SupervisionAgency">
		<span class="history_data">
			<xsl:apply-templates select="j:OrganizationORIID/j:ID" mode="history_unbounded"/>
			<xsl:text>&#160;&#160;</xsl:text>
			<xsl:apply-templates select="j:OrganizationName" mode="history_unbounded"/><br/>
		</span>
	</xsl:template>
	
	<!-- ArrestCharge/ProsecutionCharge/CourtCharge/SupervisionCharge  -->
	<xsl:template match="j:ArrestCharge | j:ProsecutionCharge | j:CourtCharge | rap:SupervisionCharge">
		<span class="minor_history_header">CHARGE</span><br/>
		<xsl:if test="j:ChargeSequenceID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SEQUENCE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeSequenceID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeTrackingID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">TRACKING NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeTrackingID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:apply-templates select="j:ChargeStatute"/>
		<xsl:apply-templates select="." mode="literal_to_comments"/>
	</xsl:template>
	
	<!-- Prosecution -->
	<xsl:template match="rap:Prosecution">
		<br/><span class="major_history_header">PROSECUTION</span><br/>
		<xsl:if test="rap:ProsecutionSubject/j:PersonName">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SUBJECT NAME:&#160;&#160;</span>
			<span class="other_criminal_name">
				<xsl:apply-templates select="rap:ProsecutionSubject/j:PersonName" mode="Arrest_Prosecution_Court_Supervision"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ActivityDate" mode="FormatLongDate"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="rap:ProsecutionAgencyRecordID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:ProsecutionAgencyRecordID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="rap:ProsecutionAgency">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">PROSECUTOR:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:ProsecutionAgency/j:OrganizationORIID/j:ID" mode="history_unbounded"/>
				<xsl:text>&#160;&#160;</xsl:text>
				<xsl:apply-templates select="rap:ProsecutionAgency/j:OrganizationName" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="rap:ProsecutionSubject/j:SubjectID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LOCAL IDENTIFICATION NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:ProsecutionSubject/j:SubjectID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="ActivityCommentText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ActivityCommentText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="CourtAction">
		<xsl:for-each select="rap:CourtAction">
			<xsl:if test="position()=1">
				<br/><span class="major_history_header">COURT</span><br/>
				<xsl:if test="rap:CourtSubject/j:PersonName">
					<xsl:call-template name="indent"/>
					<span class="history_black_header">SUBJECT NAME:&#160;&#160;</span>
					<span class="other_criminal_name">
						<xsl:apply-templates select="rap:CourtSubject/j:PersonName" mode="Arrest_Prosecution_Court_Supervision"/><br/>
					</span>
				</xsl:if>
			</xsl:if>
		</xsl:for-each>
		<xsl:for-each select="rap:CourtAction/j:ActivityDate">
			<xsl:if test="position()=1">
				<xsl:call-template name="indent"/>
				<span class="history_black_header">DATE:&#160;&#160;</span>
			</xsl:if>
			<span class="history_data">
				<xsl:if test="position()!=1">
					<xsl:text>, </xsl:text>
				</xsl:if>
				<xsl:apply-templates select="." mode="FormatLongDate"/>
				<xsl:if test="position()=last()">
					<br/>
				</xsl:if>
			</span>
		</xsl:for-each>
		<xsl:for-each select="rap:CourtAction/rap:CourtRecordID/j:ID">
			<xsl:if test="position()=1">
				<xsl:call-template name="indent"/>
				<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			</xsl:if>
			<span class="history_data">
				<xsl:if test="position()!=1">
					<xsl:text>, </xsl:text>
				</xsl:if>
				<xsl:apply-templates select="." mode="history_unbounded"/>
				<xsl:if test="position()=last()">
					<br/>
				</xsl:if>
			</span>
		</xsl:for-each>
		<xsl:for-each select="rap:CourtAction/j:Court">
			<xsl:if test="position()=1">
				<xsl:call-template name="indent"/>
				<span class="history_black_header">COURT:&#160;&#160;</span>
				<span class="history_data">
					<xsl:apply-templates select="." />
					<br/>
				</span>
			</xsl:if>
		</xsl:for-each>
		<xsl:for-each select="rap:CourtAction/j:ActivityCommentText">
			<xsl:if test="position()=1">
				<xsl:call-template name="indent"/>
				<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			</xsl:if>
			<span class="history_data">
				<xsl:if test="position()!=1">
					<xsl:text>, </xsl:text>
				</xsl:if>
				<xsl:apply-templates select="." mode="history_unbounded"/>
				<xsl:if test="position()=last()">
					<br/>
				</xsl:if>
			</span>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="rap:Sentencing">
		<span class="minor_history_header">SENTENCING</span><br/>
		<xsl:if test="j:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ActivityDate" mode="FormatLongDate"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="rap:CourtRecordID/j:ID">
	  		<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:CourtRecordID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:Court">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COURT:&#160;&#160;</span>
			<xsl:apply-templates select="j:Court"/>
		</xsl:if>
		<xsl:apply-templates select="j:Sentence/j:SentenceCharge"/>
		<xsl:apply-templates select="j:Sentence/j:SentenceDescriptionText"/>
		<xsl:if test="j:ActivityCommentText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ActivityCommentText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	<!-- Supervision -->
	<xsl:template match="rap:Supervision">
		<br/><span class="major_history_header">SUPERVISION</span><br/>
		<xsl:call-template name="indent"/>
		<span class="history_black_header">SUBJECT NAME:&#160;&#160;</span>
		<span class="other_criminal_name">
			<xsl:choose>
				<xsl:when test="j:SupervisionSubject/j:PersonName">
					<xsl:apply-templates select="j:SupervisionSubject/j:PersonName" mode="Arrest_Prosecution_Court_Supervision"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="//j:Subject/j:PersonName" mode="Arrest_Prosecution_Court_Supervision"/>
				</xsl:otherwise>
			</xsl:choose>
		</span><br/>
		<!-- First <j:ActivityCommentText> will always have either 'Juvenile Submission' or 
		     'Adult Submission' -->
		<xsl:if test="j:ActivityCommentText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">TYPE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:for-each select="j:ActivityCommentText">
					<xsl:if test="position() = 1">
						<xsl:apply-templates select="." mode="history_unbounded"/><br/>
					</xsl:if>
				</xsl:for-each>
			</span>
		</xsl:if>
		<xsl:if test="j:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ActivityDate" mode="FormatLongDate"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="rap:SupervisionAgencyRecordID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CORRECTIONS OR JAIL CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:SupervisionAgencyRecordID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="rap:CourtRecordID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COURT CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:CourtRecordID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:SupervisionAgency">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SUPERVISION AGENCY:&#160;&#160;</span>
			<xsl:apply-templates select="j:SupervisionAgency"/>
		</xsl:if>
		<xsl:if test="j:SupervisionSubject/j:SubjectID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LOCAL IDENTIFICATION NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:SupervisionSubject/j:SubjectID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ActivityCommentText and count(j:ActivityCommentText) > 1">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:for-each select="j:ActivityCommentText">
					<xsl:if test="position() > 1">
						<xsl:apply-templates select="." mode="history_unbounded"/><br/>
					</xsl:if>
				</xsl:for-each>
			</span>
		</xsl:if>
		<xsl:apply-templates select="rap:SupervisionCharge"/><br/>
		<span class="minor_history_header">SUPERVISION ACTION</span><br/>
		<xsl:if test="j:SupervisionCustodyStatus/j:StatusText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">ACTION LITERAL:&#160;&#160;</span>
 			<span class="history_data">
				<xsl:apply-templates select="j:SupervisionCustodyStatus/j:StatusText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:SupervisionRelease/j:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">RELEASE DATE:&#160;&#160;</span>
 			<span class="history_data">
				<xsl:apply-templates select="j:SupervisionRelease/j:ActivityDate" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="j:StatusText">
		<xsl:call-template name="supervisiontokenizer">
			<xsl:with-param name="string" select="." />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="supervisiontokenizer">
		<xsl:param name="string" />
		<xsl:param name="delimiter" select="'=='" />
		<xsl:choose>
			<xsl:when test="$delimiter and contains($string, $delimiter)">
				<xsl:call-template name="sentenseLineTexttokenizer">
					<xsl:with-param name="string" select="substring-before($string,$delimiter)" />
				</xsl:call-template>
				<xsl:call-template name="supervisiontokenizer">
					<xsl:with-param name="string" select="substring-after($string,$delimiter)" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$delimiter and contains($string, ':')">
						<xsl:call-template name="sentenseLineTexttokenizer">
							<xsl:with-param name="string" select="$string" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
						<span class="history_black_header">LITERAL:&#160;&#160;</span>
						<xsl:value-of select="$string" /><br/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="sentenseLineTexttokenizer">
		<xsl:param name="string" />
		<xsl:param name="delimiter" select="':'" />
		<xsl:choose>
			<xsl:when test="$delimiter and contains($string, $delimiter)">
				<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
				<span class="history_black_header">
					<!-- <xsl:if test="position()=1"><xsl:text> 123 </xsl:text></xsl:if>-->
					<xsl:value-of select="position()" />
					<xsl:value-of select="substring-before($string,$delimiter)" />:&#160;&#160;
				</span>
				<span class="history_data">
					<xsl:value-of select="substring-after($string,$delimiter)" /><br/>
				</span>
			</xsl:when>
			<xsl:otherwise>
				<span class="history_data">
					<xsl:value-of select="$string" /><br/>
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
    <xsl:template match="j:ArrestCharge | j:ProsecutionCharge | j:CourtCharge | rap:SupervisionCharge" mode="literal_to_comments">
		<xsl:if test="j:ChargeText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LITERAL:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeReporting/j:ChargeNCICCode">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">NCIC CODE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeReporting/j:ChargeNCICCode" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeCountQuantity">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COUNTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeCountQuantity" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:apply-templates select="j:ChargeClassification" />
		<xsl:if test="j:ChargeDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeDescriptionText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:apply-templates select="j:ChargeDisposition"/>
    </xsl:template>
	
	<!--  Template to apply Charge Classification -->
	<xsl:template match="j:ChargeClassification">
		<xsl:call-template name="indent"/>
		<span class="history_black_header">CLASSIFICATION:&#160;&#160;</span><br/>
		<xsl:if test="j:ChargeApplicabilityText">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">INCHOATE CHARGE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeApplicabilityText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeReducingFactorText">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE REDUCING FACTOR:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeReducingFactorText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeSpecialAllegationText">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE ENHANCING FACTOR:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeSpecialAllegationText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeSeverityText">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE SEVERITY:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeSeverityText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="j:SentenceCharge">
		<xsl:call-template name="indent"/>
		<span class="history_black_header">CONVICTED OFFENSE:</span><br/>
		<xsl:if test="j:ChargeID/j:ID">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="string-length(j:ChargeText) > 0">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE LITERAL:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeSequenceID/j:ID">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE SEQUENCE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeSequenceID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeTrackingID/j:ID">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE TRACKING NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeTrackingID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="j:SentenceDescriptionText">
		<xsl:if test="position()=1">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SENTENCE:&#160;&#160;<br/></span>
		</xsl:if>
		<xsl:call-template name="sentensetokenizer">
			<xsl:with-param name="string" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="sentensetokenizer">
		<xsl:param name="string" />
		<xsl:param name="delimiter" select="':'" />
		<xsl:choose>
			<xsl:when test="$delimiter and contains($string, $delimiter)">
				<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
				<span class="history_black_header">
					<xsl:value-of select="substring-before($string,$delimiter)" />:&#160;&#160;
				</span>
				<span class="history_data">
					<xsl:value-of select="substring-after($string,$delimiter)" /><br/>
				</span>
			</xsl:when>
			<xsl:otherwise>
				<span class="history_data">
					<xsl:value-of select="$string" /><br/>
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="j:ChargeStatute">
		<xsl:if test="j:StatuteJurisdiction/j:LocationStateName">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE STATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:StatuteJurisdiction/j:LocationStateName" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:StatuteCodeID/j:ID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">STATUTE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:StatuteCodeID/j:ID" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="j:ChargeDisposition">
		<xsl:if test="name(..)='j:ArrestCharge'">
			<span class="minor_history_header">ARREST ACTION:&#160;&#160;<br/></span>
		</xsl:if>
		<xsl:if test="name(..)='j:ProsecutionCharge'">
			<span class="minor_history_header">PROSECUTION ACTION:&#160;&#160;<br/></span>
		</xsl:if>
		<xsl:if test="name(..)='j:CourtCharge'">
			<span class="minor_history_header">COURT ACTION:&#160;&#160;<br/></span>
		</xsl:if>
		<xsl:if test="name(..)='rap:SupervisionCharge'">
			<span class="minor_history_header">DISPOSITION&#160;&#160;<br/></span>
		</xsl:if>
		<xsl:if test="@j:commentText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LITERAL:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="@j:commentText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeDispositionDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DISPOSITION DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeDispositionDate" mode="FormatLongDate"/><br/>
			</span>
		</xsl:if>
		<xsl:if test="j:ChargeDispositionDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DISPOSITION:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeDispositionDescriptionText" mode="history_unbounded"/><br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="j:PersonName" mode="Arrest_Prosecution_Court_Supervision">
		<xsl:call-template name="person_type"/>
		<xsl:call-template name="if_not_last_than_separator"/>
	</xsl:template>
	
	<xsl:template match="*" mode="history_unbounded">
		<xsl:value-of select="."/>
		<xsl:call-template name="if_not_last_than_separator"/>
	</xsl:template>
	
	<xsl:template match="j:Organization">
		<a name="contributing{$responseId}"></a>
		<xsl:if test="position() = 1">
			<br/>
			<div class="contributing_agencies"><xsl:text>Contributing Agencies</xsl:text></div>
			<br/>
		</xsl:if>
		<span class="detailvalue">
			<xsl:value-of select="j:OrganizationORIID/j:ID"/>
			<xsl:text>&#160;&#160;&#160;</xsl:text>
			<!-- xsl:value-of select="j:OrganizationName"/ -->
			<xsl:apply-templates select="j:OrganizationName" mode="TitleCase"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:apply-templates select="j:OrganizationLocation"/>
		</span>
		<br/>
		<xsl:if test="position() = last()">
			<br/>
			<br/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="j:PersonDigitalImage" mode="image">
		<xsl:if test="position()=1">
			<xsl:choose>
				<xsl:when test="j:BinaryObject.Base64">
					<xsl:variable name="responseID" select="/doj:CCHResponseDocument/@doj-ext:responseID"/>
					<img ignoreNightMode="true" src="image?ETIMEResponseId={$responseID}&amp;ImageIndex=0&amp;Resize=true"/>
					<br/>
					<a href="javascript: void(0)" onclick="window.open('imageDetail.jsp?ETIMEResponseId={$responseID}&amp;DataServiceCode=CCH&amp;WhatToDo=showImages&amp;ShowOneImage=true', '', 'directories=no, location=no, menubar=no, resizable=yes, toolbar=no, scrollbars=yes, status=no');return false;">
						<img src="../../images/detail.jpg"/>
					</a>
					<!-- 
					<xsl:if test="count(//j:PersonDigitalImage) > 1">
						<a href="javascript: void(0)" onclick="window.open('imageDetail.jsp?ETIMEResponseId={$responseID}&amp;WhatToDo=showImages', '', 'directories=no, location=no, menubar=no, resizable=yes, toolbar=no, scrollbars=yes, status=no');return false;">
							<img src="../../images/additionalimages.jpg"/>
						</a>
					</xsl:if>
					-->
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="j:BinaryAvailableIndicator='true'">
						<span class="textTealSmall">Image Available</span>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>