<?xml version="1.0"?>
<xsl:transform
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:dot-drv="http://www.doj.state.wi.us/dles/cib/dot/response/broker/driver"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dot/response" 
	xmlns:exsl="http://exslt.org/common"
	exclude-result-prefixes="xsl j doj-ext exsl"
>
  <xsl:import href="css.xsl"/>
	<!-- ###### -->	
	<!-- output -->
	<!-- ###### -->
	<xsl:output method="html"
		  version="4.01"
		  encoding="UTF-8" 
		  omit-xml-declaration="yes"
		  doctype-public="-//W3C//DTD HTML 4.01//EN"
		  doctype-system="http://www.w3.org/TR/html4/transitional.dtd"
		  indent="yes"
		  media-type="text/html"/>
		  
    <xsl:param name="theRequestData" />
	<xsl:variable name="REQUEST_DATA" select="exsl:node-set($theRequestData)/*"/>
	
	<xsl:param name="responseId">
		<xsl:value-of select="/*/@*[local-name()='responseID']"/>
	</xsl:param>

	<xsl:template name="html_main">
		<html>
			<head>
				<title>
					<!-- Stylesheets importing this one need to define the following template -->
					<xsl:call-template name="html_title"/>
				</title>
		        <!-- xsl:call-template name="styles_css"/ -->
		        <!-- xsl:call-template name="xsl_css"/ -->
				<link rel="stylesheet" type="text/css" href="../../css/styles.css" />
				<link rel="stylesheet" type="text/css" href="../../css/dynamic_styles.jsp" />
				<!--[if lt IE 7]>
					<link rel="stylesheet" type="text/css" href="../../css/ie_hacks.css" />
				<![endif]-->
				<script language="javascript" type="text/javascript" src="../../js/nightMode.jsp"></script>
				<script language="javascript" type="text/javascript" src="../../js/utility.js"></script>
				<xsl:call-template name="html_head_extension" />
			</head>
			<body>
				<div id="container">
					<div id="left-border"></div>
					<div id="right-border"></div>
					<div id="header">
						<div id="etimelogo">
							<img src="../../images/head.jpg" alt="TIME" />
						</div>
						<div id="navigation">
							<ul id="linklist">
								<li>
									<a href="../../secure/quicksearch/quicksearch.jsp">Home</a>
									<xsl:text>&#160;&#183;&#160;</xsl:text>
								</li>
								<li>
									<a href="../../secure/vehiclesearch/vehiclesearch.jsp">Vehicle Search</a>
									<xsl:text>&#160;&#183;&#160;</xsl:text>
								</li>
								<li>
									<a href="../../secure/personsearch/personsearch.jsp">Person Search</a>
									<xsl:text>&#160;&#183;&#160;</xsl:text>
								</li>
								<li>
									<a href="../../secure/propertysearch/propertysearch.jsp">Property Search</a>
									<xsl:text>&#160;&#183;&#160;</xsl:text>
								</li>
								<li>
									<a href="../../secure/boatsearch/boatsearch.jsp">Boat Search</a>
									<xsl:text>&#160;&#183;&#160;</xsl:text>
								</li>
								<li>
									<a href="../../secure/results/">Previous Results</a>
								</li>
								<li>
									<br />
									Help
									<xsl:text>&#160;&#183;&#160;</xsl:text>
								</li>
								<li>
									<a href="mailto:etime@doj.state.wi.us">Contact</a>
									<xsl:text>&#160;&#183;&#160;</xsl:text>
								</li>
								<li>
									<a onclick="return logoffClicked()" href="../../logout.jsp">Logoff</a>
								</li>
								<li>
									<br />
									<a href="index.html#Summary={$REQUEST_DATA/esid}">Return to Summary</a>
								</li>
							</ul>
						</div>
					</div>
					<div id="wrapper">
						<div id="content">
							<!-- Stylesheets importing this one need to define the following template -->
							<xsl:call-template name="html_body"/>
							<xsl:call-template name="your_request"/>
						</div>
					</div>
					<div id="footer">
						<p>
						</p>
					</div>
				</div>
			</body>
		</html>
	</xsl:template>


	<xsl:template name="html_head_extension">
		<!-- 
		     Stylesheets importing this one can optionally 
		     override this template in order to add
		     additional children to the <head> tag in order
		     to specify their own local styles, etc.
		-->
	</xsl:template>


	<xsl:template match="j:PersonName" mode="FirstMiddleLastSuffix">
		<xsl:value-of select="j:PersonGivenName" />
		<xsl:if test="j:PersonMiddleName">
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="j:PersonMiddleName" />
			<xsl:if test="string-length(j:PersonMiddleName)=1">
				<xsl:text>.</xsl:text>
			</xsl:if>
		</xsl:if>
		<xsl:text>&#32;</xsl:text>
		<xsl:value-of select="j:PersonSurName" />
		<xsl:if test="j:PersonSuffixName">
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="j:PersonSuffixName" />
		</xsl:if>
	</xsl:template>


	<xsl:template name="your_request">
		<xsl:variable name="HEADER" select="/*/*[local-name()='Header']"/>
		<xsl:variable name="REQUESTOR_DETAILS" select="$HEADER/doj-ext:SubmissionRequestorDetails"/>
		<xsl:variable name="SUBMITTER_DETAILS" select="$HEADER/doj-ext:SubmissionSubmitterDetails"/>
		<a name="request{$responseId}"></a>
		<div class="detaillabel" style="margin-top:15px;clear:both;">Your Request:</div>
		<table class="detailvalue" cellspacing="0">
			<colgroup>
				<col width="25%"/>
				<col width="25%"/>
				<col width="25%"/>
			</colgroup>
			<tr>
				<td>User ID:</td>
				<td><xsl:apply-templates select="$REQUESTOR_DETAILS/doj-ext:SubmissionRequestor.Person/doj-ext:PersonHumanResourcesID/doj-ext:ID" mode="TitleCase"/></td>
				<td>Interface Identifier:</td>
				<td><xsl:value-of select="$REQUESTOR_DETAILS/doj-ext:SubmissionRequestor.InterfaceID/doj-ext:ID"/></td>
			</tr>
			<tr>
				<td>Agency Information:</td>
				<td><xsl:value-of select="$REQUESTOR_DETAILS/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID"/></td>
				<td>Initiator Identifier:</td>
				<td><xsl:value-of select="/*/@doj-ext:initiatorID"/></td>
			</tr>
			<tr>
				<td>EBC Message Identifier:</td>
				<td><xsl:value-of select="/*/@doj-ext:interfaceControlFieldText"/></td>
				<td>Response Identifier:</td>
				<td><xsl:value-of select="$responseId"/></td>
			</tr>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date &#38; Time:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="$SUBMITTER_DETAILS/doj-ext:SubmissionSubmittedDate" mode="FormatFullDateAsMMDDYYYY"/>
					<xsl:text>&#32;</xsl:text>
					<xsl:value-of select="$SUBMITTER_DETAILS/doj-ext:SubmissionSubmittedTime"/>
				</xsl:with-param>
				<xsl:with-param name="label2" select="'State:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/State"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Registration Number:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/PlateNumber"/>
				<xsl:with-param name="label2" select="'VIN:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/VIN"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Type:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/PlateType"/>
				<xsl:with-param name="label2" select="'Expiration Year:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/ExpirationYear"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Primary Name:'"/>
				<xsl:with-param name="value1">
					<xsl:if test="$REQUEST_DATA/LastName or $REQUEST_DATA/FirstName or $REQUEST_DATA/MiddleName">
						<xsl:value-of select="$REQUEST_DATA/LastName"/>
						<xsl:text>,&#32;</xsl:text>
						<xsl:value-of select="$REQUEST_DATA/FirstName"/>
						<xsl:if test="$REQUEST_DATA/MiddleName">
							<xsl:text>&#32;</xsl:text>
							<xsl:value-of select="$REQUEST_DATA/MiddleName"/>
							<xsl:if test="string-length($REQUEST_DATA/MiddleName)=1">
								<xsl:text>.</xsl:text>
							</xsl:if>
						</xsl:if>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label2" select="'Birth Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="$REQUEST_DATA/BirthDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Sex:'"/>
				<xsl:with-param name="value1">
					<xsl:choose>
						<xsl:when test="$REQUEST_DATA/Sex = 'M'">Male</xsl:when>
						<xsl:when test="$REQUEST_DATA/Sex = 'F'">Female</xsl:when>
						<xsl:otherwise><xsl:value-of select="$REQUEST_DATA/Sex"/></xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
				<xsl:with-param name="label2" select="'Race:'"/>
				<xsl:with-param name="value2">
					<xsl:choose>
						<xsl:when test="$REQUEST_DATA/Race = 'W'">White</xsl:when>
						<xsl:when test="$REQUEST_DATA/Race = 'B'">Black</xsl:when>
						<xsl:when test="$REQUEST_DATA/Race = 'A'">Asian or Pacific Islander</xsl:when>
						<xsl:when test="$REQUEST_DATA/Race = 'I'">American Indian or Alaskan Native</xsl:when>
						<xsl:when test="$REQUEST_DATA/Race = 'U'">Unknown</xsl:when>
						<xsl:otherwise><xsl:value-of select="$REQUEST_DATA/Race"/></xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Attn Line:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/Attention"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'State Ident Number:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/StateID"/>
				<xsl:with-param name="label2" select="'Purpose Code:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/PurposeCode"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Social Security Number:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/SSN"/>
				<xsl:with-param name="label2" select="'Miscellaneous Number:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/MiscNumber"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'DNR Number:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/dnrNumber"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'FBI Number:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/FBINumber"/>
				<xsl:with-param name="label2" select="'FPS Number:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/FPSNumber"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Partial Plate Number:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/DMVPartialPlateNumber"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Business Name:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/DMVTitleBusinessName"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Last Name:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/DMVTitleLastName"/>
				<xsl:with-param name="label2" select="'First Name:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/DMVTitleFirstName"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Serial / OAN:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/serialOAN"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Article Type:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/articleType"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Security Type:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/securityType"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Denomination:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/denomination"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Owner:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/owner"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Security SSN:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/securitySSN"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'OLN:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/DriversLicense"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'City:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/City"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'County:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/County"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Make:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/Make"/>
				<xsl:with-param name="label2" select="'Model:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/Model"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Model Year:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/ModelYear"/>
				<xsl:with-param name="label2" select="'Model Year Range Max:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/ModelYearRangeEnd"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Image Id:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/ImageId"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
			<!--  for Boat -->
				<xsl:with-param name="label1" select="'Registration Number:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/registrationNumber"/>
				<xsl:with-param name="label2" select="'Hull / OAN Number:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/hullNumber"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
			<!--  for Boat -->
				<xsl:with-param name="label1" select="'Boat Name:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/boatName"/>
				<xsl:with-param name="label2" select="'Boat Home Port:'"/>
				<xsl:with-param name="value2" select="$REQUEST_DATA/homePort"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Coast Guard Number:'"/>
				<xsl:with-param name="value1" select="$REQUEST_DATA/coastGuardNumber"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
</xsl:transform>