<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dmv/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:dmv="http://www.doj.state.wi.us/dles/cib/dmv/response/extension" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
    xmlns:xalan="http://xml.apache.org/xslt"
    exclude-result-prefixes="xsl xsi doj doj-ext dmv j xalan"
>
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../util.xsl"/>
	<xsl:param name="from"/>
	<xsl:param name="currentPageNo" select="'all'"/><!--  default to all for MRS; eBC will override -->
	<xsl:output method="html"
                version="4.01"
                encoding="UTF-8" 
                omit-xml-declaration="yes"
                doctype-public="-//W3C//DTD HTML 4.01//EN"
                doctype-system="http://www.w3.org/TR/html4/strict.dtd"
                indent="yes"
                media-type="text/html"
                xalan:indent-amount="2"/>

	<xsl:variable name="TOTAL_RECORDS">
		<xsl:choose>
			<xsl:when test="$from = 'mrs'">
				<!-- dmv:VehicleResponse elements may have been purged so use dmv:HitCountNumber for display in MRS -->
				<xsl:value-of select="/doj:DMVResponseDocument/doj:Result/dmv:HitCountNumber"/>
			</xsl:when>
			<xsl:otherwise>
				<!--  Use the number of dmv:VehicleResponse elements (most reliable) -->
				<xsl:value-of select="count(/doj:DMVResponseDocument/doj:Result/dmv:VehicleResponse)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="RECORDS_PER_PAGE">
		<xsl:choose>
			<xsl:when test="$currentPageNo = 'all'">
				<xsl:value-of select="$TOTAL_RECORDS"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="number(15)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="TOTAL_PAGES">
		<xsl:choose>
			<xsl:when test="$currentPageNo = 'all'">
				<xsl:value-of select="number(1)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="ceiling($TOTAL_RECORDS div $RECORDS_PER_PAGE)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="FIRST_RECORD_DISPLAYED">
		<xsl:choose>
			<xsl:when test="$currentPageNo = 'all'">
				<xsl:value-of select="number(1)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="($currentPageNo * $RECORDS_PER_PAGE) - $RECORDS_PER_PAGE + 1"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="LAST_RECORD_DISPLAYED">
		<xsl:choose>
			<xsl:when test="$TOTAL_RECORDS &lt; ($FIRST_RECORD_DISPLAYED + $RECORDS_PER_PAGE - 1)">
				<xsl:value-of select="$TOTAL_RECORDS"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$FIRST_RECORD_DISPLAYED + $RECORDS_PER_PAGE - 1"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="USE_PAGING">
		<xsl:choose>
			<xsl:when test="$from='ebc' and $currentPageNo != 'all' and $TOTAL_RECORDS &gt; $RECORDS_PER_PAGE">true</xsl:when>
			<xsl:otherwise>false</xsl:otherwise> 
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="OBO_ORI" select="/doj:DMVResponseDocument/doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID" />
	
	
	<xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension"/>
        <xsl:call-template name="html_body"/>
      </xsl:otherwise>
    </xsl:choose>
	</xsl:template>


	<xsl:template name="html_title">TIME - DMV Partial Plate</xsl:template>


	<xsl:template name="html_head_extension">
		<style type="text/css">
			th {
				vertical-align: bottom;
			}
			#dataserviceimage {
				float: right;
			}
			.filetype {
				white-space: nowrap;
			}
		</style>
		<script lang="text/javascript">
			var currentPgNo = "<xsl:value-of select="$currentPageNo"/>";
			
			addLoadEvent(onPageLoad);
						
			//window.onload = onPageLoad;  // dynamically set the body onLoad handler
			
			function onPageLoad() {
				var xmlLinkContainer = document.getElementById("xmlLinkContainer");
				var delimitedLinkContainer = document.getElementById("delimitedLinkContainer");
				var previousPageLinkContainer = document.getElementById("previousPageLinkContainer");
				var nextPageLinkContainer = document.getElementById("nextPageLinkContainer");
				var allRecordsLinkContainer = document.getElementById("allRecordsLinkContainer");
				
				if (xmlLinkContainer) {
					var url = window.location.pathname + getSearchStrWithoutPgParam() + "&amp;xml=true";
					xmlLinkContainer.innerHTML = "&lt;a href=\"" + url + "\" type=\"text/xml\"&gt;XML Download&lt;/a&gt;";
				}
				
				if (delimitedLinkContainer) {
					var url = "/secure/results/dmvdelimited?erid=" + extractERIDValue();
					delimitedLinkContainer.innerHTML = "&lt;a href=\"" + url + "\" type=\"text/plain\"&gt;Tab Delimited Download&lt;/a&gt;";
				}
				
				if (previousPageLinkContainer)
					previousPageLinkContainer.innerHTML = "&lt;a href=\"" + createPagingURL(-1) + "\"&gt;Previous&lt;/a&gt;";
				
				if (nextPageLinkContainer)
					nextPageLinkContainer.innerHTML = "&lt;a href=\"" + createPagingURL(1) + "\"&gt;Next&lt;/a&gt;";
				
				if (allRecordsLinkContainer)
					allRecordsLinkContainer.innerHTML = "&lt;a href=\"" + createPagingURL("all") + "\"&gt;All&lt;/a&gt;";
			}
			
			function createPagingURL(changeToPgParam) {
				// changeToPgParam should be either 1 (next page), -1 (prev page), or 'all'
				var searchStr = getSearchStrWithoutPgParam();
				var newPgValue;
				if (changeToPgParam == 1 || changeToPgParam == -1)
					newPgValue = parseInt(currentPgNo) + changeToPgParam;
				else
					newPgValue = "all";
				// Don't add the pg param if the link is to page 1 in order to preserve the visited link color
				if (newPgValue == "1")
					return window.location.pathname + getSearchStrWithoutPgParam();
				else
					return window.location.pathname + getSearchStrWithoutPgParam() + "&amp;pg=" + newPgValue;
			}
			
			function getSearchStrWithoutPgParam() {
				// return the search string with the optional pg param stripped from it
				var searchStr = window.location.search;
				if (searchStr.indexOf("&amp;pg=") != -1)
					// pg param was found and is not the first param
					searchStr = searchStr.replace(/\&amp;pg=[^\&amp;\0]*/, "");
				else if (/\?pg=/.test(searchStr))
					// pg param was found and it is the first (and assumed not the last)
					searchStr = searchStr.replace(/\?pg=.*\&amp;/, "?");
				return searchStr;
			}
			
			function extractERIDValue() {
				// Extract the erid param value from the current search string
				var searchStr = window.location.search;
				var results = searchStr.match(/((\?|\&amp;)erid=)([\d]+)/);
				// alert(results[0] + '\n' + results[1] + '\n' + results[2] + '\n' + results[3];
				//   results[0] = ?erid=1234
				//   results[1] = erid=
				//   results[2] = ?
				//   results[3] = 1234
				return results[3];  // just want the digits (erid value)
			}
		</script>
	</xsl:template>


	<xsl:template name="html_body">
		<img id="dataserviceimage" src="../../images/DOT.gif" alt="Wisconsin Department of Transportation"/>
		<h1 class="filetype">DMV Open Search</h1>
		
		<xsl:if test="doj:DMVResponseDocument/doj:Result/doj:ResultText">
			<div class="caveat">
				<xsl:value-of select="doj:DMVResponseDocument/doj:Result/doj:ResultText"/>
			</div>
		</xsl:if>
		
		<hr style="clear:both;"/>
		
		<img src="../../images/VehicleIcon.jpg" alt="Vehicle Image" style="float:left;"/>
		<div class="basiclabel" style="float:left;">
			<!-- Vehicles 1-25 of 200 -->
			<xsl:text>Vehicles&#32;</xsl:text>
			<xsl:value-of select="$FIRST_RECORD_DISPLAYED"/>
			<xsl:text>-</xsl:text>
			<xsl:value-of select="$LAST_RECORD_DISPLAYED"/>
			<span style="text-transform:lowercase;">&#160;of&#160;</span>
			<xsl:value-of select="$TOTAL_RECORDS"/>
		</div>
		<xsl:if test="$from = 'ebc'">
			<div id="xmlLinkContainer" style="float:right;"/><!-- Actual href will be created by onPageLoad() -->
			<br/>
			<div id="delimitedLinkContainer" style="float:right;"/><!-- Actual href will be created by onPageLoad() -->
		</xsl:if>
		<xsl:if test="$USE_PAGING='true'">
			<div style="clear:both; float:right; margin-top:20px;">
				Page <xsl:value-of select="$currentPageNo"/> of <xsl:value-of select="$TOTAL_PAGES"/>&#32;
				<xsl:if test="$currentPageNo != 1">
					<!-- Actual href will be created by onPageLoad() -->
					<span id="previousPageLinkContainer" style="margin-left:15px;"/>
				</xsl:if>
				<xsl:if test="$currentPageNo != $TOTAL_PAGES">
					<!-- Actual href will be created by onPageLoad() -->
					<span id="nextPageLinkContainer" style="margin-left:15px;"/>
				</xsl:if>
				<!-- Actual href will be created by onPageLoad() -->
				<span id="allRecordsLinkContainer" style="margin-left:15px;"/>
			</div>
		</xsl:if>
		
		<xsl:if test="doj:DMVResponseDocument/doj:Result/dmv:VehicleResponse">
			<table style="clear:both;">
				<tr class="detaillabel">
					<th></th>
					<th>Plate</th>
					<th>Plate<br/>Type</th>
					<th>Owner(s)/Lessee(s)</th>
					<th>City</th>
					<th>County<br/>Kept In</th>
					<th colspan="5">Vehicle</th>
				</tr>
				<xsl:apply-templates select="doj:DMVResponseDocument/doj:Result/dmv:VehicleResponse"/>
			</table>			
		</xsl:if>
	</xsl:template><!-- html_body -->


	<xsl:template match="doj:ResultText">
		<div class="resulttext">
			<h1 class="filetype"><xsl:value-of select="."/></h1>
		</div>
	</xsl:template><!-- doj:ResultText -->


	<xsl:template match="dmv:VehicleResponse">
		<xsl:if test="position() &gt;= $FIRST_RECORD_DISPLAYED and position() &lt;= $LAST_RECORD_DISPLAYED">
			<tr>
				<td class="detaillabel">
					<xsl:value-of select="position()"/>
				</td>
				<xsl:choose>
					<xsl:when test="dmv:VehicleRegistration">
						<td class="detailvalue">
							<xsl:apply-templates select="dmv:VehicleRegistration" mode="PlateList">
								<!-- Pass in the vehicle record number -->
								<xsl:with-param name="theRecordNo" select="position()"/>
							</xsl:apply-templates>
						</td>
						<td class="detailvalue">
							<xsl:apply-templates select="dmv:VehicleRegistration" mode="PlateTypeList"/>
						</td>
					</xsl:when>
					<xsl:otherwise>
						<td class="detailvalue">
						<!-- No plates for this vehicle; create a VIN Only hyperlink instead -->
						<xsl:if test="$from = 'ebc'">
							<xsl:variable name="VIN" select="j:VehicleID/j:ID" />
							<!-- Use the vehicle record number and VIN value combined to generate a unique form ID -->
							<form id="V{position()}V_{$VIN}" action="/secure/vehiclesearch/builddotrq.jsp" method="post" style="display:inline">
								<input name="vin" type="hidden" value="{$VIN}" />
								<xsl:if test="$OBO_ORI">
									<input name="ori" type="hidden" value="{$OBO_ORI}" />
								</xsl:if>
							</form>
							<a href="javascript:document.getElementById('V{position()}V_{$VIN}').submit();">VIN Only</a>
						</xsl:if>
						</td>
						<td class="detailvalue"></td><!-- Plate Type not applicable on VIN Only -->
					</xsl:otherwise>
				</xsl:choose>
				<xsl:apply-templates select="j:VehicleTitle"/>
				<td class="detailvalue">
					<xsl:apply-templates select="j:LocationCountyName" mode="TitleCase"/>
				</td>
				<td class="detailvalue">
					<xsl:value-of select="j:VehicleModelYearDate"/>
				</td>
				<td class="detailvalue">
					<xsl:apply-templates select="dmv:VehicleMakeCodeText" mode="TitleCase"/>
				</td>
				<td class="detailvalue">
					<xsl:value-of select="j:VehicleModelCodeText"/>
				</td>
				<td class="detailvalue">
					<xsl:value-of select="dmv:VehicleStyleCodeText"/>
				</td>
				<td class="detailvalue">
					<xsl:apply-templates select="j:VehicleColorPrimaryText" mode="TitleCase"/>
					<xsl:if test="j:VehicleColorPrimaryText and j:VehicleColorSecondaryText">
						<xsl:text>/</xsl:text>
						<xsl:apply-templates select="j:VehicleColorSecondaryText" mode="TitleCase"/>
					</xsl:if>
				</td>
			</tr>
		</xsl:if>
	</xsl:template><!-- dmv:VehicleResponse -->


	<xsl:template match="dmv:VehicleRegistration" mode="PlateList">
		<xsl:param name="theRecordNo" />
		<xsl:variable name="PLATE_NO" select="j:VehicleRegistrationPlateID/j:ID" />
		<xsl:choose>
			<xsl:when test="$from = 'ebc'">
				<!-- Use the vehicle record number and plate value combined to generate a unique form ID -->
				<form id="V{$theRecordNo}P_{$PLATE_NO}" action="/secure/vehiclesearch/builddotrq.jsp" method="post" style="display:inline">
					<input name="plateNumber" type="hidden" value="{$PLATE_NO}" />
					<xsl:if test="$OBO_ORI">
						<input name="ori" type="hidden" value="{$OBO_ORI}" />
					</xsl:if>
				</form>
				<a href="javascript:document.getElementById('V{$theRecordNo}P_{$PLATE_NO}').submit();">
					<xsl:value-of select="$PLATE_NO"/>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$PLATE_NO"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="position() != last()">
			<br/>
		</xsl:if>
	</xsl:template><!-- PlateList mode dmv:VehicleRegistration -->


	<xsl:template match="dmv:VehicleRegistration" mode="PlateTypeList">
		<xsl:value-of select="j:VehicleRegistrationPlateTypeText"/>
		<xsl:if test="position() != last()">
			<br/>
		</xsl:if>
	</xsl:template><!-- PlateTypeList mode dmv:VehicleRegistration -->


	<xsl:template match="j:VehicleTitle">
		<td class="detailvalue">
			<!-- For some reason the union doesn't work right when
			     used directly in an apply-templates or for-each
			     loop (second value doesn't display) but assigning 
			     the node sets to a variable first gets around
			     the problem. -->
			<xsl:variable name="ownersLeeses" select="j:TitleParty.Person/j:PersonName
								                    | j:TitleParty.Organization/j:OrganizationName"/>
			<xsl:for-each select="$ownersLeeses">
				<xsl:apply-templates select="." mode="Single"/>
				<xsl:if test="position() != last()">
					<xsl:text>,</xsl:text>
					<br/>
				</xsl:if>
			</xsl:for-each>
		</td>
		<td class="detailvalue">
			<!--  Same problem as above but descendant:: also gets around the problem -->
			<xsl:apply-templates select="descendant::j:LocationAddress/j:LocationCityName" mode="List"/>
		</td>
	</xsl:template><!-- j:VehicleTitle -->


	<xsl:template match="j:LocationCityName" mode="List">
		<xsl:apply-templates select="." mode="TitleCase"/>
		<xsl:if test="position() != last()">
			<xsl:text>,</xsl:text>
			<br/>
		</xsl:if>
	</xsl:template><!-- List mode j:LocationCityName -->


	<xsl:template match="j:PersonName" mode="Single">
		<xsl:apply-templates select="j:PersonGivenName" mode="TitleCase"/>
		<xsl:if test="j:PersonMiddleName">
			<xsl:text>&#32;</xsl:text>
			<xsl:apply-templates select="j:PersonMiddleName" mode="TitleCase"/>
			<xsl:if test="string-length(j:PersonMiddleName)=1">
				<xsl:text>.</xsl:text>
			</xsl:if>
		</xsl:if>
		<xsl:text>&#32;</xsl:text>
		<xsl:apply-templates select="j:PersonSurName" mode="TitleCase"/>
		<xsl:if test="j:PersonSuffixName">
			<xsl:text>&#32;</xsl:text>
			<xsl:apply-templates select="j:PersonSuffixName" mode="TitleCase"/>
		</xsl:if>
	</xsl:template><!-- Single mode j:PersonName -->
	
	
	<xsl:template match="j:OrganizationName" mode="Single">
		<xsl:apply-templates select="." mode="TitleCase"/>
	</xsl:template><!-- Single mode j:OrganizationName -->


</xsl:transform>