<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:dnr-ext="http://www.doj.state.wi.us/dles/cib/dnr/response/extension" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dnr/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	
	
	<xsl:template name="html_head_extension">
		<style type="text/css">
			#dataserviceimage {
				float: right;
			}
			
			#recorddetails {
				clear: both;
			}
			
			h2.basiclabel {
				font-size: large;
				margin-bottom: 0px;
			}
			
			h3.detaillabel {
				font-weight: normal;
				margin-bottom: 0px;
			}
			
			.pageref {
				padding-right: 10%;
			}
			
			.label1, .label2 {
				padding-right: 2%;
			}
			
			.subjecttitle {
				text-transform: none; /* Override the text-transform setting inherited from external stylesheets */
			}
			
			.newsection {
				margin-top: 15px;
				margin-bottom: 15px;
			}
			
			.filetype {
				float: none; /* Override the float setting inherited from external stylesheets */
			}
		</style>
	</xsl:template>
	
	
	<xsl:template name="dnrLogo">
		<table width="100%">
			<tr>
				<td align="right"><img src="../../images/DNR.gif" alt="DNR Logo" width="60" height="30" /></td>
			</tr>
		</table>
	</xsl:template>
	
	
	<xsl:template match="j:PropertyOwner.Person">
		<xsl:if test="j:PersonName/j:PersonFullName">
			<tr>
				<td><xsl:value-of select="j:PersonName/j:PersonFullName" /></td>
			</tr>
		</xsl:if>
		<xsl:if test="j:PersonBirthDate">
			<tr>
				<td>
					DOB: <xsl:apply-templates select="j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY" />
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText">
			<tr>
				<td>
					<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText" />
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="j:Residence/j:LocationAddress/j:LocationCityName | 
					  j:Residence/j:LocationAddress/j:LocationStateName | 
					  j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID">
			<tr>
				<td>
					<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationCityName" />
					<xsl:if test="j:Residence/j:LocationAddress/j:LocationCityName and 
								  j:Residence/j:LocationAddress/j:LocationStateName">
						<xsl:text>, </xsl:text>
					</xsl:if>
					<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationStateName" />
					<xsl:text> </xsl:text>
					<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID" />
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="j:Residence/j:LocationAddress/j:LocationCountyName">
			<tr>
				<td>County: <xsl:value-of select="j:Residence/j:LocationAddress/j:LocationCountyName" /></td>
			</tr>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Converts length in inch to feet/inch -->
	<xsl:template match="*" mode="LengthConversion">
		<xsl:if test=". != ''">
			<xsl:variable name="feetPart">
				<xsl:value-of select="floor(. div 12)" />
			</xsl:variable>
			<xsl:variable name="inchPart">
				<xsl:value-of select=". mod 12" />
			</xsl:variable>
			
			<xsl:value-of select="$feetPart" />
			<xsl:text>' </xsl:text>
			<xsl:value-of select="$inchPart" />
			<xsl:text>"</xsl:text>
		</xsl:if>
	</xsl:template>
	
	<!-- Displays owner information on a single line -->
	<xsl:template match="j:Residence" mode="additionalowner">
		<xsl:text> </xsl:text>
		<xsl:if test="j:LocationAddress/j:LocationStreet/j:StreetFullText !=''">
			<xsl:value-of select="j:LocationAddress/j:LocationStreet/j:StreetFullText"/>
			<xsl:text> </xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationCityName !=''">
			<xsl:value-of select="j:LocationAddress/j:LocationCityName"/>
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationStateName !=''">
			<xsl:value-of select="j:LocationAddress/j:LocationStateName"/>
			<xsl:text> </xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationPostalCodeID/j:ID !=''">
			<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeID/j:ID"/>
		</xsl:if>
	</xsl:template>
	
</xsl:transform>