<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:dnr-ext="http://www.doj.state.wi.us/dles/cib/dnr/response/extension" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dnr/response" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
	xmlns:xalan="http://xml.apache.org/xslt" 
	exclude-result-prefixes="xsl xsi dnr-ext doj j xalan">
	
	<xsl:import href="../common.xsl" />
	<xsl:import href="dnr_common.xsl" />
	<xsl:import href="../util.xsl" />
	
	<xsl:param name="from" />
	<xsl:param name="responseId">
		<xsl:value-of select="doj:DNRResponseDocument/@doj-ext:responseID" />
	</xsl:param>
	
	<xsl:output method="html" 
				version="4.01" 
				encoding="UTF-8" 
				omit-xml-declaration="yes" 
				doctype-public="-//W3C//DTD HTML 4.01//EN" 
				doctype-system="http://www.w3.org/TR/html4/strict.dtd" 
				indent="yes" 
				media-type="text/html" 
				xalan:indent-amount="2" />
	
	
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$from='ebc'">
				<xsl:call-template name="html_main" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="html_head_extension" />
				<xsl:call-template name="html_body" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="html_title">
		TIME - DNR Snowmobile Registration
	</xsl:template>
	
	
	<xsl:template name="html_body">
		<xsl:call-template name="dnrLogo" />
		<xsl:call-template name="snowmobileLogo" />
		<hr />
		<!-- Not all of the following will be applicable on a single response -->
		<xsl:apply-templates
			select="doj:DNRResponseDocument/doj:Result/doj:ResultText" />
		<!-- Hit response -->
		<xsl:apply-templates
			select="doj:DNRResponseDocument/doj:Result/doj:SnowmobileResponse/doj:InquiryResult/dnr-ext:Snowmobile" />
	</xsl:template>
	
	
	<xsl:template name="snowmobileLogo">
		<h1>
			<img src="../../images/snowmobile.jpg" alt="DNR Snowmobile" />
			<xsl:text>&#160;&#160;</xsl:text>
			<xsl:text>DNR Snowmobile Registration</xsl:text>
		</h1>
	</xsl:template>
	
	
	<xsl:template match="doj:ResultText | dnr-ext:ResponseText">
		<div class="resulttext">
			<h1 class="filetype">
				<xsl:value-of select="." />
			</h1>
		</div>
	</xsl:template>
	
	
	<xsl:template match="dnr-ext:Snowmobile">
		<table class="detailvalue" cellspacing="0">
			<tr>
				<td colspan="2">
					<span class="propertyinfo">
						<xsl:text>Status: </xsl:text>
						<xsl:value-of select="dnr-ext:VehicleRegistration/j:VehicleRegistrationStatus/j:StatusText" />
					</span>
				</td>
			</tr>
			<tr>
				<td colspan="2">
					<span class="propertyinfo">
						<xsl:value-of select="dnr-ext:PropertyPhysicalDetails/j:PropertyYearDate" />
						<xsl:text> </xsl:text>
						<xsl:value-of select="dnr-ext:PropertyPhysicalDetails/j:PropertyMakeName" />
					</span>
				</td>
			</tr>
			<xsl:if test="j:PropertyAssignedIDDetails/j:PropertySerialID/j:ID">
				<tr>
					<td>
						<span class="propertyinfo">
							<xsl:text>Serial #: </xsl:text>
							<xsl:value-of select="j:PropertyAssignedIDDetails/j:PropertySerialID/j:ID" />
						</span>
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="j:PropertyOwner.Person[position()=1]/j:PersonName/j:PersonFullName">
				<tr>
					<td>
						<span class="propertyinfo">
							<xsl:text>Owner(s) Name#: </xsl:text>
							<xsl:value-of select="j:PropertyOwner.Person[position()=1]/j:PersonName/j:PersonFullName" />
						</span>
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="dnr-ext:VehicleRegistration/j:RegistrationID/j:ID">
				<tr>
					<td><br /></td>
				</tr>
				<tr>
					<td>
						<span class="propertyinfo">
							<xsl:text>Registration#: </xsl:text>
							<xsl:value-of select="dnr-ext:VehicleRegistration/j:RegistrationID/j:ID" />
						</span>
					</td>
				</tr>
				<tr>
					<td>
						<span class="propertyinfo">
							<xsl:text>Expiration: </xsl:text>
							<xsl:value-of select="dnr-ext:VehicleRegistration/dnr-ext:DecalID[position()=1]/dnr-ext:IDExpirationYear" />
						</span>
					</td>
				</tr>
			</xsl:if>
		</table>
		
		<table class="detailvalue" cellspacing="0">
			<tr>
				<td><br /></td>
			</tr>
			<tr>
				<td>
					<div class="detaillabel" style="margin-top:15px;clear:both;">Owner(s):</div>
				</td>
			</tr>
			<xsl:apply-templates select="j:PropertyOwner.Person[position()=1]" />
			<xsl:if test="j:PropertyOwner.Person[position()=2]">
				<tr>
					<td><br /></td>
				</tr>
				<xsl:apply-templates select="j:PropertyOwner.Person[position()=2]" />
			</xsl:if>
			<tr>
				<td><br/></td>
			</tr>
		</table>
		
		<table class="detailvalue" cellspacing="0">
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">Registration:</div>
				</td>
			</tr>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Registration Number:'"/>
				<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/j:RegistrationID/j:ID" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Received Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates
						select="dnr-ext:VehicleRegistration/dnr-ext:ApplicationReceivedDate" mode="FormatFullDateAsMMDDYYYY" />
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Status:'"/>
				<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/j:VehicleRegistrationStatus/j:StatusText" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'LE Status:'"/>
				<xsl:with-param name="value2" select="j:PropertyStatus/j:StatusText" />
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<tr>
				<td colspan="4"><br/></td>
			</tr>
			
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">Decal(s):</div>
				</td>
			</tr>
			<xsl:for-each select="dnr-ext:VehicleRegistration/dnr-ext:DecalID">
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Decal number:'"/>
					<xsl:with-param name="value1" select="j:ID" />
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
					<xsl:with-param name="label2" select="'Type:'"/>
					<xsl:with-param name="value2" select="j:IDTypeText" />
					<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
				</xsl:call-template>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Expiration Year:'"/>
					<xsl:with-param name="value1" select="dnr-ext:IDExpirationYear" />
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
					<xsl:with-param name="label2" select="''"/>
					<xsl:with-param name="value2" select="''" />
					<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
				</xsl:call-template>
				<tr>
					<td colspan="4"><br/></td>
				</tr>
			</xsl:for-each>
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">Record Details:</div>
				</td>
			</tr>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Make:'"/>
				<xsl:with-param name="value1" select="dnr-ext:PropertyPhysicalDetails/j:PropertyMakeName" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Horse Power:'"/>
				<xsl:with-param name="value2" select="dnr-ext:VehicleEngine/j:VehicleEngineHorsepowerQuantity" />
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Model Year:'"/>
				<xsl:with-param name="value1" select="dnr-ext:PropertyPhysicalDetails/j:PropertyYearDate" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Engine Disp(CC):'"/>
				<xsl:with-param name="value2" select="dnr-ext:VehicleEngine/j:VehicleEngineDisplacementMeasure" />
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Serial number:'"/>
				<xsl:with-param name="value1" select="j:PropertyAssignedIDDetails/j:PropertySerialID/j:ID" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'County Kept:'"/>
				<xsl:with-param name="value2" select="dnr-ext:VehicleRegistration/dnr-ext:VehicleLocationCountyName" />
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Purchase Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="dnr-ext:PurchaseDateTime/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY" />
					<xsl:if test="dnr-ext:PurchaseDateTime/j:ActivityDate | dnr-ext:PurchaseDateTime/j:ActivityTime">
						<xsl:text>&#32;</xsl:text>
					</xsl:if>
					<xsl:value-of select="dnr-ext:PurchaseDateTime/j:ActivityTime" />
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="''"/>
				<xsl:with-param name="value2" select="''" />
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<tr>
				<td><br/></td>
			</tr>
		</table>
	</xsl:template>
	
</xsl:transform>