<?xml version="1.0"?>
<xsl:transform version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xmlns:doj="http://www.doj.state.wi.us/dles/cib/nlets/response"
  xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
  xmlns:j="http://www.it.ojp.gov/jxdm/3.0"
  xmlns:j2="http://www.it.ojp.gov/jxdm/3.0.2"
  xmlns:n="http://www.nlets.org"
  xmlns:xalan="http://xml.apache.org/xslt"
  exclude-result-prefixes="xsl xsi doj doj-ext j j2 n xalan">
  <xsl:import href="../common.xsl" />
  <xsl:import href="../util.xsl" />
  <xsl:param name="from" />
  <xsl:param name="nightMode" />
  <xsl:param name="responseId">
    <xsl:value-of
      select="doj:NLETSResponseDocument/@doj-ext:responseID" />
  </xsl:param>
  <xsl:output method="html" version="4.01" encoding="UTF-8"
    omit-xml-declaration="yes"
    doctype-public="-//W3C//DTD HTML 4.01//EN"
    doctype-system="http://www.w3.org/TR/html4/strict.dtd" indent="yes"
    media-type="text/html" xalan:indent-amount="2" />
  
  
  <xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension" />
        <xsl:call-template name="html_body" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template name="html_title">TIME - Driver</xsl:template>
  
  
  <xsl:template name="html_head_extension">
    <style type="text/css">
      #dataserviceimage
      {
        float: right;
      }
      .filetype
      {
         float: none; /* Override the float setting inherited from external stylesheets */
      }
      .licensetypetitle
      {
        text-transform: none; /* Override inherited uppercase setting */
      }
      .newsection
      {
         margin-top: 15px;
      }
      .savexmlbuttonimage
      {
        background-color: transparent;
        border-style: none;
        cursor: pointer;
        height: 24px;
        width: 110px;
      }
      img.driverimage
      {
        float: right;
        height: 150px;
        width: 150px;
      }
      img.pagerefimage
      {
        border: none;
        float: right;
        padding-left: 15px;
        padding-right: 25px;
      }
      p.certifiedstatus
      {
        color: red;
        margin-bottom: 10px;
        margin-top: 10px;
        vertical-align: text-top;
      }
      td.labelEvents
      {
        width: 220px;
      }
      td.labelPermit
      {
        width: 120px;
      }
      td.labelPerson
      {
        width: 120px;
      }
      td.labelPersonDataMedicalHistory
      {
        width: 130px;
      }
      td.labelPersonDataOrganDonor
      {
        width: 110px;
      }
      td.labelPersonDataTSA
      {
        width: 220px;
      }
      td.labelRecordDetails
      {
        width: 330px;
      }
      td.labelResidence
      {
        width: 170px;
      }
      <xsl:choose>
        <xsl:when test="$nightMode='true'">
          .caveat
          {
            color: teal; /* Override the color inherited from external stylesheets */
          }
          .textBlackSmall
          {
            color: teal;
            font-size: 98%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
          }
          .textBlueSmall
          {
            color: blue;
            font-size: 98%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
          }
          .textTealMedium
          {
            color: teal;
            font-size: 98%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
            font-weight: bold;
          }
          .textTealLarge
          {
            color: teal;
            font-size: 125%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
            font-weight: bold;
          }
          .textTealSmall
          {
            color: teal;
            font-size: 98%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
          }
        </xsl:when>
        <xsl:otherwise>
          .caveat
          {
            color: teal; /* Override the color inherited from external stylesheets */
          }
          .textBlackSmall
          {
            color: black;
            font-size: 98%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
          }
          .textBlueSmall
          {
            color: blue;
            font-size: 98%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
          }
          .textTealMedium
          {
            color: teal;
            font-size: 98%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
            font-weight: bold;
          }
          .textTealLarge
          {
            color: teal;
            font-size: 125%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
            font-weight: bold;
          }
          .textTealSmall
          {
            color: teal;
            font-size: 98%;
            font-family: "bookman old style", georgia, "times new roman", times, serif;
          }
        </xsl:otherwise>
      </xsl:choose>
    </style>
    <script language="JavaScript">
      function copyxml() {
        document.form1.savexmltext1.value = document.form2.savexmltext2.value;
      }
    </script>
  </xsl:template>
  
  
  <xsl:template name="html_body">
    <img id="dataserviceimage" src="../../images/nlets.gif" alt="NLETS" />
    <!-- Format header information -->
    <xsl:variable name="HEADER_INFORMATION">
      <xsl:if test="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseHeader/j:DocumentSource.Organization/j:OrganizationORIID/j:ID">
        <xsl:value-of select="substring(doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseHeader/j:DocumentSource.Organization/j:OrganizationORIID/j:ID,1,2)" />
        <xsl:text> </xsl:text>
      </xsl:if>
      <xsl:text>Driver Record</xsl:text>
    </xsl:variable>
    <!-- Not all of the following will be applicable on a single response -->
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/doj:ResultText">
        <xsl:with-param name="headerInformation" select="$HEADER_INFORMATION" />
    </xsl:apply-templates>
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:ResponseText">
          <xsl:with-param name="headerInformation" select="$HEADER_INFORMATION" />
    </xsl:apply-templates>
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:DriverStatus/n:StandardResponse">
          <xsl:with-param name="headerInformation" select="$HEADER_INFORMATION" />
    </xsl:apply-templates>
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:DriverHistory/n:StandardResponse">
          <xsl:with-param name="headerInformation" select="$HEADER_INFORMATION" />
    </xsl:apply-templates>
  </xsl:template>
  
  
  <xsl:template match="doj:ResultText | n:ResponseText">
    <xsl:param name="headerInformation" />
    <xsl:if test="position()=1">
      <table>
        <h2 class="filetype"><xsl:value-of select="$headerInformation" /></h2>
        <tr>
          <td>
            <form name="form1" method="post" action="/servlet/SaveXMLResponseServlet">
              <textarea name="saveresponsetext1" id="saveresponsetext1" style="display:none" rows="1" cols="1">
                <xsl:text>DL_NLETS</xsl:text>
              </textarea>
              <textarea name="savexmltext1" id="savexmltext1" style="display:none" rows="1" cols="1"/>
              <table cellpadding="0" cellspacing="0" align="right" border="0">
                <tr>
                  <td height="24" valign="bottom" align="right">
                    <button onclick="copyxml();" name="savexmlbutton1" class="savexmlbuttonimage" type="submit">
                      <u><img width="110" height="24" alt="Save XML File" src="../../images/savexmlfileicon.gif"/></u>
                    </button>
                  </td>
                </tr>
              </table>
            </form>
          </td>
        </tr>
        <tr>
          <td><hr/></td>
        </tr>
      </table>
    </xsl:if>
    <table>
      <tr>
        <td>
          <table>
            <tr>
              <td align="left" class="textBlackSmall">
                <xsl:value-of select="." />
              </td>
            </tr>
          </table>
          <xsl:if test="../j2:PersonDigitalImage">
            <table>
              <tr>
                <td width="80%" />
                <td align="left" width="20%">
                  <xsl:apply-templates select="../j2:PersonDigitalImage" />
                </td>
              </tr>
            </table>
          </xsl:if>
        </td>
      </tr>
    </table>
  </xsl:template>
  
  
  <xsl:template match="j2:PersonName" mode="nlets">
    <xsl:apply-templates select="j2:PersonSurName" mode="TitleCase"/>
    <xsl:for-each select="j2:PersonSuffixName">
      <xsl:text> </xsl:text>
      <xsl:apply-templates select="." mode="TitleCase"/>
    </xsl:for-each>
    <!-- In 2009V01 release it is possible that there may not be a first name
    	The dot-drv:CardSurfaceName is put in j2:PersonSurName  -->
    <xsl:if test="j2:PersonGivenName">
      <xsl:text>; </xsl:text>
      <xsl:apply-templates select="j2:PersonGivenName" mode="TitleCase"/>
    </xsl:if>
    <xsl:for-each select="j2:PersonMiddleName">
      <xsl:choose>
        <xsl:when test="position() = 1">
          <xsl:text>, </xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text> </xsl:text>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="." mode="TitleCase"/>
      <xsl:if test="string-length(.)=1">
        <xsl:text>.</xsl:text>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
  
  
  <xsl:template match="n:DriverRestriction">
    <xsl:if test="position() > 1"><br/></xsl:if>
    <xsl:for-each select="n:DrivingRestrictionCodeText">
      <xsl:if test="position() > 1">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="TitleCase"/>
    </xsl:for-each>
    <xsl:if test="n:DrivingRestrictionCodeText and j2:DrivingRestrictionText">
      <xsl:text> - </xsl:text>
    </xsl:if>
    <xsl:text> </xsl:text>
    <xsl:for-each select="j2:DrivingRestrictionText">
      <xsl:if test="position() > 1">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="TitleCase"/>
    </xsl:for-each>
    <xsl:text> </xsl:text>
    <xsl:if test="j2:DrivingRestrictionDescriptionText">
      <xsl:text>(</xsl:text>
      <xsl:for-each select="j2:DrivingRestrictionDescriptionText">
        <xsl:if test="position() > 1">
          <xsl:text>, </xsl:text>
        </xsl:if>
        <xsl:apply-templates select="." mode="TitleCase"/>
      </xsl:for-each>
      <xsl:text>)</xsl:text>
    </xsl:if>
    <xsl:text> </xsl:text>
    <xsl:if test="j2:DrivingRestrictionEndDate">
      <xsl:text>End Date: </xsl:text>
      <xsl:for-each select="j2:DrivingRestrictionEndDate">
        <xsl:if test="position() > 1">
          <xsl:text>, </xsl:text>
        </xsl:if>
        <xsl:call-template name="dateFormat">
          <xsl:with-param name="date" select="."/>
        </xsl:call-template>
      </xsl:for-each>
    </xsl:if>
  </xsl:template>
  
  
  <!-- ############################################################ -->
  <!-- Starting point for displaying a driver record "HIT" response -->
  <!-- ############################################################ -->
  <xsl:template match="n:StandardResponse">
    <xsl:param name="headerInformation" />
    <xsl:variable name="show_header">
      <xsl:choose>
        <xsl:when test="/doj:NLETSResponseDocument/doj:Result/doj:ResultText 
                       or /doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:ResponseText">
          <xsl:text>false</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>true</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:if test="$show_header='true'">
    <table>
      <h2 class="filetype">
        <xsl:value-of select="$headerInformation" />
      </h2>
      <tr>
        <td>
        <form name="form1" method="post" action="/servlet/SaveXMLResponseServlet">
          <textarea name="saveresponsetext1" id="saveresponsetext1" style="display:none" rows="1" cols="1">
            <xsl:text>DL_</xsl:text>
            <xsl:value-of select="n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationID.Detailed/j2:ID" />
          </textarea>
          <textarea name="savexmltext1" id="savexmltext1" style="display:none" rows="1" cols="1"/>
          <table cellpadding="0" cellspacing="0" align="right" border="0">
            <tr>
              <td height="24" valign="bottom" align="right">
                <button onclick="copyxml();" name="savexmlbutton1" class="savexmlbuttonimage" type="submit">
                  <u><img width="110" height="24" alt="Save XML File" src="../../images/savexmlfileicon.gif"/></u>
                </button>
              </td>
            </tr>
          </table>
        </form>
        </td>
      </tr>
      <tr>
        <td><hr/></td>
      </tr>
    </table>
    </xsl:if>
    <table>
      <tr>
        <xsl:variable name="width">
          <xsl:choose>
            <xsl:when test="j2:Person/j2:PersonBiometricDetails/j2:PersonDigitalImage">
              <xsl:text>width60percent</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>width80percent</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <td class="{$width}">
        
    <!-- Driver Name -->
    <span class="textTealLarge">
      <xsl:for-each select="j2:Person/j2:PersonName">
        <p/>
        <xsl:apply-templates select="." mode="nlets" />
      </xsl:for-each>
      <br/>
      <br/>
      <xsl:text>Drivers License or ID Card #: </xsl:text>
      <xsl:value-of select="n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationID.Detailed/j2:ID"/>
      <xsl:text> </xsl:text>
      <xsl:for-each select="n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationID.Detailed/j2:DrivingJurisdictionAuthorityCode.ncicLSTA">
        <xsl:if test="position() > 1">
          <xsl:text>, </xsl:text>
        </xsl:if>
        <xsl:value-of select="."/>
      </xsl:for-each>
      <xsl:for-each select="j2:Person/j2:PersonAssignedIDDetails/j2:PersonSSNID/j2:ID">
        <xsl:choose>
          <xsl:when test="position() = 1">
            <p/>
            <xsl:text>Social Security #: </xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>, </xsl:text>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="ssnFormat">
          <xsl:with-param name="ssn" select="."/>
        </xsl:call-template>
      </xsl:for-each>
      <xsl:for-each select="j2:Person/j2:PersonAssignedIDDetails/j2:PersonOtherID/j2:ID">
        <xsl:choose>
          <xsl:when test="position() = 1">
            <p/>
            <xsl:text>Other ID #: </xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>, </xsl:text>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="."/>
      </xsl:for-each>
      <p/>
      <xsl:if test="n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationExpirationDate">
        <table cellspacing="0" cellpadding="0">
          <tr>
            <td class="labelPerson">
              Expiration:
            </td>
            <td>
              <xsl:call-template name="dateFormat">
                <xsl:with-param name="date" select="n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationExpirationDate"/>
              </xsl:call-template>
            </td>
          </tr>
        </table>
      </xsl:if>
      <xsl:if test="n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationIssueDate">
        <table cellspacing="0" cellpadding="0">
          <tr>
            <td class="labelPerson">
              Issue Date:
            </td>
            <td>
              <xsl:call-template name="dateFormat">
                <xsl:with-param name="date" select="n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationIssueDate"/>
              </xsl:call-template>
            </td>
          </tr>
        </table>
      </xsl:if>
    </span>
    <p/>
    
    <span class="textTealMedium">
      <xsl:if test="n:DriverLicenseDetails/n:DriverAuthorizationDetails/n:DriverRestriction">
        <table cellspacing="0" cellpadding="0">
          <tr>
            <td class="labelPerson">
              Restrictions:
            </td>
            <td>
              <xsl:apply-templates select="n:DriverLicenseDetails/n:DriverAuthorizationDetails/n:DriverRestriction"/>
            </td>
          </tr>
        </table>
      </xsl:if>
      <xsl:if test="n:DriverLicenseDetails/n:DriverAuthorizationDetails/n:DrivingEndorsementCodeText 
                    or n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationEndorsementText">
        <table cellspacing="0" cellpadding="0">
          <tr>
            <td class="labelPerson">
              Endorsements:
            </td>
            <td>
              <xsl:for-each select="n:DriverLicenseDetails/n:DriverAuthorizationDetails/n:DrivingEndorsementCodeText">
                <xsl:if test="position() > 1">
                  <br/>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
                <xsl:if test="./@j2:commentText">
                  <xsl:text> - </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
              </xsl:for-each>
              <xsl:for-each select="n:DriverLicenseDetails/n:DriverAuthorizationDetails/j2:DriverAuthorizationEndorsementText">
                <xsl:choose>
                  <xsl:when test="../n:DrivingEndorsementCodeText">
                    <br/>
                  </xsl:when>
                  <xsl:when test="position() > 1">
                    <br/>
                  </xsl:when>
                </xsl:choose>
                <xsl:apply-templates select="." mode="TitleCase"/>
                <xsl:if test="./@j2:commentText">
                  <xsl:text> - </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
              </xsl:for-each>
            </td>
          </tr>
        </table>
      </xsl:if>
      <br/>
      <xsl:if test="n:DriverLicenseDetails/j2:DriverLicensePermitQuantity">
        Number of Driver Permits:
        <xsl:value-of select="n:DriverLicenseDetails/j2:DriverLicensePermitQuantity"/>
      </xsl:if>
      <xsl:if test="n:DriverLicenseDetails/j2:DriverLicenseCommercialClassCode 
                    or n:DriverLicenseDetails/j2:DriverLicenseCommercialStatusText">
        <br/>
        <br/>
        <span class="detaillabel">
          Commercial:
        </span>
        <xsl:for-each select="n:DriverLicenseDetails/j2:DriverLicenseCommercialClassCode">
          <br/>
          <xsl:apply-templates select="." mode="TitleCase"/>
          <xsl:if test="./@j2:commentText">
            <xsl:text> - </xsl:text>
            <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
          </xsl:if>
        </xsl:for-each>
        <xsl:if test="n:DriverLicenseDetails/j2:DriverLicenseCommercialStatusText">
          <br/>
          <xsl:apply-templates select="n:DriverLicenseDetails/j2:DriverLicenseCommercialStatusText" mode="TitleCase"/>
          <xsl:if test="n:DriverLicenseDetails/j2:DriverLicenseCommercialStatusText/@j2:commentText">
            <xsl:text> - </xsl:text>
            <xsl:apply-templates select="n:DriverLicenseDetails/j2:DriverLicenseCommercialStatusText/@j2:commentText" mode="TitleCase"/>
          </xsl:if>
        </xsl:if>
      </xsl:if>
      <xsl:if test="n:DriverLicenseDetails/j2:DriverLicenseNonCommercialStatusText 
                    or n:DriverLicenseDetails/n:DrivingNonCommercialClassCodeText 
                    or n:DriverLicenseDetails/j2:DriverLicenseNonCommercialClassText">
        <br/>
        <br/>
        <span class="detaillabel">
          Non-Commercial:
        </span>
        <xsl:for-each select="n:DriverLicenseDetails/n:DrivingNonCommercialClassCodeText">
          <br/>
          <xsl:apply-templates select="." mode="TitleCase"/>
          <xsl:if test="./@j2:commentText">
            <xsl:text> - </xsl:text>
            <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
          </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="n:DriverLicenseDetails/j2:DriverLicenseNonCommercialStatusText">
          <br/>
          <xsl:apply-templates select="." mode="TitleCase"/>
          <xsl:if test="./@j2:commentText">
            <xsl:text> - </xsl:text>
            <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
          </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="n:DriverLicenseDetails/j2:DriverLicenseNonCommercialClassText">
          <br/>
          <xsl:apply-templates select="." mode="TitleCase"/>
          <xsl:if test="./@j2:commentText">
            <xsl:text> - </xsl:text>
            <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
          </xsl:if>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="n:DriverLicenseDetails/n:DriverLicensePermitDetails">
        <br/>
        <xsl:for-each select="n:DriverLicenseDetails/n:DriverLicensePermitDetails">
          <br/>
          <span class="detaillabel">
            Permit:
          </span>
          <table cellspacing="0" cellpadding="0">
            <xsl:if test="j2:DriverLicensePermitStatusText">
              <tr>
                <td class="labelPermit">
                  Status:
                </td>
                <td>
                  <xsl:apply-templates select="j2:DriverLicensePermitStatusText" mode="TitleCase"/>
                  <xsl:if test="j2:DriverLicensePermitStatusText/@j2:commentText">
                    <xsl:text> - </xsl:text>
                    <xsl:apply-templates select="j2:DriverLicensePermitStatusText/@j2:commentText" mode="TitleCase"/>
                  </xsl:if>
                </td>
              </tr>
            </xsl:if>
            <xsl:if test="j2:DriverAuthorizationExpirationDate">
              <tr>
                <td class="labelPermit">
                  Expiration:
                </td>
                <td>
                  <xsl:call-template name="dateFormat">
                    <xsl:with-param name="date" select="j2:DriverAuthorizationExpirationDate"/>
                  </xsl:call-template>
                </td>
              </tr>
            </xsl:if>
            <xsl:if test="j2:DriverAuthorizationIssueDate">
              <tr>
                <td class="labelPermit">
                  Issue Date:
                </td>
                <td>
                  <xsl:call-template name="dateFormat">
                    <xsl:with-param name="date" select="j2:DriverAuthorizationIssueDate"/>
                  </xsl:call-template>
                </td>
              </tr>
            </xsl:if>
            <xsl:if test="j2:DriverLicensePermitClassificationText">
              <tr>
                <td class="labelPermit">
                  Type:
                </td>
                <td>
                  <xsl:apply-templates select="j2:DriverLicensePermitClassificationText" mode="TitleCase"/>
                  <xsl:if test="j2:DriverLicensePermitClassificationText/@j2:commentText">
                    <xsl:text> - </xsl:text>
                    <xsl:apply-templates select="j2:DriverLicensePermitClassificationText/@j2:commentText" mode="TitleCase"/>
                  </xsl:if>
                </td>
              </tr>
            </xsl:if>
            <xsl:if test="n:DrivingPermitClassCodeText">
              <tr>
                <td class="labelPermit">
                  Type Code:
                </td>
                <td>
                  <xsl:apply-templates select="n:DrivingPermitClassCodeText" mode="TitleCase"/>
                  <xsl:if test="n:DrivingPermitClassCodeText/@j2:commentText">
                    <xsl:text> - </xsl:text>
                    <xsl:apply-templates select="n:DrivingPermitClassCodeText/@j2:commentText" mode="TitleCase"/>
                  </xsl:if>
                </td>
              </tr>
            </xsl:if>
            <xsl:if test="j2:DriverAuthorizationEndorsementText or n:DrivingEndorsementCodeText">
              <tr>
                <td class="labelPermit">
                  Endorsement:
                </td>
                <td>
                  <xsl:for-each select="n:DrivingEndorsementCodeText">
                    <xsl:if test="position() > 1">
                      <br/>
                    </xsl:if>
                    <xsl:apply-templates select="." mode="TitleCase"/>
                    <xsl:if test="./@j2:commentText">
                      <xsl:text> - </xsl:text>
                      <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
                    </xsl:if>
                  </xsl:for-each>
                  <xsl:if test="n:DrivingEndorsementCodeText">
                    <br/>
                  </xsl:if>
                  <xsl:for-each select="j2:DriverAuthorizationEndorsementText">
                    <xsl:if test="position() > 1">
                      <br/>
                    </xsl:if>
                    <xsl:apply-templates select="." mode="TitleCase"/>
                    <xsl:if test="./@j2:commentText">
                      <xsl:text> - </xsl:text>
                      <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
                    </xsl:if>
                  </xsl:for-each>
                </td>
              </tr>
            </xsl:if>
            <xsl:if test="n:DriverRestriction">
              <tr>
                <td class="labelPermit">
                  Restriction:
                </td>
                <td>
                  <xsl:apply-templates select="n:DriverRestriction"/>
                </td>
              </tr>
            </xsl:if>
          </table>
        </xsl:for-each>
      </xsl:if>
    </span>
    
    <xsl:if test="j2:Person/j2:PersonPhysicalDetails or j2:Person/j2:PersonBirthDate or j2:Person/j2:PersonMedicalDetails 
                  or n:DriverLicenseDetails/n:DriverOrganDonorIndicator or n:DriverLicenseDetails/n:DriverLicenseHMEThreat 
                  or j2:Person/j2:Residence or j2:Person/j2:PrimaryContactInformation or n:DriverLicenseDetails/n:DriverAlias">
    <span class="textTealSmall">
      <br/>
      <br/>
      <span class="detaillabel">
        Person Data:
      </span>
      <br/>
      <xsl:for-each select="j2:Person/j2:PersonPhysicalDetails/j2:PersonSexText">
        <xsl:apply-templates select="." mode="TitleCase"/>
        <xsl:text> </xsl:text>
      </xsl:for-each>
      <xsl:text>&#160;&#160;&#160;</xsl:text>
      <xsl:for-each select="j2:Person/j2:PersonPhysicalDetails/j2:PersonRaceText">
        <xsl:apply-templates select="." mode="TitleCase"/>
        <xsl:text> </xsl:text>
      </xsl:for-each>
      <xsl:text>&#160;&#160;&#160;</xsl:text>
      <xsl:for-each select="j2:Person/j2:PersonBirthDate">
        <xsl:call-template name="dateFormat">
          <xsl:with-param name="date" select="."/>
        </xsl:call-template>
        <xsl:text> </xsl:text>
      </xsl:for-each>
      <br/>
      <xsl:for-each select="j2:Person/j2:PersonPhysicalDetails/j2:PersonHeightMeasure">
        <xsl:call-template name="heightFormat">
          <xsl:with-param name="height" select="."/>
        </xsl:call-template>
        <xsl:text> </xsl:text>
      </xsl:for-each>
      <xsl:text>&#160;&#160;&#160;</xsl:text>
      <xsl:for-each select="j2:Person/j2:PersonPhysicalDetails/j2:PersonWeightMeasure">
        <xsl:value-of select="."/>
        <xsl:text> lbs </xsl:text>
      </xsl:for-each>
      <xsl:text>&#160;&#160;&#160;</xsl:text>
      <xsl:for-each select="j2:Person/j2:PersonPhysicalDetails/j2:PersonEyeColorText">
        <xsl:apply-templates select="." mode="TitleCase"/>
        <xsl:text> Eyes </xsl:text>
      </xsl:for-each>
      <xsl:text>&#160;&#160;&#160;</xsl:text>
      <xsl:for-each select="j2:Person/j2:PersonPhysicalDetails/j2:PersonHairColorText">
        <xsl:apply-templates select="." mode="TitleCase"/>
        <xsl:text> Hair </xsl:text>
      </xsl:for-each>
      <xsl:if test="j2:Person/j2:PersonMedicalDetails/j2:PersonMedicalFileIndicator">
        <table cellspacing="0" cellpadding="0">
          <tr>
            <td class="labelPersonDataMedicalHistory">
              <xsl:text>Medical History: </xsl:text>
            </td>
            <td>
              <xsl:for-each select="j2:Person/j2:PersonMedicalDetails/j2:PersonMedicalFileIndicator">
                <xsl:if test="position() > 1">
                  <br/>
                </xsl:if>
                <xsl:call-template name="indicatorFormat">
                  <xsl:with-param name="indicator" select="."/>
                </xsl:call-template>
                <xsl:if test="./@j2:commentText">
                  <xsl:text> - </xsl:text>
                  <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
                </xsl:if>
              </xsl:for-each>
            </td>
          </tr>
        </table>
      </xsl:if>
      <xsl:if test="n:DriverLicenseDetails/n:DriverOrganDonorIndicator">
        <table cellspacing="0" cellpadding="0">
          <tr>
            <td class="labelPersonDataOrganDonor">
              <xsl:text>Organ Donor: </xsl:text>
            </td>
            <td>
              <xsl:call-template name="indicatorFormat">
                <xsl:with-param name="indicator" select="n:DriverLicenseDetails/n:DriverOrganDonorIndicator"/>
              </xsl:call-template>
            </td>
          </tr>
        </table>
      </xsl:if>
      <xsl:if test="n:DriverLicenseDetails/n:DriverLicenseHMEThreat">
        <table cellspacing="0" cellpadding="0">
          <tr>
            <td class="labelPersonDataTSA">
              <xsl:text>TSA Hazmat Determination:</xsl:text>
            </td>
            <td>
              <xsl:for-each select="n:DriverLicenseDetails/n:DriverLicenseHMEThreat">
                <xsl:if test="position() > 1">
                  <br/>
                </xsl:if>
                <xsl:apply-templates select="n:DriverLicenseHMEThreatText" mode="TitleCase"/>
                <xsl:if test="n:DriverLicenseHMEThreatDate">
                  <xsl:text> - </xsl:text>
                  <xsl:call-template name="dateFormat">
                    <xsl:with-param name="date" select="n:DriverLicenseHMEThreatDate"/>
                  </xsl:call-template>
                </xsl:if>
              </xsl:for-each>
            </td>
          </tr>
        </table>
      </xsl:if>
      <xsl:for-each select="j2:Person/j2:Residence">
        <xsl:if test="position() = 1">
          <br/>
          <br/>
          <span class="detaillabel">
            Residence:
          </span>
        </xsl:if>
        <xsl:for-each select="j2:LocationAddress/j2:LocationStreet/j2:StreetFullText">
          <br/>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <br/>
        <xsl:for-each select="j2:LocationAddress/j2:LocationCityName">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <xsl:text>, </xsl:text>
        <xsl:for-each select="j2:LocationAddress/j2:LocationStateName">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
        <xsl:text> </xsl:text>
        <xsl:for-each select="j2:LocationAddress/j2:LocationPostalCodeID/j2:ID">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <xsl:if test="j2:LocationAddress/j2:LocationCountyName or j2:LocationAddress/j2:LocationCountryName">
          <br/>
        </xsl:if>
        <xsl:for-each select="j2:LocationAddress/j2:LocationCountyName">
          <xsl:if test="position() = 1">
            County:
          </xsl:if>
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <xsl:text> </xsl:text>
        <xsl:for-each select="j2:LocationAddress/j2:LocationCountryName">
          <xsl:if test="position() = 1">
            Country:
          </xsl:if>
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <xsl:if test="j2:ResidenceEndDate">
          <br/>
          <table cellspacing="0" cellpadding="0">
            <tr>
              <td class="labelResidence">
                Residence End Date:
              </td>
              <td>
                <xsl:for-each select="j2:ResidenceEndDate">
                  <xsl:if test="position() > 1">
                    <br/>
                  </xsl:if>
                  <xsl:call-template name="dateFormat">
                    <xsl:with-param name="date" select="."/>
                  </xsl:call-template>
                </xsl:for-each>
              </td>
            </tr>
          </table>
        </xsl:if>
      </xsl:for-each>
      <xsl:for-each select="j2:Person/j2:PrimaryContactInformation">
        <br/>
        <xsl:if test="position() = 1">
          <br/>
          <span class="detaillabel">
            Mailing Address:
          </span>
        </xsl:if>
        <xsl:for-each select="j2:ContactMailingAddress/j2:LocationStreet/j2:StreetFullText">
          <br/>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <br/>
        <xsl:for-each select="j2:ContactMailingAddress/j2:LocationCityName">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <xsl:text>, </xsl:text>
        <xsl:for-each select="j2:ContactMailingAddress/j2:LocationStateName">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
        <xsl:text> </xsl:text>
        <xsl:for-each select="j2:ContactMailingAddress/j2:LocationPostalCodeID/j2:ID">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <xsl:if test="j2:ContactMailingAddress/j2:LocationCountyName or j2:ContactMailingAddress/j2:LocationCountryName">
          <br/>
        </xsl:if>
        <xsl:for-each select="j2:ContactMailingAddress/j2:LocationCountyName">
          <xsl:if test="position() = 1">
            County:
          </xsl:if>
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <xsl:text> </xsl:text>
        <xsl:for-each select="j2:ContactMailingAddress/j2:LocationCountryName">
          <xsl:if test="position() = 1">
            Country:
          </xsl:if>
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
      </xsl:for-each>
      <xsl:for-each select="n:DriverLicenseDetails/n:DriverAlias">
        <br/>
        <xsl:if test="position() = 1">
          <br/>
          <span class="detaillabel">
            Former:
            <br/>
          </span>
        </xsl:if>
        <xsl:if test="j2:PersonName">
          <xsl:apply-templates select="j2:PersonName" mode="nlets"/>
          <xsl:text> </xsl:text>
        </xsl:if>
        <xsl:if test="j2:PersonBirthDate">
          <xsl:call-template name="dateFormat">
            <xsl:with-param name="date" select="j2:PersonBirthDate"/>
          </xsl:call-template>
          <xsl:text> </xsl:text>
        </xsl:if>
        <xsl:if test="j2:PersonSSNID/j2:ID">
          <xsl:call-template name="ssnFormat">
            <xsl:with-param name="ssn" select="j2:PersonSSNID/j2:ID"/>
          </xsl:call-template>
          <xsl:text> </xsl:text>
        </xsl:if>
        <xsl:if test="j2:DriverAuthorizationID.Detailed">
          <xsl:value-of select="j2:DriverAuthorizationID.Detailed/j2:ID"/>
          <xsl:for-each select="j2:DriverAuthorizationID.Detailed/j2:DrivingJurisdictionAuthorityCode.ncicLSTA">
            <xsl:text> </xsl:text>
            <xsl:value-of select="."/>
          </xsl:for-each>
          <xsl:text> </xsl:text>
        </xsl:if>
      </xsl:for-each>
    </span>
    </xsl:if>
    
       </td>
        <xsl:variable name="width">
          <xsl:choose>
            <xsl:when test="j2:Person/j2:PersonBiometricDetails/j2:PersonDigitalImage">
              <xsl:text>width20percent</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>width40percent</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <td class="{$width}" align="left">
          <xsl:apply-templates select="j2:Person/j2:PersonBiometricDetails/j2:PersonDigitalImage" />
        </td>
      </tr>
    </table>
    
    <span class="textTealMedium">
      <xsl:if test="string-length(n:DriverLicenseDetails/j2:DriverHistoryConvictionQuantity)>0 
                    or string-length(n:DriverLicenseDetails/j2:DriverHistoryAccidentQuantity)>0 
                    or string-length(n:DriverLicenseDetails/j2:DriverHistoryWithdrawalQuantity)>0">
        <br/>
        <br/>
        <span class="detaillabel">
          Record Details:
        </span>
        <table cellspacing="0" cellpadding="0">
          <xsl:if test="string-length(n:DriverLicenseDetails/j2:DriverHistoryConvictionQuantity)>0">
            <tr>
              <td class="labelRecordDetails">
                Prior Conviction Count:
              </td>
              <td>
                <xsl:value-of select="n:DriverLicenseDetails/j2:DriverHistoryConvictionQuantity"/>
              </td>
            </tr>
          </xsl:if>
          <xsl:if test="string-length(n:DriverLicenseDetails/j2:DriverHistoryAccidentQuantity)>0">
            <tr>
              <td class="labelRecordDetails">
                Prior Incident/Accident Count:
              </td>
              <td>
                <xsl:value-of select="n:DriverLicenseDetails/j2:DriverHistoryAccidentQuantity"/>
              </td>
            </tr>
          </xsl:if>
          <xsl:if test="string-length(n:DriverLicenseDetails/j2:DriverHistoryWithdrawalQuantity)>0">
            <tr>
              <td class="labelRecordDetails">
                Prior Withdrawals/Reinstatement Count:
              </td>
              <td>
                <xsl:value-of select="n:DriverLicenseDetails/j2:DriverHistoryWithdrawalQuantity"/>
              </td>
            </tr>
          </xsl:if>
        </table>
      </xsl:if>
    </span>
    
    <span class="textTealSmall">
      <xsl:for-each select="../n:AdditionalInformation/n:StateElement">
        <xsl:if test="position() = 1">
          <br/>
          <span class="textBlueSmall">
            Notation:
          </span>
        </xsl:if>
        <br/>
        <xsl:apply-templates select="j2:MetadataFieldName" mode="TitleCase"/>
        <xsl:text>: </xsl:text>
        <xsl:apply-templates select="j2:MetadataFieldValueText" mode="TitleCase"/>
      </xsl:for-each>
      <br/>
      <table cellspacing="0" cellpadding="0">
        <xsl:for-each select="n:DriverLicenseDetails/j2:DriverConviction">
          <tr>
            <td>
              &#160;
            </td>
          </tr>
          <tr>
            <td class="labelEvents">
              <xsl:for-each select="j2:ActivityDate">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:call-template name="dateFormat">
                  <xsl:with-param name="date" select="."/>
                </xsl:call-template>
              </xsl:for-each>
              <xsl:text> - </xsl:text>
              <xsl:for-each select="j2:ConvictionOffense/j2:ActivityDate">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:call-template name="dateFormat">
                  <xsl:with-param name="date" select="."/>
                </xsl:call-template>
              </xsl:for-each>
            </td>
            <td>
              <span class="textBlueSmall">
                Conviction
              </span>
              <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:ConvictionOffense/j2:IncidentViolatedStatute">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
                <xsl:text> </xsl:text>
                <xsl:for-each select="j2:StatuteOffenseID">
                  <xsl:if test="position() > 1">
                    <xsl:text>, </xsl:text>
                  </xsl:if>
                  <xsl:apply-templates select="j2:ID" mode="TitleCase"/>
                </xsl:for-each>
              </xsl:for-each>
              <xsl:for-each select="j2:ConvictionCourt[@j2:commentText or j2:OrganizationTypeText]">
                <xsl:if test="position() = 1">
                  Court:
                  <xsl:apply-templates select="@j2:commentText" mode="TitleCase"/>
                  <xsl:text> </xsl:text>
                </xsl:if>
                <xsl:for-each select="j2:OrganizationTypeText">
                  <xsl:if test="position() > 1">
                    <xsl:text>, </xsl:text>
                  </xsl:if>
                  <xsl:apply-templates select="." mode="TitleCase"/>
                </xsl:for-each>
                <xsl:text> </xsl:text>
              </xsl:for-each>
              <xsl:for-each select="j2:ConvictionCourt/j2:OrganizationJurisdiction">
                <xsl:if test="position() = 1">
                  State:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:for-each select="j2:LocationStateCode.ncicLSTA">
                  <xsl:if test="position() > 1">
                    <xsl:text>, </xsl:text>
                  </xsl:if>
                  <xsl:value-of select="."/>
                </xsl:for-each>
              </xsl:for-each>
              <xsl:for-each select="j2:DriverConvictionCitation">
                <xsl:text> </xsl:text>
                <xsl:for-each select="j2:ActivityDate">
                  <xsl:if test="position() > 1">
                    <xsl:text>, </xsl:text>
                  </xsl:if>
                  <xsl:call-template name="dateFormat">
                    <xsl:with-param name="date" select="."/>
                  </xsl:call-template>
                </xsl:for-each>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverConvictionOffenseText">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverConvictionOffenseDescriptionText">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverConvictionCMVText">
                <xsl:if test="position() = 1">
                  Commercial Vehicle:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverConvictionHazMatText">
                <xsl:if test="position() = 1">
                  Hazardous Materials:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:ConvictionLocatorReferenceID">
                <xsl:if test="position() = 1">
                  File #:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:value-of select="j2:ID"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
            </td>
          </tr>
        </xsl:for-each>
        <xsl:for-each select="n:DriverLicenseDetails/j2:DriverLicenseWithdrawal">
          <tr>
            <td>
              &#160;
            </td>
          </tr>
          <tr>
            <td class="labelEvents">
              <xsl:for-each select="j2:DriverLicenseWithdrawalEffectiveDate">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:call-template name="dateFormat">
                  <xsl:with-param name="date" select="."/>
                </xsl:call-template>
              </xsl:for-each>
              <xsl:for-each select="j2:DriverLicenseWithdrawalReinstatementDate">
                <xsl:if test="position() = 1">
                  <xsl:if test="../j2:DriverLicenseWithdrawalEffectiveDate">
                    <xsl:text> - </xsl:text>
                  </xsl:if>
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:call-template name="dateFormat">
                  <xsl:with-param name="date" select="."/>
                </xsl:call-template>
              </xsl:for-each>
              <xsl:text> </xsl:text>
            </td>
            <td>
              <span class="textBlueSmall">
                Withdrawal/Reinstatement
              </span>
              <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalIssuingAuthorityCode">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalReasonReferenceCodeText">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalExtentText">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalActionText">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalBasisText">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalText">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalDueProcessStatusText">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:ActivityDate">
                <xsl:if test="position() = 1">
                  Activity Date:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:call-template name="dateFormat">
                  <xsl:with-param name="date" select="."/>
                </xsl:call-template>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalEligibilityDate">
                <xsl:if test="position() = 1">
                  Eligibility:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:call-template name="dateFormat">
                  <xsl:with-param name="date" select="."/>
                </xsl:call-template>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalEligibilityCode">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DriverLicenseWithdrawalLocatorReferenceID">
                <xsl:if test="position() = 1">
                  File #:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:value-of select="."/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
            </td>
          </tr>
        </xsl:for-each>
        <xsl:for-each select="n:DriverLicenseDetails/j2:DrivingIncident">
          <tr>
            <td>
              &#160;
            </td>
          </tr>
          <tr>
            <td class="labelEvents">
              <xsl:for-each select="j2:ActivityDate">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:call-template name="dateFormat">
                  <xsl:with-param name="date" select="."/>
                </xsl:call-template>
              </xsl:for-each>
            </td>
            <td>
              <span class="textBlueSmall">
                Incident/Accident
              </span>
              <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:IncidentViolatedStatute">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
                <xsl:text> </xsl:text>
                <xsl:for-each select="j2:StatuteOffenseID">
                  <xsl:if test="position() > 1">
                    <xsl:text>, </xsl:text>
                  </xsl:if>
                  <xsl:value-of select="j2:ID"/>
                  <xsl:text> </xsl:text>
                  <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
                  <xsl:text> </xsl:text>
                  <xsl:apply-templates select="j2:ID/@j2:commentText" mode="TitleCase"/>
                </xsl:for-each>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DrivingIncidentJurisdiction">
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
                <xsl:text> </xsl:text>
                <xsl:for-each select="j2:LocationStateCode.ncicLSTA">
                  <xsl:if test="position() > 1">
                    <xsl:text>, </xsl:text>
                  </xsl:if>
                  <xsl:value-of select="."/>
                  <xsl:text> </xsl:text>
                  <xsl:apply-templates select="./@j2:commentText" mode="TitleCase"/>
                </xsl:for-each>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DrivingAccidentSeverityText">
                <xsl:if test="position() = 1">
                  Accident Severity:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DrivingIncidentCMVText">
                <xsl:if test="position() = 1">
                  Commercial Vehicle:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DrivingIncidentHazMatText">
                <xsl:if test="position() = 1">
                  Hazardous Materials:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:apply-templates select="." mode="TitleCase"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
              <xsl:for-each select="j2:DrivingIncidentLocatorReferenceID">
                <xsl:if test="position() = 1">
                  File #:
                </xsl:if>
                <xsl:if test="position() > 1">
                  <xsl:text>, </xsl:text>
                </xsl:if>
                <xsl:value-of select="j2:ID"/>
              </xsl:for-each>
              <xsl:text> </xsl:text>
            </td>
          </tr>
        </xsl:for-each>
      </table>
    </span>
  </xsl:template>
  
  
  <!-- Call templates follow -->
  <xsl:template name="dateFormat">
    <xsl:param name="date"/>
    <xsl:choose>
      <xsl:when test="substring($date, 5, 1) = '-'">
        <xsl:value-of select="substring($date, 6, 2)"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="substring($date, 9, 2)"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="substring($date, 1, 4)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$date"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template name="heightFormat">
    <xsl:param name="height"/>
    <xsl:choose>
      <xsl:when test="string-length($height) = 3">
        <xsl:value-of select="substring($height, 1, 1)"/>
        <xsl:text>' </xsl:text>
        <xsl:value-of select="substring($height, 2, 2)"/>
        <xsl:text>"</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$height"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template name="indicatorFormat">
    <xsl:param name="indicator"/>
    <xsl:choose>
      <xsl:when test="$indicator = 'false'">
        <xsl:text>No</xsl:text>
      </xsl:when>
      <xsl:when test="$indicator = 'true'">
        <xsl:text>Yes</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$indicator"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template name="ssnFormat">
    <xsl:param name="ssn"/>
    <xsl:choose>
      <xsl:when test="string-length($ssn) = 9">
        <xsl:value-of select="substring($ssn, 1, 3)"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="substring($ssn, 4, 2)"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="substring($ssn, 6, 4)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$ssn"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template match="j2:PersonDigitalImage">
    <xsl:if test="position()=1">
      <xsl:choose>
        <xsl:when test="j2:BinaryObject.Base64">
          <xsl:variable name="responseID" select="/doj:NLETSResponseDocument/@doj-ext:responseID"/>
          <img ignoreNightMode="true" src="image?ETIMEResponseId={$responseID}&amp;ImageIndex=0&amp;Resize=true"/>
          <br/>
          <a href="javascript: void(0)" 
             onclick="window.open('imageDetail.jsp?ETIMEResponseId={$responseID}&amp;WhatToDo=showImages&amp;ShowOneImage=true', '', 'directories=no, location=no, menubar=no, resizable=yes, toolbar=no, scrollbars=yes, status=no');return false;">
            <img src="../../images/detail.jpg"/>
          </a>
          <xsl:if test="count(//j2:PersonDigitalImage) > 1">
            <a href="javascript: void(0)" 
               onclick="window.open('imageDetail.jsp?ETIMEResponseId={$responseID}&amp;WhatToDo=showImages', '', 'directories=no, location=no, menubar=no, resizable=yes, toolbar=no, scrollbars=yes, status=no');return false;">
              <img src="../../images/additionalimages.jpg"/>
            </a>
            <!-- <a href="javascript: void(0)" onclick="alert('Additional Images is not available at this time');return false;"><img src="../../images/additionalimages.jpg"/></a> -->
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <xsl:if test="j2:BinaryAvailableIndicator='true'">
            <span class="textTealSmall">Image Available</span>
          </xsl:if>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>
  
</xsl:transform>