<?xml version="1.0"?>
<xsl:transform version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xmlns:doj="http://www.doj.state.wi.us/dles/cib/nlets/response"
  xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
  xmlns:j="http://www.it.ojp.gov/jxdm/3.0"
  xmlns:j2="http://www.it.ojp.gov/jxdm/3.0.2"
  xmlns:java="http://xml.apache.org/xslt/java"
  xmlns:n="http://www.nlets.org"
  xmlns:xalan="http://xml.apache.org/xslt"
  exclude-result-prefixes="xsl xsi doj doj-ext j j2 n xalan">
  <xsl:import href="../common.xsl" />
  <xsl:import href="../util.xsl" />
  <xsl:param name="from" />
  <xsl:param name="responseId">
    <xsl:value-of
      select="doj:NLETSResponseDocument/@doj-ext:responseID" />
  </xsl:param>
  <xsl:output method="html" version="4.01" encoding="UTF-8"
    omit-xml-declaration="yes"
    doctype-public="-//W3C//DTD HTML 4.01//EN"
    doctype-system="http://www.w3.org/TR/html4/strict.dtd" indent="yes"
    media-type="text/html" xalan:indent-amount="2" />
  <xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension" />
        <xsl:call-template name="html_body" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="*" mode="address1">
    <xsl:for-each select="j2:LocationStreet/j2:StreetFullText">
      <xsl:apply-templates select="." mode="TitleCase"/>
      <br/>
    </xsl:for-each>
    <xsl:for-each select="j2:LocationCityName">
      <xsl:if test="position() > 1">
        <xsl:text> </xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="TitleCase"/>
    </xsl:for-each>
    <xsl:text> </xsl:text>
    <xsl:for-each select="j2:LocationStateName">
      <xsl:if test="position() > 1">
        <xsl:text> </xsl:text>
      </xsl:if>
      <xsl:value-of select="."/>
    </xsl:for-each>
    <xsl:text> </xsl:text>
    <xsl:for-each select="j2:LocationPostalCodeID/j2:ID">
      <xsl:if test="position() > 1">
        <xsl:text> </xsl:text>
      </xsl:if>
      <xsl:value-of select="."/>
    </xsl:for-each>
    <xsl:text> </xsl:text>
    <xsl:for-each select="j2:LocationCountryName">
      <xsl:if test="position() > 1">
        <xsl:text> </xsl:text>
      </xsl:if>
      <xsl:value-of select="."/>
    </xsl:for-each>
    <xsl:if test="j2:LocationCountyName">
      <br/>
      <xsl:for-each select="j2:LocationCountyName">
        <xsl:if test="position() > 1">
          <xsl:text>, </xsl:text>
        </xsl:if>
        <xsl:apply-templates select="." mode="TitleCase"/>
      </xsl:for-each>
      <xsl:text> County</xsl:text>
    </xsl:if>
    <br/>
  </xsl:template>
  <xsl:template match="*" mode="address2">
    <xsl:for-each select="j2:LocationStreet/j2:StreetFullText">
      <xsl:apply-templates select="." mode="TitleCase"/>
      <xsl:text>, </xsl:text>
    </xsl:for-each>
    <xsl:for-each select="j2:LocationCityName">
      <xsl:apply-templates select="." mode="TitleCase"/>
      <xsl:text> </xsl:text>
    </xsl:for-each>
    <xsl:for-each select="j2:LocationStateName">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:for-each>
    <xsl:for-each select="j2:LocationPostalCodeID/j2:ID">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:for-each>
    <xsl:for-each select="j2:LocationCountryName">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:for-each>
    <xsl:for-each select="j2:LocationCountyName">
      <xsl:if test="position() > 1">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="TitleCase"/>
      <xsl:if test="position() = last()">
        <xsl:text> County</xsl:text>
      </xsl:if>
    </xsl:for-each>
    <br/>
  </xsl:template>
  <xsl:template match="*" mode="organization">
    <xsl:for-each select="j2:OrganizationName">
      <xsl:apply-templates select="." mode="TitleCase"/>
      <br/>
    </xsl:for-each>
    <xsl:for-each select="j2:OrganizationLocation/j2:LocationAddress">
      <xsl:if test="position() > 1">
        <br/>
      </xsl:if>
      <xsl:apply-templates select="." mode="address1"/>
    </xsl:for-each>
  </xsl:template>
  <xsl:template match="*" mode="person">
    <xsl:apply-templates select="j2:PersonName" mode="nlets"/>
    <xsl:if test="j2:PersonBirthDate">
      <xsl:text>DOB: </xsl:text>
      <xsl:for-each select="j2:PersonBirthDate">
        <xsl:if test="position() > 1">
          <xsl:text>, </xsl:text>
        </xsl:if>
        <xsl:call-template name="dateFormat">
          <xsl:with-param name="date" select="."/>
        </xsl:call-template>
        <xsl:if test="position()=1">
          <xsl:text> </xsl:text>
          <xsl:variable name="lastName" select="../j2:PersonName/j2:PersonSurName" />
          <xsl:variable name="firstName" select="../j2:PersonName/j2:PersonGivenName" />
          <xsl:variable name="middleName" select="../j2:PersonName/j2:PersonMiddleName" />
          <xsl:variable name="dob" select="." />
          <xsl:variable name="state" select="../../../j2:RegistrationJurisdictionCode.ncicLIS" />
          <!-- <xsl:variable name="sex" select="../j2:PersonPhysicalDetails/j2:PersonSexText" /> -->
          <form id="fullRecordRequest_{$lastName}_{$firstName}" action="/secure/personsearch/builddl.jsp" method="post" style="display:inline">
            <input name="lastName" type="hidden" value="{$lastName}" />
            <input name="firstName" type="hidden" value="{$firstName}" />
            <input name="middleName" type="hidden" value="{$middleName}" />
            <input name="dob" type="hidden" value="{$dob}" />
            <input name="state" type="hidden" value="{$state}" />
            <!-- <input name="sex" type="hidden" value="{$sex}" /> -->
            <input name="source" type="hidden" value="NLETS" />
          </form>
          <a href="javascript:document.getElementById('fullRecordRequest_{$lastName}_{$firstName}').submit();">Click here to submit driver query</a>
        </xsl:if>
      </xsl:for-each>
      <xsl:text> </xsl:text>
    </xsl:if>
    <xsl:for-each select="j2:PersonPhysicalDetails/j2:PersonSexText">
      <xsl:if test="position() = 1">
        <br/>
      </xsl:if>
      <xsl:if test="position() > 1">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="TitleCase"/>
    </xsl:for-each>
    <xsl:if test="j2:PersonBirthDate or j2:PersonPhysicalDetails/j2:PersonSexText">
      <br/>
    </xsl:if>
    <xsl:for-each select="j2:Residence/j2:LocationAddress">
      <xsl:if test="position() > 1">
        <br/>
      </xsl:if>
      <xsl:apply-templates select="." mode="address1"/>
    </xsl:for-each>
  </xsl:template>
  <xsl:template match="doj:ResultText | n:ResponseText">
  	<xsl:param name="headerInformation" />
    <h1 class="filetype">
      <xsl:value-of select="$headerInformation" />
    </h1>
    <table border="0" width="100%" align="right">
      <tr>
		    <td align="right">		    
		      <form name="form1" method="post" action="/servlet/SaveXMLResponseServlet">
		    	  <textarea name="saveresponsetext1" id="saveresponsetext1" style="display:none" rows="1" cols="1">
					    <xsl:text>VIN_NLETS</xsl:text>
				    </textarea>
				    <textarea name="savexmltext1" id="savexmltext1" style="display:none" rows="1" cols="1"/>
            <button onclick="copyxml();" name="savexmlbutton1" class="savexmlbuttonimage" type="submit">
              <u>
                <img width="110" height="24" alt="Save XML File" src="../../images/savexmlfileicon.gif"/>
              </u>
            </button>    
		      </form>    
    	  </td>
	    </tr> 
    </table>
    <hr/>
    <pre>
      <xsl:value-of select="." />
    </pre>
  </xsl:template>
  <xsl:template match="j:CaveatText">
    <xsl:value-of select="."/>
    <br/>
  </xsl:template>
  <xsl:template match="j2:PersonName" mode="nlets">
    <xsl:for-each select="j2:PersonSurName">
      <xsl:if test="position() > 1">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="TitleCase"/>
    </xsl:for-each>
    <xsl:for-each select="j2:PersonSuffixName">
      <xsl:text> </xsl:text>
      <xsl:apply-templates select="." mode="TitleCase"/>
    </xsl:for-each>
    <xsl:text>; </xsl:text>
    <xsl:for-each select="j2:PersonGivenName">
      <xsl:if test="position() > 1">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="TitleCase"/>
    </xsl:for-each>
    <xsl:for-each select="j2:PersonMiddleName">
      <xsl:choose>
        <xsl:when test="position() = 1">
          <xsl:text>, </xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text> </xsl:text>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="." mode="TitleCase"/>
      <xsl:if test="string-length(.)=1">
        <xsl:text>.</xsl:text>
      </xsl:if>
    </xsl:for-each>
    <br/>
  </xsl:template>
  <xsl:template match="n:IndividualMatch">
    <br/>
    <br/>
    <div class="matchNumber">
      <xsl:text># </xsl:text>
      <xsl:value-of select="position()"/>
    </div>
    <div class="textTealMedium">
      <xsl:value-of select="j2:VehicleRegistrationPlateID/j2:ID"/>
      <xsl:text> </xsl:text>
      <xsl:apply-templates select="j2:VehicleRegistrationPlateTypeText" mode="TitleCase"/>
      <xsl:text> </xsl:text>
      <xsl:call-template name="dateFormat">
        <xsl:with-param name="date" select="j2:RegistrationExpirationDate"/>
      </xsl:call-template>
      <xsl:text> </xsl:text>
      <xsl:value-of select="j2:VehicleModelYearDate"/>
      <xsl:text> </xsl:text>
      <xsl:value-of select="j2:VehicleMakeCode"/>
      <xsl:if test="j2:PropertyMakeName">
        <xsl:if test="j2:VehicleMakeCode">
          <xsl:text>-</xsl:text>
        </xsl:if>
        <xsl:apply-templates select="." mode="TitleCase"/>
      </xsl:if>
    </div>
    <br/>
    <br/>
    <xsl:apply-templates select="n:RegistrationPrimaryParty"/>
  </xsl:template>
  <xsl:template match="n:RegistrationMatches">
    <xsl:param name="headerInformation" />
    <xsl:call-template name="saveXML">
      <xsl:with-param name="headerInformation" select="$headerInformation"/>
      <xsl:with-param name="vehicleID" select="n:IndividualMatch/j2:VehicleID/j2:ID"/>
    </xsl:call-template>
    <img style="float:right" src="../../images/Plate1.jpg"/>
    <xsl:if test="../j:CaveatText">
      <span class="caveat">
        <xsl:apply-templates select="../j:CaveatText"/>
        <br/>
      </span>
    </xsl:if>
    <div class="textTealLarge">
      Possible Matches:
    </div>
    <xsl:apply-templates select="n:IndividualMatch"/>
  </xsl:template>
  <xsl:template match="n:RegistrationParty | n:RegistrationPrimaryParty">
    <xsl:choose>
      <xsl:when test="position() = 1">
        <div class="detaillabel">
          <xsl:text>Registrant(s):</xsl:text>
        </div>
      </xsl:when>
      <xsl:otherwise>
        <br/>
      </xsl:otherwise>
    </xsl:choose>
    <div class="textTealSmall">
      <table cellpadding="0" cellspacing="0">
        <tr>
          <td>
            <xsl:apply-templates select="j2:RegistrationParty.Organization" mode="organization"/>
            <xsl:for-each select="n:RegistrationPartyName">
              <xsl:apply-templates select="." mode="TitleCase"/>
              <br/>
            </xsl:for-each>
            <xsl:apply-templates select="j2:RegistrationParty.Person" mode="person"/>
          </td>
          <xsl:if test="n:MailingAddress">
            <td>
              <div class="textTealMedium">
                <xsl:text>Mailing Address:</xsl:text>
              </div>
              <xsl:apply-templates select="n:MailingAddress/j2:LocationAddress" mode="address1"/>
            </td>
          </xsl:if>
        </tr>
      </table>
    </div>
  </xsl:template>
  <xsl:template match="n:StandardResponse">
    <xsl:param name="headerInformation" />
    <xsl:call-template name="saveXML">
      <xsl:with-param name="headerInformation" select="$headerInformation"/>
      <xsl:with-param name="vehicleID" select="j2:VehicleID/j2:ID"/>
    </xsl:call-template>
    <xsl:if test="../j:CaveatText">
      <span class="caveat">
        <xsl:apply-templates select="../j:CaveatText"/>
        <br/>
      </span>
    </xsl:if>
    <table>
      <tr>
        <td width="120px">
          <img src="../../images/Plate1.jpg"/>
          <br/>
          <img src="../../images/VehicleIcon.jpg"/>
        </td>
        <td class="textTealLarge">
          <xsl:if test="n:RegistrationDetails/j2:RegistrationStatus or n:RegistrationDetails/j2:VehicleRegistrationStatusDetailText">
            <table cellpadding="0" cellspacing="0">
              <tr>
                <td valign="top" width="80px">
                  <xsl:text>Status:</xsl:text>
                </td>
                <td>
                  <xsl:for-each select="n:RegistrationDetails/j2:RegistrationStatus/j2:StatusText">
                    <xsl:apply-templates select="." mode="TitleCase"/>
                    <xsl:text> </xsl:text>
                  </xsl:for-each>
                  <xsl:for-each select="n:RegistrationDetails/j2:RegistrationStatus/j2:StatusDate">
                    <xsl:call-template name="dateFormat">
                      <xsl:with-param name="date" select="."/>
                    </xsl:call-template>
                    <xsl:text> </xsl:text>
                  </xsl:for-each>
                  <xsl:if test="n:RegistrationDetails/j2:RegistrationStatus/j2:StatusText or n:RegistrationDetails/j2:RegistrationStatus/j2:StatusDate">
                    <br/>
                  </xsl:if>
                  <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationStatusDetailText">
                    <xsl:apply-templates select="." mode="TitleCase"/>
                    <br/>
                  </xsl:for-each>
                </td>
              </tr>
            </table>
            <br/>
          </xsl:if>
          <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationPlateID/j2:ID">
            <xsl:value-of select="."/>
            <xsl:text> </xsl:text>
          </xsl:for-each>
          <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationPlateTypeText">
            <xsl:value-of select="."/>
            <xsl:text> </xsl:text>
          </xsl:for-each>
          <xsl:for-each select="n:RegistrationDetails/j2:RegistrationExpirationDate">
            <xsl:call-template name="dateFormat">
              <xsl:with-param name="date" select="."/>
            </xsl:call-template>
            <xsl:text> </xsl:text>
          </xsl:for-each>
          <br/>
          <br/>
          <xsl:variable name="field1">
            <xsl:for-each select="n:VehicleDetails/j2:VehicleModelYearDate">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:value-of select="."/>
            </xsl:for-each>
          </xsl:variable>
          <xsl:variable name="field2">
            <xsl:for-each select="n:VehicleDetails/j2:VehicleMakeCode">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:value-of select="."/>
            </xsl:for-each>
          </xsl:variable>
          <xsl:variable name="field3">
            <xsl:for-each select="n:VehicleDetails/j2:PropertyMakeName">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:apply-templates select="." mode="TitleCase"/>
            </xsl:for-each>
          </xsl:variable>
          <xsl:variable name="field4">
            <xsl:for-each select="n:VehicleDetails/j2:VehicleModelCode">
              <xsl:if test="position() > 1">
                <xsl:text>-</xsl:text>
              </xsl:if>
              <xsl:value-of select="."/>
            </xsl:for-each>
          </xsl:variable>
          <xsl:variable name="field5">
            <xsl:for-each select="n:VehicleDetails/j2:VehicleModelCodeText">
              <xsl:if test="position() > 1">
                <xsl:text>-</xsl:text>
              </xsl:if>
              <xsl:apply-templates select="." mode="TitleCase"/>
            </xsl:for-each>
          </xsl:variable>
          <xsl:variable name="field6">
            <xsl:for-each select="n:VehicleDetails/j2:VehicleStyleCode">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:value-of select="."/>
            </xsl:for-each>
          </xsl:variable>
          <xsl:variable name="field7">
            <xsl:for-each select="n:VehicleDetails/j2:VehicleDoorQuantity">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:value-of select="."/>
              <xsl:text> door</xsl:text>
            </xsl:for-each>
          </xsl:variable>
          <xsl:variable name="field8">
            <xsl:for-each select="n:VehicleDetails/j2:VehicleColorPrimaryText">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:apply-templates select="." mode="TitleCase"/>
            </xsl:for-each>
          </xsl:variable>
          <xsl:variable name="field9">
            <xsl:for-each select="n:VehicleDetails/j2:VehicleColorSecondaryText">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:apply-templates select="." mode="TitleCase"/>
            </xsl:for-each>
          </xsl:variable>
          <!-- Build the line right to left. The direction to use for adding commas. -->
          <xsl:variable name="linea">
            <xsl:value-of select="$field9"/>
          </xsl:variable>
          <xsl:variable name="lineb">
            <xsl:value-of select="$field8"/>
            <xsl:if test="string-length($field8) > 0 and string-length($linea) > 0">
              <xsl:text>/</xsl:text>
            </xsl:if>
            <xsl:value-of select="$linea"/>
          </xsl:variable>
          <xsl:variable name="linea">
            <xsl:value-of select="$field7"/>
            <xsl:if test="string-length($field7) > 0 and string-length($lineb) > 0">
              <xsl:text> </xsl:text>
            </xsl:if>
            <xsl:value-of select="$lineb"/>
          </xsl:variable>
          <xsl:variable name="lineb">
            <xsl:value-of select="$field6"/>
            <xsl:if test="string-length($field6) > 0 and string-length($linea) > 0">
              <xsl:text> </xsl:text>
            </xsl:if>
            <xsl:value-of select="$linea"/>
          </xsl:variable>
          <xsl:variable name="fields45">
            <xsl:value-of select="$field4"/>
            <xsl:if test="string-length($field4) > 0 and string-length($field5) > 0">
              <xsl:text>-</xsl:text>
            </xsl:if>
            <xsl:value-of select="$field5"/>
          </xsl:variable>
          <xsl:variable name="linea">
            <xsl:value-of select="$fields45"/>
            <xsl:if test="string-length($fields45) > 0 and string-length($lineb) > 0">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:value-of select="$lineb"/>
          </xsl:variable>
          <xsl:variable name="fields23">
            <xsl:value-of select="$field2"/>
            <xsl:if test="string-length($field2) > 0 and string-length($field3) > 0">
              <xsl:text>-</xsl:text>
            </xsl:if>
            <xsl:value-of select="$field3"/>
          </xsl:variable>
          <xsl:variable name="lineb">
            <xsl:value-of select="$fields23"/>
            <xsl:if test="string-length($fields23) > 0 and string-length($linea) > 0">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:value-of select="$linea"/>
          </xsl:variable>
          <xsl:variable name="linea">
            <xsl:value-of select="$field1"/>
            <xsl:if test="string-length($field1) > 0 and string-length($lineb) > 0">
              <xsl:text> </xsl:text>
            </xsl:if>
            <xsl:value-of select="$lineb"/>
          </xsl:variable>
          <xsl:value-of select="$linea"/>
          <xsl:if test="n:VehicleDetails/j2:VehicleID/j2:ID or n:VehicleDetails/j2:VehicleVINAText">
            <table cellpadding="0" cellspacing="0">
              <tr>
                <td valign="top" width="80px">
                  <xsl:text>VIN:</xsl:text>
                </td>
                <td valign="center">
                  <xsl:for-each select="n:VehicleDetails/j2:VehicleID/j2:ID">
                    <xsl:value-of select="."/>
                    <xsl:text> </xsl:text>
                  </xsl:for-each>
                  <xsl:for-each select="n:VehicleDetails/j2:VehicleVINAText">
                    <xsl:value-of select="."/>
                    <xsl:text> </xsl:text>
                  </xsl:for-each>
                </td>
              </tr>
            </table>
          </xsl:if>
          <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleID">
            <table cellpadding="0" cellspacing="0">
              <tr>
                <td valign="top" width="80px">
                  <xsl:text>Title #:</xsl:text>
                </td>
                <td valign="center">
                  <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleID/j2:ID">
                    <xsl:value-of select="."/>
                    <xsl:text> </xsl:text>
                  </xsl:for-each>
                </td>
              </tr>
            </table>
          </xsl:if>
          <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleIssueDate or n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleStatusText or n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:StatusDate">
            <table cellpadding="0" cellspacing="0">
              <tr>
                <td valign="top" width="80px">
                  <xsl:text>Title:</xsl:text>
                </td>
                <td>
                  <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleIssueDate">
                    <xsl:choose>
                      <xsl:when test="position() = 1">
                        Issued
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:text> </xsl:text>
                      </xsl:otherwise>
                    </xsl:choose>
                    <xsl:call-template name="dateFormat">
                      <xsl:with-param name="date" select="."/>
                    </xsl:call-template>
                  </xsl:for-each>
                  <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleStatusText or n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:StatusDate">
                    <xsl:text>, </xsl:text>
                    Status
                    <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleStatusText">
                      <xsl:apply-templates select="." mode="TitleCase"/>
                      <xsl:text> </xsl:text>
                    </xsl:for-each>
                    <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:StatusDate">
                      <xsl:call-template name="dateFormat">
                        <xsl:with-param name="date" select="."/>
                      </xsl:call-template>
                      <xsl:text> </xsl:text>
                    </xsl:for-each>
                  </xsl:if>
                </td>
              </tr>
            </table>
          </xsl:if>
          <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:PropertyAssignedIDDetails/j2:PropertyOwnerAppliedID">
            <table cellpadding="0" cellspacing="0">
              <tr>
                <td class="textTealLarge" valign="top" width="170px">
                  <xsl:text>Owner Applied #:</xsl:text>
                </td>
                <td valign="center">
                  <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:PropertyAssignedIDDetails/j2:PropertyOwnerAppliedID/j2:ID">
                    <xsl:value-of select="."/>
                    <xsl:text> </xsl:text>
                  </xsl:for-each>
                </td>
              </tr>
            </table>
          </xsl:if>
        </td>
      </tr>
    </table>
    <!-- Boy, this is a kludgy mess to do newspaper column formatting. Also this has to be done here
    instead of where this data is displayed in order to determine if the image should be included. -->
    <xsl:variable name="javaLabel" select="java:java.util.ArrayList.new()"/>
    <xsl:variable name="javaValue" select="java:java.util.ArrayList.new()"/>
    <xsl:if test="n:RegistrationDetails/j2:RegistrationID">
      <xsl:if test="java:add($javaLabel, 'Registration ID')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:RegistrationID/j2:ID">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleOwnershipTypeText">
      <xsl:if test="java:add($javaLabel, 'Ownership Type')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleOwnershipTypeText">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:RegistrationAuthorityName">
      <xsl:if test="java:add($javaLabel, 'Registration Authority')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:RegistrationAuthorityName">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:RegistrationEffectiveDate">
      <xsl:if test="java:add($javaLabel, 'Registration Effective Date')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:RegistrationEffectiveDate">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:call-template name="dateFormat">
            <xsl:with-param name="date" select="."/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:RegistrationJurisdictionCode.ncicLIS">
      <xsl:if test="java:add($javaLabel, 'Registration Jurisdiction')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:RegistrationJurisdictionCode.ncicLIS">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:RegistrationDuplicateQuantity">
      <xsl:if test="java:add($javaLabel, 'Registration Duplicate Qty')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:RegistrationDuplicateQuantity">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:VehicleRegistrationPermenantIndicator">
      <xsl:if test="java:add($javaLabel, 'Permanent Registration')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationPermenantIndicator">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:call-template name="indicatorFormat">
            <xsl:with-param name="indicator" select="."/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:VehicleRegistrationGrossWeightMeasure">
      <xsl:if test="java:add($javaLabel, 'Registration Gross Weight')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationGrossWeightMeasure">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="./@j2:weightUnitCode"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleLeaseIndicator">
      <xsl:if test="java:add($javaLabel, 'Leased Vehicle')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleLeaseIndicator">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:call-template name="indicatorFormat">
            <xsl:with-param name="indicator" select="."/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleCurrentWeightMeasure">
      <xsl:if test="java:add($javaLabel, 'Current Weight')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleCurrentWeightMeasure">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="./@j2:weightUnitCode"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleGrossLadenSumWeightMeasure">
      <xsl:if test="java:add($javaLabel, 'Gross Laden Sum Weight')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleGrossLadenSumWeightMeasure">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="./@j2:weightUnitCode"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleUnladenWeightMeasure">
      <xsl:if test="java:add($javaLabel, 'Unladen Weight')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleUnladenWeightMeasure">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="./@j2:weightUnitCode"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleMaximumLoadWeightMeasure">
      <xsl:if test="java:add($javaLabel, 'Vehicle Maximum Weight')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleMaximumLoadWeightMeasure">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="./@j2:weightUnitCode"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:PropertyLengthMeasure">
      <xsl:if test="java:add($javaLabel, 'Vehicle Length')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:PropertyLengthMeasure">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="./@j2:lengthUnitCode"/>
          <xsl:value-of select="./@j2:lengthUnitMeasure"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleAxleQuantity">
      <xsl:if test="java:add($javaLabel, 'Axle Quantity')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:CommercialVehicleDetails/j2:VehicleAxleQuantity">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngineQuantity">
      <xsl:if test="java:add($javaLabel, 'Engine Quantity')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngineQuantity">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleEngineID/j2:ID">
      <xsl:if test="java:add($javaLabel, 'Engine Number')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleEngineID/j2:ID">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleEngineCylinderQuantity">
      <xsl:if test="java:add($javaLabel, 'Cylinder Quantity')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleEngineCylinderQuantity">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleEngineHorsepowerQuantity">
      <xsl:if test="java:add($javaLabel, 'Horsepower')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleEngineHorsepowerQuantity">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleEngineDisplacementMeasure">
      <xsl:if test="java:add($javaLabel, 'Engine Displacement')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleEngineDisplacementMeasure">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="./@j2:vehicleEngineDisplacementUnitCode"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleFuelTypeText">
      <xsl:if test="java:add($javaLabel, 'Fuel Type')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/j2:VehicleEngine/j2:VehicleFuelTypeText">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehicleOdometerReadingMeasure">
      <xsl:if test="java:add($javaLabel, 'Odometer Reading')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/j2:VehicleOdometerReadingMeasure">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
          <xsl:if test="./@j2:vehicleOdometerReadingUnitCode">
            <xsl:text> </xsl:text>
            <xsl:value-of select="./@j2:vehicleOdometerReadingUnitCode"/>
          </xsl:if>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehicleOdometerReadingMeasure/@j2:measureDate">
      <xsl:if test="java:add($javaLabel, 'Odometer Reading Date')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/j2:VehicleOdometerReadingMeasure/@j2:measureDate">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:call-template name="dateFormat">
            <xsl:with-param name="date" select="."/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehicleSeatingQuantity">
      <xsl:if test="java:add($javaLabel, 'Seating Capacity')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/j2:VehicleSeatingQuantity">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehiclePassengerSafeQuantity">
      <xsl:if test="java:add($javaLabel, 'Safe Passenger Capacity')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/j2:VehiclePassengerSafeQuantity">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehicleTransmissionTypeText">
      <xsl:if test="java:add($javaLabel, 'Transmission Type')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/j2:VehicleTransmissionTypeText">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehicleMSRPAmount">
      <xsl:if test="java:add($javaLabel, 'Mfg Suggested Rtl Price')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/j2:VehicleMSRPAmount">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehicleInvoiceID">
      <xsl:if test="java:add($javaLabel, 'Vehicle Invoice Number')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/j2:VehicleInvoiceID/j2:ID">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehicleInvoiceDate">
      <xsl:if test="java:add($javaLabel, 'Vehicle Invoice Date')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:VehicleDetails/j2:VehicleInvoiceDate">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:call-template name="dateFormat">
            <xsl:with-param name="date" select="."/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalID">
      <xsl:if test="java:add($javaLabel, 'Decal Number')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalID/j2:ID">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalColorText">
      <xsl:if test="java:add($javaLabel, 'Decal Color')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalColorText">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalPeriodText">
      <xsl:if test="java:add($javaLabel, 'Decal Period')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalPeriodText">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalYearDate">
      <xsl:if test="java:add($javaLabel, 'Decal Year')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalYearDate">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <xsl:if test="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalMonthDate">
      <xsl:if test="java:add($javaLabel, 'Decal Month')"/>
      <xsl:variable name="value">
        <xsl:for-each select="n:RegistrationDetails/j2:VehicleRegistrationDecal/j2:DecalMonthDate">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </xsl:variable>
      <xsl:if test="java:add($javaValue, $value)"/>
    </xsl:if>
    <br/>
    <table cellpadding="0" cellspacing="0">
      <tr>
        <xsl:if test="java:size($javaValue) > 0">
          <td width="100px">
            <a href="#recorddetails{$responseId}">
              <img src="../../images/RegistrationDetails.jpg" />
            </a>
        </td>
        </xsl:if>
        <xsl:if test="n:VehicleDetails/j2:Insurance or n:VehicleDetails/n:InsuranceDetails">
          <td width="100px">
            <a href="#insurancedetails{$responseId}">
              <img src="../../images/InsuranceDetails.jpg" />
            </a>
          </td>
        </xsl:if>
        <xsl:if test="../n:AdditionalInformation">
          <td width="110px">
            <a href="#additionalinformation{$responseId}">
              <img src="../../images/AdditionalInformation.jpg" />
            </a>
          </td>
        </xsl:if>
        <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:Lien">
          <td width="100px">
            <a href="#lienholderdetails{$responseId}">
              <img src="../../images/LienHolderDetails.jpg" />
            </a>
          </td>
        </xsl:if>
        <td>
          &#160;
        </td>
      </tr>
    </table>
    <br/>
    <xsl:apply-templates select="n:RegistrationDetails/n:RegistrationParty"/>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleProperty">
      <br/>
      <div class="detaillabel">
        Owner(s):
      </div>
      <table cellpadding="0" cellspacing="0" class="textTealSmall">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:TitleProperty">
          <xsl:if test="position() mod 2 = 1"> <!-- start a new row? -->
            <xsl:text disable-output-escaping="yes">&lt;tr&gt;</xsl:text>
          </xsl:if>
          <td>
            <xsl:for-each select="j2:PropertyOwner.Organization">
              <xsl:apply-templates select="." mode="organization"/>
              <br/>
            </xsl:for-each>
            <xsl:for-each select="j2:PropertyOwner.Person">
              <xsl:apply-templates select="." mode="person"/>
              <br/>
            </xsl:for-each>
          </td>
          <xsl:if test="position() mod 2 = 0 or position() = last()"> <!-- end the row? -->
            <xsl:text disable-output-escaping="yes">&lt;/tr&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
      </table>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:Lessor">
      <br/>
      <div class="detaillabel">
        Lessor(s):
      </div>
      <table cellpadding="0" cellspacing="0" class="textTealSmall">
        <xsl:for-each select="n:VehicleDetails/n:Lessor">
          <xsl:if test="position() mod 2 = 1"> <!-- start a new row? -->
            <xsl:text disable-output-escaping="yes">&lt;tr&gt;</xsl:text>
          </xsl:if>
          <td>
            <xsl:for-each select="j2:Lessor.Organization">
              <xsl:apply-templates select="." mode="organization"/>
              <br/>
            </xsl:for-each>
            <xsl:for-each select="j2:Lessor.Person">
              <xsl:apply-templates select="." mode="person"/>
              <br/>
            </xsl:for-each>
          </td>
          <xsl:if test="position() mod 2 = 0 or position() = last()"> <!-- end the row? -->
            <xsl:text disable-output-escaping="yes">&lt;/tr&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
      </table>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:Lessee">
      <br/>
      <div class="detaillabel">
        Lessee(s):
      </div>
      <table cellpadding="0" cellspacing="0" class="textTealSmall">
        <xsl:for-each select="n:VehicleDetails/j2:Lessee">
          <xsl:if test="position() mod 2 = 1"> <!-- start a new row? -->
            <xsl:text disable-output-escaping="yes">&lt;tr&gt;</xsl:text>
          </xsl:if>
          <td>
            <xsl:for-each select="j2:LesseeParty.Organization">
              <xsl:apply-templates select="." mode="organization"/>
              <br/>
            </xsl:for-each>
            <xsl:for-each select="j2:LesseeParty.Person">
              <xsl:apply-templates select="." mode="person"/>
              <br/>
            </xsl:for-each>
          </td>
          <xsl:if test="position() mod 2 = 0 or position() = last()"> <!-- end the row? -->
            <xsl:text disable-output-escaping="yes">&lt;/tr&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
      </table>
    </xsl:if>
    <br/>
    <xsl:if test="java:size($javaValue) > 0">
      <a name="#recorddetails{$responseId}"/>
      <div class="detaillabel">
        Registration Details:
      </div>
      <table cellpadding="0" cellspacing="0">
        <xsl:call-template name="twoColumnLeft">
          <xsl:with-param name="index1"     select="0"/>
          <xsl:with-param name="javaLabel"  select="$javaLabel"/>
          <xsl:with-param name="javaValue"  select="$javaValue"/>
          <xsl:with-param name="labelWidth" select="'30%'"/>
        </xsl:call-template>
      </table>
    </xsl:if>
    <xsl:if test="java:clear($javaLabel)"/>
    <xsl:if test="java:clear($javaValue)"/>
    <xsl:if test="n:VehicleDetails/j2:Insurance or n:VehicleDetails/n:InsuranceDetails">
      <xsl:if test="n:VehicleDetails/j2:Insurance/j2:InsuranceCarrierName">
        <xsl:if test="java:add($javaLabel, 'Carrier Name')"/>
        <xsl:variable name="value">
          <xsl:for-each select="n:VehicleDetails/j2:Insurance/j2:InsuranceCarrierName">
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:apply-templates select="." mode="TitleCase"/>
          </xsl:for-each>
        </xsl:variable>
        <xsl:if test="java:add($javaValue, $value)"/>
      </xsl:if>
      <xsl:if test="n:VehicleDetails/n:InsuranceDetails/j2:InsuranceCarrierName">
        <xsl:if test="java:add($javaLabel, 'Carrier Name')"/>
        <xsl:variable name="value">
          <xsl:for-each select="n:VehicleDetails/n:InsuranceDetails/j2:InsuranceCarrierName">
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:apply-templates select="." mode="TitleCase"/>
          </xsl:for-each>
        </xsl:variable>
        <xsl:if test="java:add($javaValue, $value)"/>
      </xsl:if>
      <xsl:if test="n:VehicleDetails/j2:Insurance/j2:InsurancePolicyID">
        <xsl:if test="java:add($javaLabel, 'Policy #')"/>
        <xsl:variable name="value">
          <xsl:for-each select="n:VehicleDetails/j2:Insurance/j2:InsurancePolicyID/j2:ID">
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:value-of select="."/>
          </xsl:for-each>
        </xsl:variable>
        <xsl:if test="java:add($javaValue, $value)"/>
      </xsl:if>
      <xsl:if test="n:VehicleDetails/j2:Insurance/j2:InsuranceEffectiveDate">
        <xsl:if test="java:add($javaLabel, 'Effective Date')"/>
        <xsl:variable name="value">
          <xsl:for-each select="n:VehicleDetails/j2:Insurance/j2:InsuranceEffectiveDate">
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:call-template name="dateFormat">
              <xsl:with-param name="date" select="."/>
            </xsl:call-template>
          </xsl:for-each>
        </xsl:variable>
        <xsl:if test="java:add($javaValue, $value)"/>
      </xsl:if>
      <xsl:if test="n:VehicleDetails/j2:Insurance/j2:InsuranceEndDate">
        <xsl:if test="java:add($javaLabel, 'End Date')"/>
        <xsl:variable name="value">
          <xsl:for-each select="n:VehicleDetails/j2:Insurance/j2:InsuranceEndDate">
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:call-template name="dateFormat">
              <xsl:with-param name="date" select="."/>
            </xsl:call-template>
          </xsl:for-each>
        </xsl:variable>
        <xsl:if test="java:add($javaValue, $value)"/>
      </xsl:if>
      <br/>
      <a name="#insurancedetails{$responseId}"/>
      <div class="detaillabel">
        Insurance Details:
      </div>
      <table cellpadding="0" cellspacing="0">
        <xsl:call-template name="twoColumnLeft">
          <xsl:with-param name="index1"     select="0"/>
          <xsl:with-param name="javaLabel"  select="$javaLabel"/>
          <xsl:with-param name="javaValue"  select="$javaValue"/>
          <xsl:with-param name="labelWidth" select="'150px'"/>
        </xsl:call-template>
      </table>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/j2:VehicleBrand or n:VehicleDetails/j2:VehicleInspection">
      <br/>
      <div class="detaillabel">
        Vehicle History:
      </div>
      <div class="textTealSmall">
        <xsl:for-each select="n:VehicleDetails/j2:VehicleBrand">
          <xsl:if test="position() > 1">
            <br/>
          </xsl:if>
          <xsl:for-each select="j2:VehicleBrandCode">
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:value-of select="."/>
          </xsl:for-each>
          <xsl:for-each select="j2:VehicleBrandText">
            <xsl:if test="position() = 1">
              <xsl:if test="../j2:VehicleBrandCode">
                <xsl:text>-</xsl:text>
              </xsl:if>
            </xsl:if>
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:value-of select="."/>
          </xsl:for-each>
          <xsl:text> </xsl:text>
          <xsl:for-each select="j2:VehicleBrandDate">
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:call-template name="dateFormat">
              <xsl:with-param name="date" select="."/>
            </xsl:call-template>
          </xsl:for-each>
          <xsl:text> </xsl:text>
          <xsl:for-each select="j2:VehicleBrander">
            <xsl:if test="position() > 1">
              <br/>
            </xsl:if>
            <xsl:for-each select="j2:BranderID/j2:ID">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:value-of select="."/>
            </xsl:for-each>
            <br/>
            <xsl:for-each select="j2:OrganizationName">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:apply-templates select="." mode="TitleCase"/>
            </xsl:for-each>
            <br/>
            <xsl:apply-templates select="j2:OrganizationLocation/j2:LocationAddress" mode="address2"/>
          </xsl:for-each>
        </xsl:for-each>
        <br/>
        <xsl:if test="n:VehicleDetails/j2:VehicleInspection">
          <xsl:for-each select="n:VehicleDetails/j2:VehicleInspection/j2:ActivityDate">
            <xsl:if test="position() = 1">
              <xsl:text>Inspection Date: </xsl:text>
            </xsl:if>
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:call-template name="dateFormat">
              <xsl:with-param name="date" select="."/>
            </xsl:call-template>
          </xsl:for-each>
          <xsl:text> </xsl:text>
          <xsl:for-each select="n:VehicleDetails/j2:VehicleInspection/j2:VehicleInspectionStationID/j2:ID">
            <xsl:if test="position() = 1">
              <xsl:text>Inspection Station: </xsl:text>
            </xsl:if>
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:value-of select="."/>
          </xsl:for-each>
          <xsl:text> </xsl:text>
          <xsl:for-each select="n:VehicleDetails/j2:VehicleInspection/j2:VehicleInspectionInspectorID/j2:ID">
            <xsl:if test="position() = 1">
              <xsl:text>Inspector ID: </xsl:text>
            </xsl:if>
            <xsl:if test="position() > 1">
              <xsl:text>, </xsl:text>
            </xsl:if>
            <xsl:value-of select="."/>
          </xsl:for-each>
          <br/>
          <xsl:apply-templates select="n:VehicleDetails/j2:VehicleInspection/j2:VehicleInspectionAddress" mode="address2"/>
        </xsl:if>
      </div>
    </xsl:if>
    <xsl:if test="../n:AdditionalInformation">
      <br/>
      <a name="#additionalinformation{$responseId}"/>
      <div class="detaillabel">
        Additional Information:
      </div>
      <div class="textTealSmall">
        <xsl:for-each select="../n:AdditionalInformation/n:StateElement">
          <xsl:if test="position() > 1">
            <br/>
          </xsl:if>
          <xsl:apply-templates select="j2:MetadataFieldName" mode="TitleCase"/>
          <xsl:text>: </xsl:text>
          <xsl:apply-templates select="j2:MetadataFieldValueText" mode="TitleCase"/>
        </xsl:for-each>
      </div>
    </xsl:if>
    <xsl:if test="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:Lien">
      <br/>
      <a name="#lienholderdetails{$responseId}"/>
      <div class="detaillabel">
        Lien Holder Details:
      </div>
      <div class="textTealSmall">
        <xsl:for-each select="n:VehicleDetails/n:VehicleBasicsDetail/n:VehicleTitleDetails/j2:Lien">
          <xsl:for-each select="j2:LienHolder.Organization">
            <xsl:if test="position() > 1">
              <br/>
            </xsl:if>
            Secured Party:
            <xsl:for-each select="j2:OrganizationName">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:apply-templates select="." mode="TitleCase"/>
            </xsl:for-each>
            <br/>
            <xsl:apply-templates select="j2:OrganizationLocation/j2:LocationAddress" mode="address2"/>
          </xsl:for-each>
          <xsl:for-each select="j2:LienHolder.Person">
            <xsl:if test="position() > 1">
              <br/>
            </xsl:if>
            <xsl:apply-templates select="j2:PersonName" mode="nlets"/>
            <br/>
            <xsl:apply-templates select="j2:Residence/j2:LocationAddress" mode="address2"/>
          </xsl:for-each>
        </xsl:for-each>
      </div>
    </xsl:if>
  </xsl:template>
  <xsl:template name="dateFormat">
    <xsl:param name="date"/>
    <xsl:choose>
      <xsl:when test="substring($date, 5, 1) = '-'">
        <xsl:value-of select="substring($date, 6, 2)"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="substring($date, 9, 2)"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="substring($date, 1, 4)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$date"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="html_body">
    <img id="dataserviceimage" src="../../images/nlets.gif" alt="NLETS" />
    <!-- Format header information -->
    <xsl:variable name="headerInformation">
      <xsl:choose>
        <xsl:when test="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseHeader/j:DocumentSource.Organization/j:OrganizationORIID/j:ID">
          <xsl:value-of select="substring(doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseHeader/j:DocumentSource.Organization/j:OrganizationORIID/j:ID,1,2)" />
          <xsl:text> Vehicle Registration</xsl:text>          
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>Vehicle Registration</xsl:text> 
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <!-- Not all of the following will be applicable on a single response -->
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/doj:ResultText">
          <xsl:with-param name="headerInformation" select="$headerInformation" />
    </xsl:apply-templates>
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:ResponseText">
          <xsl:with-param name="headerInformation" select="$headerInformation" />
    </xsl:apply-templates>
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:RegistrationMatches">
          <xsl:with-param name="headerInformation" select="$headerInformation" />
    </xsl:apply-templates>
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:RegistrationStatus/n:StandardResponse">
          <xsl:with-param name="headerInformation" select="$headerInformation" />
    </xsl:apply-templates>
    <xsl:apply-templates
      select="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:RegistrationHistory/n:StandardResponse">
          <xsl:with-param name="headerInformation" select="$headerInformation" />
    </xsl:apply-templates>
  </xsl:template>
  <xsl:template name="html_head_extension">
    <style type="text/css">
      #dataserviceimage
      {
        float: right;
      }
      .caveat
      {
        color: teal; /* Override the color inherited from external stylesheets */
      }
      .filetype
      {
         float: none; /* Override the float setting inherited from external stylesheets */
      }
      .matchNumber
      {
        color: red;
        font-size: 125%;
        font-family: "bookman old style", georgia, "times new roman", times, serif;
        font-weight: bold;
      }
      .newsection
      {
         margin-top: 15px;
      }
      .savexmlbuttonimage
      {
        background-color: transparent;
        border-style: none;
        cursor: pointer;
        float: right;
        height: 24px;
        width: 110px;
      }
      .textBlackLarge
      {
        color: black;
        font-size: 125%;
        font-family: "bookman old style", georgia, "times new roman", times, serif;
        font-weight: bold;
      }
      .textTealMedium
      {
        color: teal;
        font-size: 98%;
        font-family: "bookman old style", georgia, "times new roman", times, serif;
        font-weight: bold;
      }
      .textTealLarge
      {
        color: teal;
        font-size: 125%;
        font-family: "bookman old style", georgia, "times new roman", times, serif;
        font-weight: bold;
      }
      .textTealSmall
      {
        color: teal;
        font-size: 98%;
        font-family: "bookman old style", georgia, "times new roman", times, serif;
      }
    </style>
    <script language="JavaScript">
      function copyxml(){
        document.form1.savexmltext1.value = document.form2.savexmltext2.value;
      }
    </script>
  </xsl:template>
  <xsl:template name="html_title">TIME - Vehicle Registration</xsl:template>
  <xsl:template name="indicatorFormat">
    <xsl:param name="indicator"/>
    <xsl:choose>
      <xsl:when test="$indicator = 'false'">
        <xsl:text>No</xsl:text>
      </xsl:when>
      <xsl:when test="$indicator = 'true'">
        <xsl:text>Yes</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$indicator"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="saveXML">
    <xsl:param name="headerInformation" />
    <xsl:param name="vehicleID" />
    <h1 class="filetype">
      <xsl:value-of select="$headerInformation" />
    </h1>
    <form action="/servlet/SaveXMLResponseServlet" method="post" name="form1" style="margin: 0%">
      <textarea name="saveresponsetext1" id="saveresponsetext1" style="display:none" rows="1" cols="1">
        <xsl:text>VIN_</xsl:text>
        <xsl:choose>
          <xsl:when test="$vehicleID">
            <xsl:value-of select="$vehicleID" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>UNKNOWN</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </textarea>
      <textarea name="savexmltext1" id="savexmltext1" style="display:none" rows="1" cols="1"/>
      <button onclick="copyxml();" name="savexmlbutton1" class="savexmlbuttonimage" type="submit">
        <img alt="Save XML File" src="../../images/savexmlfileicon.gif"/>
      </button>
      <hr style="clear: right;"/>
    </form>
  </xsl:template>
  <xsl:template name="twoColumnLeft">
    <xsl:param name="index1"/>
    <xsl:param name="javaLabel"/>
    <xsl:param name="javaValue"/>
    <xsl:param name="labelWidth"/>
    <xsl:variable name="half" select="floor((java:size($javaLabel) + 1) div 2)"/>
    <xsl:if test="$index1 > 0"> <!-- come from registrationDetailsRight? -->
      <xsl:text disable-output-escaping="yes">&lt;/tr&gt;</xsl:text> <!-- close 0-(n - 1) rows -->
    </xsl:if>
    <xsl:if test="$index1 &lt; $half">
      <xsl:text disable-output-escaping="yes">&lt;tr&gt;</xsl:text> <!-- open 0-n rows -->
      <xsl:text disable-output-escaping="yes">&lt;td class="textTealMedium"</xsl:text>
      <xsl:if test="$labelWidth">
        <xsl:text> width="</xsl:text>
        <xsl:value-of select="$labelWidth"/>
        <xsl:text>"</xsl:text>
      </xsl:if>
      <xsl:text disable-output-escaping="yes">&gt;</xsl:text>
      <xsl:value-of select="java:get($javaLabel, $index1)"/>
      <xsl:text disable-output-escaping="yes">:&lt;/td&gt;</xsl:text>
      <td class="textTealSmall">
        <xsl:value-of select="java:get($javaValue, $index1)"/>
      </td>
      <xsl:call-template name="twoColumnRight">
        <xsl:with-param name="half"       select="$half"/>
        <xsl:with-param name="index1"     select="$index1"/>
        <xsl:with-param name="javaLabel"  select="$javaLabel"/>
        <xsl:with-param name="javaValue"  select="$javaValue"/>
        <xsl:with-param name="labelWidth" select="$labelWidth"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$index1 = 0">
      <xsl:text disable-output-escaping="yes">&lt;/tr&gt;</xsl:text> <!-- close n row -->
    </xsl:if>
  </xsl:template>
  <xsl:template name="twoColumnRight">
    <xsl:param name="half"/>
    <xsl:param name="index1"/>
    <xsl:param name="javaLabel"/>
    <xsl:param name="javaValue"/>
    <xsl:param name="labelWidth"/>
    <xsl:param name="index2" select="$index1 + $half"/>
    <xsl:if test="$index2 &lt; java:size($javaValue)">
      <xsl:text disable-output-escaping="yes">&lt;td class="textTealMedium"</xsl:text>
      <xsl:if test="$labelWidth">
        <xsl:text> width="</xsl:text>
        <xsl:value-of select="$labelWidth"/>
        <xsl:text>"</xsl:text>
      </xsl:if>
      <xsl:text disable-output-escaping="yes">&gt;</xsl:text>
      <xsl:value-of select="java:get($javaLabel, $index2)"/>
      <xsl:text disable-output-escaping="yes">:&lt;/td&gt;</xsl:text>
      <td class="textTealSmall">
        <xsl:value-of select="java:get($javaValue, $index2)"/>
      </td>
      <xsl:call-template name="twoColumnLeft">
        <xsl:with-param name="index1"     select="$index1 + 1"/>
        <xsl:with-param name="javaLabel"  select="$javaLabel"/>
        <xsl:with-param name="javaValue"  select="$javaValue"/>
        <xsl:with-param name="labelWidth" select="$labelWidth"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
</xsl:transform>