<?xml version="1.0"?>
<xsl:transform
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<xsl:include href="../../util.xsl"/>
	<xsl:include href="../cib_ncic_common.xsl"/>
	
	<xsl:template match="doj:Result">
		<xsl:param name="fileName" select="."/>
		
	    <xsl:choose>
	      <xsl:when test="$from='ebc'">
	        <xsl:call-template name="html_main">
				<xsl:with-param name="fileName" select="$fileName"/>
			</xsl:call-template>
	      </xsl:when>
	      <xsl:otherwise>
	        <xsl:call-template name="html_head_extension" />
	        <!-- This prevents the solid black lines from displaying in online validations (FB 189) -->
	        <div id="container">
	        	<xsl:call-template name="html_body" />
	        </div>
	      </xsl:otherwise>
	    </xsl:choose>
	</xsl:template>
	
	<xsl:template name="html_body">
		<xsl:param name="fileName"/>
		<xsl:choose>
			<xsl:when test="FormattedResultText">
				<xsl:apply-templates select="FormattedResultText"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="doj:ResultText"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="child::node()/doj:InquiryResult"/>
	</xsl:template>
	
	<xsl:template name="cibLogo">
		<table width="100%" >
			<tr>
				<td align="right">
					<img src="../../images/cib3_small.png" alt="CIB Logo" width="50" height="50"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<!-- ##################################################### -->
	<!-- #  REUSABLE MATCH TEMPLATES FOR ALL FILE TYPES   	 # -->
	<!-- ##################################################### -->
	
	<!-- Record Details section  -->
	<xsl:template match="doj:InquiryResult" mode="record_details_all">
		<br/>
		<xsl:choose>
			<xsl:when test="contains(cib-ext:RecordTypeText,'WANTED')">
				<a name="warrantdetails{$responseId}">
					<span class="detaillabel uppercase">Warrant Details:</span>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<a name="recorddetails{$responseId}">
					<span class="detaillabel uppercase">Record Details:</span>
				</a>
			</xsl:otherwise>
		</xsl:choose>
		<table>
			<!-- System Id and NIC# -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'System Ident #:'"/>
				<xsl:with-param name="value1" select="cib-ext:EnteringAgencyDetails/cib-ext:SystemControlNumberID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'NCIC #:'"/>
				<xsl:with-param name="value2" select="cib-ext:EnteringAgencyDetails/j:DocumentFileControlID/j:ID"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
	
			<!-- Agency Case and Unit # -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Agency Case #:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="." mode="agency_case_number"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Unit #:'"/>
				<xsl:with-param name="value2" select="cib-ext:EnteringAgencyDetails/j:DocumentSubmitter.Organization/j:OrganizationLocalID/j:ID"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		
			<!-- Entered By and Date --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Entered By:'"/>
				<xsl:with-param name="value1" select="cib-ext:EnteringAgencyDetails/j:DocumentSubmitter.Person/j:PersonAssignedIDDetails/j:PersonHumanResourcesID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Entry Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="cib-ext:EnteringAgencyDetails/j:DocumentFiledDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		
			<!-- Update By and Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Updated By:'"/>
				<xsl:with-param name="value1" select="cib-ext:EnteringAgencyDetails/cib-ext:DocumentLastModifiedPerson/j:PersonHumanResourcesID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel  width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Update Date:'"/>
				<xsl:with-param name="value2">
				<xsl:apply-templates 
						select="cib-ext:EnteringAgencyDetails/j:DocumentLastModifiedDate" 
						mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		
			<!-- Validator and Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Validator:'"/>
				<xsl:with-param name="value1" select="cib-ext:EnteringAgencyDetails/cib-ext:ValidationPersonText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Validated Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="cib-ext:EnteringAgencyDetails/cib-ext:ValidationDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
	
			<!-- Linking ORI and Linking Case -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Linking ORI:'"/>
				<xsl:with-param name="value1" select="cib-ext:LinkageAgency/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Linking Case #:'"/>
				<xsl:with-param name="value2" select="cib-ext:LinkageAgency/j:CaseDocketID/j:ID"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			
			<!-- Public Dissemination and Date -->
			<xsl:if test="../../doj:VehicleResponse|../../doj:ArticleResponse" >
			       <xsl:call-template name="ConditionalRow">
				       <xsl:with-param name="label1" select="'Public Disseminations:'"/>
				       <xsl:with-param name="value1" select="cib-ext:PublicDisseminationStatus/cib-ext:PublicDisseminationStatusText"/>
				       <xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				       <xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				       <xsl:with-param name="label2" select="'Date:'"/>
				       <xsl:with-param name="value2">  
 				       		<xsl:apply-templates select="cib-ext:PublicDisseminationStatus/cib-ext:PublicDisseminationStatusDate" mode="FormatFullDateAsMMDDYYYY"/>
 				       </xsl:with-param>
  				       <xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				       <xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/> 
			       </xsl:call-template>
			</xsl:if>
		</table>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="agency_case_number">
		<!-- sex offender -->
	 	<!-- probation/parole -->	
 		<!-- wanted person -->	
		<!-- protection order -->
		<!-- missing person --> 
		<!-- stolen/felony vehicle -->
		<!-- stolen parts -->
		<!-- stolen license plates -->
		<xsl:if test="child::node()/j:ActivityCrimeCase/j:CaseDocketID">	
			<xsl:value-of select="child::node()/j:ActivityCrimeCase/j:CaseDocketID/j:ID"/>
		</xsl:if>
	</xsl:template>

	<!-- File Type Header -->
	<xsl:template name="file_type_header_all">
		<xsl:param name="fileLogoPic" />
		<xsl:param name="flagPic1" />
		<xsl:param name="flagPic2" />
		<xsl:param name="flagPic3" />
		<!-- Data Service Logo -->	
		<xsl:call-template name="cibLogo"/>
		<!-- File Type Header Section -->
		<table>
			<tr>
				<td class="width10percent">
					<!-- Display File Type Logo -->	
					<img src="{substring-before($fileLogoPic,'-')}" alt="{substring-after($fileLogoPic,'-')}"/>
				</td>
				<td class="width90percent">
					<table> 
						<tr><td>
							<!-- File Description --> 	
							<span class="filetype">
								<xsl:apply-templates select="cib-ext:RecordTypeText" mode="TitleCase"/>			
							</span>
							<!-- File Flags Images -->
							<xsl:text>&#160;</xsl:text>
							<xsl:if test="$flagPic1 != '' ">
								<img src="{substring-before($flagPic1,'-')}" alt="{substring-after($flagPic1,'-')}"/>
								<xsl:text>&#160;</xsl:text>
							</xsl:if>
							<xsl:if test="$flagPic2 != '' ">
								<img src="{substring-before($flagPic2,'-')}" alt="{substring-after($flagPic2,'-')}"/>
								<xsl:text>&#160;</xsl:text>
							</xsl:if>
							<xsl:if test="$flagPic3 != '' ">
								<img src="{substring-before($flagPic3,'-')}" alt="{substring-after($flagPic3,'-')}"/>
								<xsl:text>&#160;</xsl:text>
							</xsl:if>
						</td></tr>
						<tr><td>	
							<!-- Caution Text -->
							<xsl:choose>
								<xsl:when test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator='true' or cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator='true'">
									<!--  do not display caution text -->
								</xsl:when>
								<xsl:otherwise>
									<xsl:apply-templates select="cib-ext:FileTypeDetails/cib-ext:CautionIndicator"/>
								</xsl:otherwise>
							</xsl:choose>
							
							<!-- Caveat Text -->
							<xsl:apply-templates select="j:CaveatText" mode="TopCaveats"/>
							
							<!-- Protection Order specifics --> 	
							<xsl:apply-templates select="j:ProtectionOrder/j:CourtOrderDesignatedSubject/cib-ext:PersonFirearmProhibitedText"/>
							<xsl:apply-templates select="j:ProtectionOrder/cib-ext:ProtectionOrderConditionText"/>
							
							<!-- Missing Person specifics -->	
							<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonCircumstanceText"/>
							<xsl:if test="cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonDisappearanceTypeCode='AA' or
							    cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonDisappearanceTypeCode='CA'">
								<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonDisappearanceTypeText"/>
							</xsl:if>
												
							<!-- Caveat Text Common for  all Property Files -->
							
							<xsl:if test="cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
								<div class="caveat">
									<xsl:text>**&#32;USE CAUTION - HOLD FOR LATENT FINGERPRINTS&#32;**</xsl:text> 
								</div>
							</xsl:if>
							<xsl:if test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'">
								<div class="caveat">
									<xsl:text>**&#32;USE CAUTION - ARMED AND DANGEROUS&#32;**</xsl:text>
								</div>
							</xsl:if>
							
							<xsl:if test="(cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true' 
								   or cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true') 
								   and cib-ext:MiscellaneousText">
								<a href="#remarks" class="remarks">See Remarks</a>
							</xsl:if>	
						
							<!-- Notify Agency ORI -->
							<xsl:apply-templates select="cib-ext:NotifyOriginatingAgencyIndicator"/>
							
							<!-- All files -->
							<xsl:apply-templates select="j:CaveatText" mode="BottomCaveats"/>
							
							<!-- WP specific  -->
							<xsl:apply-templates select="cib-ext:DetainerDetails"/>
						 </td></tr>
					</table>
				</td>
			</tr>
		</table>
		<!-- Horizontal Line -->
		<hr/>
	</xsl:template>

	<xsl:template match="doj:InquiryResult" mode="property_details_all"> 
		<table>
			<!-- Date of Offense, Date of Theft, Date of Lost or Date of Recovery: -->
			<xsl:call-template name="ConditionalRow"> 
				<xsl:with-param name="label1">
					<xsl:choose>
						<xsl:when test="cib-ext:FileTypeDetails/cib-ext:StolenIndicator = 'true'">
							<xsl:text>Date of Theft:</xsl:text>
						</xsl:when>
						<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LostIndicator = 'true'">
							<xsl:text>Date of Lost:</xsl:text>
						</xsl:when>
						<xsl:when test="cib-ext:FileTypeDetails/cib-ext:RecoveredIndicator = 'true'">
							<xsl:text>Date of Recovery:</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Date of Offense:</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="child::node()/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width75percent'"/>
			</xsl:call-template>
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	</xsl:template>	
	
	<xsl:template name="EnteringAgency">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Entering Agency:'"/>
			<xsl:with-param name="value1">
				<xsl:value-of select="cib-ext:EnteringAgencyDetails/j:DocumentSubmitter.Organization/j:OrganizationORIID/j:ID"/>
				<xsl:text>&#160;-&#160;</xsl:text>
				<xsl:apply-templates select="cib-ext:EnteringAgencyDetails/j:DocumentSubmitter.Organization/j:OrganizationName" mode="TitleCase"/>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
			<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
		</xsl:call-template>		
	</xsl:template>	
	
	<xsl:template match="cib-ext:RecoveryDetails" mode="recovery_all"> 
		<table>
			<!-- Date of Recovery: -->
			<xsl:choose>
				<xsl:when test="j:ActivityDate/@j:commentText='Cleared'">
					<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Cleared Date:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Located Date:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- Recovering Agency ORI: --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Recovering Agency ORI:'"/>
				<xsl:with-param name="value1" select="j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Recovering Agency Case: --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Recovering Agency Case:'"/>
				<xsl:with-param name="value1" select="j:CaseDocketID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Extradition: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Extradition:'"/>
				<xsl:with-param name="value1" select="cib-ext:WarrantExtraditionText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Reason for Record Removal: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Reason for Person Record Removal:'"/>
				<xsl:with-param name="value1" select="cib-ext:BenefitsData/cib-ext:RecordRemovalReasonText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Date of Record Removal: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date of Record Removal:'"/>
				<xsl:with-param name="value1" select="cib-ext:BenefitsData/cib-ext:RecordRemovalDate"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Disposition: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Disposition:'"/>
				<xsl:with-param name="value1" select="j:Disposition/j:DispositionText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Person Armed: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Person Armed:'"/>
				<xsl:with-param name="value1" select="cib-ext:BenefitsData/cib-ext:PersonArmedCode"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Wanted/Missing Person Hit Results: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Wanted/Missing Person Hit Results:'"/>
				<xsl:with-param name="value1" select="cib-ext:BenefitsData/cib-ext:HitResultsText/cib-ext:HitResultsText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Number of Persons Apprehended: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Number of Persons Apprehended:'"/>
				<xsl:with-param name="value1" select="cib-ext:BenefitsData/cib-ext:IncidentPersonApprehendedQuantity"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Number of Missing Persons Found: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Number of Missing Persons Found:'"/>
				<xsl:with-param name="value1"> 
					<xsl:apply-templates select="cib-ext:BenefitsData/cib-ext:IncidentMissingPersonsFound"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Value of Recovered Property: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Value of Recovered Property:'"/>
				<xsl:with-param name="value1"> 
					<xsl:apply-templates select="cib-ext:BenefitsData/cib-ext:IncidentRecoveredProperty/j:PropertyValueDetails"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Value of Other Recovered Property: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Value of Other Recovered Property:'"/>
				<xsl:with-param name="value1"> 
					<xsl:apply-templates select="cib-ext:BenefitsData/cib-ext:IncidentRecoveredOtherProperty/j:PropertyValueDetails"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- Value of Recovered Contraband: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Value of Recovered Contraband:'"/>
				<xsl:with-param name="value1"> 
					<xsl:apply-templates select="cib-ext:BenefitsData/cib-ext:IncidentRecoveredContrabandProperty/j:PropertyValueDetails"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>	
	
	<xsl:template match="cib-ext:IncidentMissingPersonsFound">
		<xsl:value-of select="cib-ext:JuvenileIndexedQuantity"/>
		<xsl:value-of select="cib-ext:JuvenileNotIndexedQuantity"/>
		<xsl:value-of select="cib-ext:OtherPersonsIndexedQuantity"/>
		<xsl:value-of select="cib-ext:OtherPersonsIndexedQuantity"/>
	</xsl:template>
	
	<xsl:template match="j:PropertyValueDetails">
		<xsl:value-of select="j:PropertyRecoveredValue/j:PropertyValueAmount"/>
	</xsl:template>
	
	<xsl:template match="j:CaveatText" mode="TopCaveats">
		<!-- Displays caveats which belong on the top of a response -->
        <xsl:if test="not(starts-with(.,'Verify') and contains(.,'Immediately With ORI'))">
        	<div class="caveat">
			   <xsl:text>**&#32;</xsl:text>
			   <xsl:value-of select="."/>
			   <xsl:text>&#32;**</xsl:text>
			</div>
        </xsl:if>
      </xsl:template>
      
	 <xsl:template match="j:CaveatText" mode="BottomCaveats">
     	<!-- Displays caveats which belong on the bottom of a response -->
        <xsl:if test="starts-with(.,'Verify') and contains(.,'Immediately With ORI')">
            <div class="verify">
				<xsl:text>*****&#160;</xsl:text>
				<xsl:value-of select="."/>
				<xsl:text>&#160;*****</xsl:text>
			</div>
        </xsl:if>
    </xsl:template>
    
</xsl:transform>
