<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/>
	
	<!--  CIB - CONCEALED CARRY RECORD -->
	<!-- ############  -->
	<!-- main template -->
	<!-- ############  -->
	<xsl:template match="/doj:CIBResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - CIB Concealed Carry</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="j:Person" mode="subject_details_all"/>
		<xsl:apply-templates select="j:Person/j:PersonAssignedIDDetails/j:PersonOtherID" mode="ccwpermit"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="j:Person" mode="alias"/>
		
		<xsl:apply-templates select="." mode="record_details_ccw"/>
	</xsl:template>
	
	<!-- ###########################  -->
	<!-- File Type Header	 		  -->
	<!-- ###########################  -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.  -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:text>../../images/ccwGun.jpg</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Concealed Carry</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img border="0" src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width80percent" align="center">
					<xsl:apply-templates select="j:Person/j:PersonAssignedIDDetails/j:PersonOtherID" mode="ccwpermit_record_details"/>
				</td>
				<td class="width10percent"></td> <!-- on purpose left empty -->
			</tr>
		</table>
		<br/>
	</xsl:template>
	
	<!-- Concealed Carry Permit - Record Details Section -->
	<xsl:template match="j:PersonOtherID" mode="ccwpermit_record_details">
		<xsl:variable name="permit_type">
			<xsl:choose>
				<xsl:when test="contains(j:IDTypeText, 'LICENSE')">
					<xsl:text>LICENSE</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>PERMIT</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<table>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'STATUS:'"/>
				<xsl:with-param name="value1" select="j:IDStatus/j:StatusText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width40percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width60percent'"/>
			</xsl:call-template>
			<xsl:choose>
				<xsl:when test="$permit_type='LICENSE'">
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'LICENSE NUMBER:'"/>
						<xsl:with-param name="value1">
							<xsl:for-each select="j:ID">
								<xsl:if test="@j:commentText='DOJ'">
									<xsl:value-of select="."/>
									<xsl:if test="../@j:commentText">
										<xsl:text> - </xsl:text>
										<xsl:value-of select="../@j:commentText"/>
									</xsl:if>
								</xsl:if>
							</xsl:for-each>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width40percent'"/>
						<xsl:with-param name="value_class_name1" select="'detailvalue width60percent'"/>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'ISSUED DATE:'"/>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="j:IDEffectiveDate" mode="FormatFullDateAsMMDDYYYY"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width40percent'"/>
						<xsl:with-param name="value_class_name1" select="'detailvalue width60percent'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'CERTIFICATION NUMBER:'"/>
						<xsl:with-param name="value1">
							<xsl:value-of select="j:ID"/>
							<xsl:if test="@j:commentText">
								<xsl:text> - </xsl:text>
								<xsl:value-of select="@j:commentText"/>
							</xsl:if>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width40percent'"/>
						<xsl:with-param name="value_class_name1" select="'detailvalue width60percent'"/>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'DETERMINATION DATE:'"/>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="j:IDEffectiveDate" mode="FormatFullDateAsMMDDYYYY"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width40percent'"/>
						<xsl:with-param name="value_class_name1" select="'detailvalue width60percent'"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'EXPIRATION DATE:'"/>
				<xsl:with-param name="value1">
					 <xsl:apply-templates select="j:IDExpirationDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width40percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width60percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<!-- Concealed Carry Permit -->
	<xsl:template match="j:PersonOtherID" mode="ccwpermit">
		<br/>
		<table>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'TYPE:'"/>
				<xsl:with-param name="value1" select="j:IDTypeText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'WEAPON:'"/>
				<xsl:with-param name="value1">
					<xsl:choose>
						<xsl:when test="j:IDTypeDescriptionText/@j:commentText='weapon'">
							<xsl:value-of select="j:IDTypeDescriptionText"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text></xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
			<!-- WI-CWQ will not have SSN
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'SOCIAL SECURITY #:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="../j:PersonSSNID/j:ID">
						<xsl:apply-templates select="." mode="FormatSSN"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template> -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'ISSUING AGENCY:'"/>
				<xsl:with-param name="value1" select="j:IDIssuingAuthorityText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width70percent'"/>
			</xsl:call-template>
		</table>
		<table>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'LOCAL AGENCY LICENSE-CERTIFICATION #:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="j:ID">
						<xsl:if test="@j:commentText='Other Agency'">
							<xsl:value-of select="."/>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width40percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width60percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="record_details_ccw">
		<br/>
		<a name="recorddetails{$responseId}">
			<span class="detaillabel uppercase">Record Details:</span>
		</a>
		<table>
			<!-- System Id -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'System Ident #:'"/>
				<xsl:with-param name="value1" select="cib-ext:EnteringAgencyDetails/cib-ext:SystemControlNumberID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
</xsl:stylesheet>