<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <xsl:import href="person_common.xsl"/>
	
	<!--  CIB - PROBATION/PAROLE RECORD -->
	<!-- ############### -->
	<!-- main template   -->
	<!-- ############### -->
	<xsl:template match="/doj:CIBResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - CIB Probation and Parole</xsl:text> 
	</xsl:template>
	
   	<!-- ################### -->
	<!-- doj:InquiryResult   -->
	<!-- ################### -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="j:Supervision/j:SupervisionSubject" mode="subject_details_all"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="." mode="record_details_all"/>	 	
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file >-->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:text>../../images/probation.gif</xsl:text>  
		<xsl:text>-</xsl:text>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<xsl:apply-templates select="j:Supervision/j:SupervisionSubject" mode="subject_caution_all"/>
		<!-- Probation/Parole Details-->	
		<br/>
		<table>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date of Release:'"/>
				<xsl:with-param name="value1">
				<xsl:apply-templates select="j:Supervision/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
			</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Conviction Statute:'"/>
				<xsl:with-param name="value1" select="j:Supervision/j:ActivityCrimeCase/j:CaseCharge/j:ChargeStatute/j:StatuteCodeID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervising Officer Code:'"/>
			<xsl:with-param name="value1" select="j:Supervision/j:SupervisionOfficial/j:PersonAssignedIDDetails/j:PersonHumanResourcesID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervising Phone Number:'"/>
				<xsl:with-param name="value1" select="j:Supervision/j:SupervisionOfficial/j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue defaultcase width70percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>

</xsl:transform>
