<?xml version="1.0"?>

<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/> 

	<!--  CIB - SEX OFFENDER RECORD -->
	<!-- ############## -->
	<!-- main template  -->
	<!-- ############## -->
	<xsl:template match="/doj:CIBResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - CIB Sex Offender</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="subject_details_all"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="FBItoSMT"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="DLtoDNALoc"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all" >
			<xsl:with-param name="parent" select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender"/>
		</xsl:call-template>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="alias"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/cib-ext:RegisteredOffenderEmployer" />
		<xsl:apply-templates select="." mode="record_details_all"/>	
		<xsl:apply-templates select="." mode="record_details"/>	 	
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="fileLogoPicture">
		<xsl:text>../../images/sexOffenderCIB.gif</xsl:text>
		<xsl:text>-</xsl:text>
		<xsl:text>Registered Sex Offender</xsl:text>
	</xsl:template>

	<xsl:template match="doj:InquiryResult" mode="file_type_details"> 
		<!-- Subject Caution Text -->
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="subject_caution_all"/>
		<!-- Sex Offender Details-->	
		<table>
			<!--  Commented the following code as per CIB does not want to see -->
			<!-- 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Status:'"/>
				<xsl:with-param name="value1" 
					select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/cib-ext:RegisteredOffenderStatusText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width50percent'"/>
			</xsl:call-template>
			-->
			<!--  I did not find sexual predator on cib responses, should we remove this  ? -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Sexual Predator:'"/> 
				<xsl:with-param name="value1">
					<xsl:choose>
						<xsl:when test="cib-ext:SexualPredatorIndicator='true'">
							<span class="medicalvalue">Yes</span> 
						</xsl:when>
						<xsl:when test="cib-ext:SexualPredatorIndicator='false'">
							<span class="medicalvalue">No</span> 
						</xsl:when>
					</xsl:choose>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width50percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>

	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!-- Client Case # and Two Strike Indicator:?  -->
			<!-- SOR Effect Date and  Juvenile Registration -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'SOR Effect Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates 
						select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:RegisteredOffenderStartDate" 
						mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Juvenile Registration:'"/>
				<xsl:with-param name="value2" select="cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- SOR End Date  and Life Registration -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'SOR End Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates 
						select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:RegisteredOffenderEndDate" 
						mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Life Registration:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates 
						select="cib-ext:FileTypeDetails/cib-ext:LifeRegistrationIndicator" 
						mode="FormatBooleanAsYesNo">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Conviction Resulting in Registration and Release Detainer Indicator:-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Conviction Resulting in Registration:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates 
						select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:RegisteredOffenderEndDate" 
						mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>					
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Release Detainer Indicator:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates 
						select="cib-ext:FileTypeDetails/cib-ext:ReleaseToDetainerIndicator" 
						mode="FormatBooleanAsYesNo">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Date of Conviction-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Conviction Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates 
						select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:RegisteredOffenderEntryDate" 
						mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Place of Crime ?-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Place of Crime:'"/>
				<xsl:with-param name="value1" select="''"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="cib-ext:RegisteredOffenderEmployer">
		<br/>
		<xsl:if test="position() = 1">
			<span class="detaillabel uppercase">Employers:</span>
		</xsl:if>		
		<table>
		  <!--Employer Name-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Employer Name:'"/>
				<xsl:with-param name="value1" select="j:OrganizationName"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
            <!--Employer Address-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Employer Address:'"/>
				<xsl:with-param name="value1">
				<xsl:for-each select="j:OrganizationLocation/j:LocationAddress">
					<xsl:value-of select=" j:LocationStreet/j:StreetFullText"/>
					<xsl:text>,&#32;</xsl:text>
					<xsl:value-of select=" j:LocationCityName"/>
					<xsl:if test="j:LocationCityName">
						<xsl:text>&#32;</xsl:text>
					</xsl:if>
					<xsl:value-of select="j:LocationStateName"/>
					<xsl:if test="j:LocationStateName">
						<xsl:text>&#32;</xsl:text>
					</xsl:if>
					<xsl:value-of select="j:LocationPostalCodeID/j:ID "/>
					<xsl:if test="j:LocationPostalCodeID/j:ID ">
						<xsl:text>&#32;</xsl:text>
					</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!--Employer Address Type-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Employer Address Type:'"/>
				<xsl:with-param name="value1" select="j:OrganizationLocation/j:ResidenceTypeText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Employer Telephone:'"/>
				<xsl:with-param name="value1" select=" j:PrimaryContactInformation/j:ContactTelephoneNumber/
				j:TelephoneNumberFullID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>	
		   	
</xsl:transform>