<?xml version="1.0"?>
<xsl:transform
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	
	<xsl:import href="../common.xsl"/>

	<!-- ##################################################### -->
	<!-- #  REUSABLE MATCH TEMPLATES FOR ALL FILE TYPES      # -->
	<!-- ##################################################### -->
	<xsl:template match="cib-ext:NotifyOriginatingAgencyIndicator">
		<div class="caveat">
			<xsl:text>**&#160;NOTIFY ORI/</xsl:text>
			<xsl:apply-templates select="." mode="FormatBooleanAsYesNo"/>
			<xsl:text>&#160;**</xsl:text>
		</div>
	</xsl:template>  
	
	<!-- REMARKS (Miscellaneous) -->
	<xsl:template match="cib-ext:MiscellaneousText" mode="remarks_all">
		<xsl:if test="position() = 1">	
			<br/>
			<a name="remarks{$responseId}"></a>
		</xsl:if>	
		<table>		
			<tr>
				<td class="detaillabel width25percent">
					<xsl:if test="position() = 1">	
						<xsl:text>REMARKS:</xsl:text>
					</xsl:if>				
				</td>
				<td class="detailvalue width75percent">
					<!-- <xsl:apply-templates select="." mode="TitleCase"/> -->
					<xsl:value-of select="." />
				</td>
			</tr>			
		</table>
	</xsl:template>
	
	<!-- Additional Information (ALL FILE TYPES NCIC/CIB) -->	
	<xsl:template match="cib-ext:AdditionalInformation" >           
	 	<table>
			<tr>
				<td class="detaillabel uppercase">ADDITIONAL DATA:</td>
			</tr>
	 
			 <xsl:for-each select="cib-ext:AdditionalData"> 
			 		<tr>
			 			<td class="detailsublabel width25percent"><xsl:value-of select="j:MetadataFieldName"/></td>
			 			<td class="detailvalue width75percent"><xsl:value-of select="j:MetadataFieldValueText"/></td>
			 		</tr>
			 </xsl:for-each>
	 	</table>
	</xsl:template>	
	
	<xsl:template match="cib-ext:CautionIndicator">
		<xsl:if test=". = 'true'">
			<div class="caution">** USE CAUTION **</div>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="cib-ext:RecordTypeText" mode="TitleCase">
		<xsl:call-template name="TitleCase">
			<xsl:with-param name="text" select="translate(., $AlphaUpperCase, $AlphaLowerCase)"/>
		</xsl:call-template>
		<!--  Protection Order -->
		<xsl:if test="../j:ProtectionOrder/j:ActivityCrimeCase/j:CaseCharge/j:ChargeStatute/j:StatuteCodeID/j:ID">
			<xsl:text>&#32;-&#32;</xsl:text>
			<xsl:value-of select="../j:ProtectionOrder/j:ActivityCrimeCase/j:CaseCharge/j:ChargeStatute/j:StatuteCodeID/j:ID"/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="j:CaveatText" mode="DetainerCaveats"> 
		<!-- Displays caveats for detainers on person files  -->
        <div class="caveat">
		   <xsl:text>**&#32;</xsl:text>
		   <xsl:value-of select="."/>
		   <xsl:text>**&#32;</xsl:text>
		</div>
    </xsl:template>
     
    <xsl:template match="j:MissingPersonCircumstanceText | j:MissingPersonDisappearanceTypeText">
		<div class="caveat">
			<xsl:text>**&#32;</xsl:text>
			<xsl:value-of select="."/>
			<xsl:text>&#32;**</xsl:text>
		</div>
	</xsl:template>
	
	<xsl:template match="j:RegistrationJurisdictionName | j:VehicleRegistrationPlateTypeText">
		<xsl:apply-templates select="." mode="TitleCase"/>
	</xsl:template> 
	
	<!-- Investigative Interest currently applies to NCIC responses, 
		however CIB may add this transaction in the future -->
	<xsl:template match="cib-ext:InvestigativeInterestDetails">
		<br/>
		<xsl:if test="position() = 1">
			<span class="detaillabel uppercase">Investigative Interest:</span> 
		</xsl:if>
		<table>
			<!-- Agency ORI and Name: -->
			<xsl:if test="j:Organization">
				<tr><td colspan="2" class="detailvalue">
					<xsl:value-of select="j:Organization/j:OrganizationORIID/j:ID"/>
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="j:Organization/j:OrganizationName"/>
				</td></tr>
			</xsl:if>  
			<!-- Telephone Number and Interest Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Telephone Number:'"/> 
				<xsl:with-param name="value1" select="j:Organization/j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Date of Interest:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- case number -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Investigative Case #:'"/> 
				<xsl:with-param name="value1" select="j:CaseDocketID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- miscellaneous -->
			<xsl:if test="cib-ext:MiscellaneousText">
				<tr>
					<td class="detailvalue" style="width:25%">
						<xsl:text>Miscellaneous:&#160;&#160;</xsl:text>
					</td>
					<td class="detailvalue" colspan="3">
						<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="TitleCase"/>
					</td>
				</tr>
			</xsl:if>
		</table>
	</xsl:template>
	
	<xsl:template name="PersonWithInformation">
		<xsl:if test="cib-ext:MissingPersonIncident/cib-ext:PersonWithInformation">
			<a name="personWithInfo{$responseId}"></a>
			<table>
			<tr><td><br /></td></tr>
			<tr>
				<td class="detaillabel uppercase">Persons With Information:</td>
			</tr>
			<xsl:for-each select="cib-ext:MissingPersonIncident/cib-ext:PersonWithInformation">
				<!-- Base/primary data such as name, DOB, etc. -->
				<tr><td class="detailvalue">
					<!--  name is required -->
					<xsl:apply-templates select="j:PersonName" mode="alias"/>
					<!--  Sex is optional in NCIC -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonSexText">
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonSexText" mode="TitleCase"/>
					</xsl:if>
					<!-- race is optional  -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonRaceText">
						<xsl:choose>
							<xsl:when test="j:PersonPhysicalDetails/j:PersonSexText">
								<xsl:text>/</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>&#160;&#160;</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonRaceText" mode="TitleCase"/>
					</xsl:if>
					<!-- Ethnicity is optional.  Text is set in NCIC Handler's stylesheet (CommonResponse.xsl) 
					Per CIB we only display if Hispanic Or Latino.  If NCIC sent N this is Not Hispanic or Latino-->
					<xsl:if test="starts-with(j:PersonSocialDetails/j:PersonEthnicityText,'Hispanic')">
						<xsl:choose>
							<xsl:when test="j:PersonPhysicalDetails/j:PersonRaceText">
								<xsl:text>/</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>&#160;&#160;</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:apply-templates select="j:PersonSocialDetails/j:PersonEthnicityText" mode="TitleCase"/>
					</xsl:if>
					
					<!-- Birth date is optional -->
					<xsl:if test="cib-ext:PersonBirthDateText">
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates select="cib-ext:PersonBirthDateText"/>
					</xsl:if>
					<!-- Height and weight -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHeightMeasure">
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightMeasure,1,1)" />
						<xsl:text>'</xsl:text>
						<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightMeasure,2,2)" />
						<xsl:text>"</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure">
						<xsl:choose>
						       <xsl:when test="j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure='UNK'">
						              <xsl:text>&#160;&#160;</xsl:text>
						              <xsl:text>Unknown Height</xsl:text> 
						       </xsl:when>
						       <xsl:otherwise>
									<xsl:text>&#160;&#160;</xsl:text>
									<xsl:value-of select="substring(j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure,1,1)" />
									<xsl:text>'</xsl:text>
									<xsl:value-of select="substring(j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure,2,2)" />
									<xsl:text>"</xsl:text>
						       </xsl:otherwise>
						</xsl:choose>
					</xsl:if> 			
					<xsl:if test="j:PersonPhysicalDetails/j:PersonWeightMeasure">
						<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonWeightMeasure"/>
						<xsl:text>&#160;lbs</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure">
						<xsl:choose>
						       <xsl:when test="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure='UNK'">
						              <xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						              <xsl:text>Unknown Weight</xsl:text> 
						       </xsl:when>
						       <xsl:otherwise>
						              <xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						              <xsl:value-of select="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure"/>
						              <xsl:text>&#160;lbs</xsl:text>
						       </xsl:otherwise>
						</xsl:choose>
					</xsl:if>
					<!-- Eye color is optional -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonEyeColorText">
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonEyeColorText"/>
						<xsl:text>&#160;Eyes</xsl:text>
					</xsl:if>
					<!-- Hair color is optional -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHairColorText">
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonHairColorText"/>
						<xsl:text>&#160;Hair</xsl:text>
					</xsl:if>
					<!-- Skintone is optional -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonSkinToneText">
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:text>Skintone:&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonSkinToneText"/>
					</xsl:if>
				</td></tr>
				<!-- Social Security numbers (base and supplementals) are optional -->
				<xsl:if test="j:PersonAssignedIDDetails/j:PersonSSNID">
					<tr><td class="detailvalue">
						<xsl:text>Social Security #:&#160;&#160;</xsl:text>
						<xsl:apply-templates select="j:PersonAssignedIDDetails/j:PersonSSNID/j:ID" mode="FormatSSN"/>
						<xsl:for-each select="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
							<xsl:text>,&#32;</xsl:text>
							<xsl:apply-templates select="." mode="FormatSSN"/>
						</xsl:for-each>
					</td></tr>
				</xsl:if>
				<!-- SMTs (base and supplementals) are optional -->
				<xsl:if test="j:PersonPhysicalDetails/j:PersonPhysicalFeature">
					<tr><td class="detailvalue">
						<xsl:text>Scarmark:&#160;&#160;</xsl:text>
						<xsl:for-each select="j:PersonPhysicalDetails/j:PersonPhysicalFeature/j:PhysicalFeatureTypeText">
							<xsl:apply-templates select="." mode="TitleCase"/>
							<xsl:if test="position() != last()">
								<xsl:text>,&#32;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</td></tr>
				</xsl:if>
				<!-- Other alias data -->
				<xsl:if test="j:PersonAlias">
					<tr><td class="detailvalue">
						<xsl:text>Alias Data:&#160;&#160;</xsl:text>
						<!-- PersonName -->
						<xsl:for-each select="j:PersonAlias/j:PersonName">
							<xsl:apply-templates select="." mode="alias"/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#32;</xsl:text>
							</xsl:if>
						</xsl:for-each>
						<xsl:if test="j:PersonAlias/j:PersonName and j:PersonAlias/cib-ext:PersonBirthDateText">
							<xsl:text>;&#32;</xsl:text>
						</xsl:if>
						<!-- PersonBirthDateText -->
						<xsl:for-each select="j:PersonAlias/cib-ext:PersonBirthDateText">
							<xsl:apply-templates select="."/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#32;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</td></tr>
				</xsl:if>
				<!-- Miscellaneous Text -->
				<xsl:if test="cib-ext:MiscellaneousText">
					<tr><td class="detailvalue">
						<xsl:for-each select="cib-ext:MiscellaneousText">
							<xsl:choose>
								<xsl:when test="position() = 1">	
									<xsl:text>Miscellaneous:&#160;&#160;</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>&#32;</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="." mode="TitleCase" />
						</xsl:for-each>
					</td></tr>
				</xsl:if>
				<xsl:if test="position() != last()">
					<tr><td>&#160;</td></tr>
				</xsl:if>
			</xsl:for-each>
		</table>
		</xsl:if>
	</xsl:template>
	
</xsl:transform>
