<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">

	<xsl:import href="ncic_common.xsl"/>

	<!-- Date of Birth followed by a semi-colon -->
	<xsl:template match="cib-ext:PersonBirthDateText | j:PersonBirthDate">
		<!--  Date of Birth: Full Date -->
		<xsl:apply-templates select="." mode="FormatFullDateAsMMDDYYYY"/>
		<xsl:if test="position() != last()">
			<xsl:text>;&#160;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="cib-ext:PersonBirthYear.Range">
	 	<xsl:text>Estimated Year of Birth: </xsl:text>
		<xsl:value-of select="j:RangeMinimumMeasure"/>
		<xsl:text>&#160;-&#160;</xsl:text>
		<xsl:value-of select="j:RangeMaximumMeasure"/>
	</xsl:template>
	
	<!-- Name in format First, Middle, Last, Suffix -->
	<xsl:template match="j:PersonName">
		<span class="subjecttitle">
			<xsl:value-of select="j:PersonSurName"/>
			<xsl:if test="j:PersonGivenName">
				<xsl:text>,&#160;</xsl:text>
				<xsl:value-of select="j:PersonGivenName"/>
			</xsl:if>
			<xsl:if test="j:PersonMiddleName or j:PersonSuffixName">
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="j:PersonMiddleName"/>
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="j:PersonSuffixName"/>
			</xsl:if>
		</span>
	</xsl:template> 
	
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:SupervisionSubject |
	 	cib-ext:SupervisionSubject| j:RegisteredSexOffender | cib-ext:GroupMemberDetails |
	  	cib-ext:GroupOrganizationDetails | cib-ext:IdentityTheftVictim | j:Victim.Person"
		mode="subject_caution_all">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width80percent" align="center">
					<!--  subject caution  -->
					<xsl:apply-templates select="cib-ext:SubjectCautionInformationText"/>
					<!-- predator indicator for sex offender files -->
					<xsl:if test="cib-ext:SexualPredatorIndicator='true'">
						<br/>
						<span style="color:red; font-weight: bold; font-size: 114%;">Sexual Predator</span> 
					</xsl:if>
					<!-- sex offender status -->
					<xsl:apply-templates select="cib-ext:RegisteredOffenderStatusText"/>
					<!-- Sex offender tier level -->
					<xsl:if test="cib-ext:TierLevelCode">
						<br/>
						<span style="color:red; font-weight: bold; font-size: 114%;">
							<xsl:text>Tier Level:&#160;&#160;</xsl:text>
							<xsl:value-of select="cib-ext:TierLevelCode"/>
						</span> 
					</xsl:if>
				</td>
				<td class="width10percent"></td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:SupervisionSubject | cib-ext:SupervisionSubject
		 | j:RegisteredSexOffender | cib-ext:GroupMemberDetails | cib-ext:IdentityTheftVictim | j:Victim.Person  
		 | cib-ext:ProtectiveInterestPerson | cib-ext:ViolentPerson" 
		 
		mode="subject_details_all">
		<br/>	
		<table>
			<tr>
        <xsl:variable name="width">
          <xsl:choose>
            <xsl:when test="../../cib-ext:Image">
              <xsl:text>width60percent</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>width80percent</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
				<td class="{$width}"> 
					<!-- Name -->
					<xsl:apply-templates select="j:PersonName"/>
					<br/>
					<!-- Gender/Race -->
					<div class="subjectvalue">
					<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonSexText" mode="TitleCase"/>	
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonRaceText" mode="TitleCase"/>	
					
					<!-- Ethnicity is optional.  Text is set in NCIC Handler's stylesheet (CommonResponse.xsl) 
						Per CIB we only display if Hispanic Or Latino.  If NCIC sent N this is Not Hispanic or Latino-->
					<xsl:if test="starts-with(j:PersonSocialDetails/j:PersonEthnicityText,'Hispanic')">
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates select="j:PersonSocialDetails/j:PersonEthnicityText" mode="TitleCase"/>
					</xsl:if>
					
					<br/>		
					<!-- Person Birth Place --> 
					<xsl:if test="cib-ext:PersonBirthPlaceName or j:PersonSocialDetails">
						<xsl:if test="cib-ext:PersonBirthPlaceName">
							<xsl:text>Born in&#160;</xsl:text>
							<xsl:value-of select="cib-ext:PersonBirthPlaceName"/>
						</xsl:if>
						<!-- This is the primary citizenship text -->
						<xsl:if test="j:PersonSocialDetails/j:PersonCitizenshipText">
							<xsl:if test="cib-ext:PersonBirthPlaceName">
								<xsl:text>;&#160;</xsl:text>
							</xsl:if>
							<xsl:text>Citizen of&#160;</xsl:text>
							<xsl:value-of select="j:PersonSocialDetails/j:PersonCitizenshipText"/>
						</xsl:if>
						<!-- There can also be supplemental PersonCitizenshipText under j:PersonAlias 
							If there is no primary we would not have alias as NCIC requires the primary first -->
						<xsl:if test="j:PersonAlias/j:PersonSocialDetails/j:PersonCitizenshipText">
						  <xsl:text>;&#160;</xsl:text>
						  <xsl:for-each select="j:PersonAlias/j:PersonSocialDetails/j:PersonCitizenshipText">
							<xsl:apply-templates select="."/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#32;</xsl:text>
							</xsl:if>
						  </xsl:for-each>
						</xsl:if>
						<br/>
					</xsl:if>
					<!-- Person primary birthdate -->
					<xsl:apply-templates select="j:PersonBirthDate"/>
					<xsl:apply-templates select="cib-ext:PersonBirthDateText"/>
					<xsl:apply-templates select="cib-ext:PersonBirthYear.Range"/>
					<!--  Person other birth dates -->
					<xsl:if test="j:PersonAlias/cib-ext:PersonBirthDateText">
						<xsl:text>;&#160;</xsl:text>
						<xsl:for-each select="j:PersonAlias/cib-ext:PersonBirthDateText">
							<xsl:apply-templates select="."/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#32;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:if> 
					<!--  new line -->
					<br/>
					<!-- Emancipation Date - only wanted person -->
					<xsl:if test="cib-ext:SubjectEmancipationDate">
						<xsl:text>Emancipation&#160;Date:&#160;</xsl:text>
						<xsl:apply-templates select="cib-ext:SubjectEmancipationDate" mode="FormatFullDateAsMMDDYYYY"/>
						<br/>
					</xsl:if>			
					<!-- Height and Weight for all person files but unidentified person --> 
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHeightMeasure">
						<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightMeasure,1,1)" />
						<xsl:text>'</xsl:text>
						<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightMeasure,2,2)" />
						<xsl:text>"</xsl:text>
					</xsl:if>	 		
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure">
						<xsl:choose>
						       <xsl:when test="j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure='UNK'">
						              <xsl:text>Unknown Height</xsl:text> 
						       </xsl:when>
						       <xsl:otherwise>
									<xsl:value-of select="substring(j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure,1,1)" />
									<xsl:text>'</xsl:text>
									<xsl:value-of select="substring(j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure,2,2)" />
									<xsl:text>"</xsl:text>
						       </xsl:otherwise>
						</xsl:choose>
					</xsl:if> 
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure">
						<xsl:choose>
						       <xsl:when test="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure='UNK'">
						              <xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						              <xsl:text>Unknown Weight</xsl:text> 
						       </xsl:when>
						       <xsl:otherwise>
						              <xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						              <xsl:value-of select="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure"/>
						              <xsl:text>&#160;lbs</xsl:text>
						       </xsl:otherwise>
						</xsl:choose>
					</xsl:if>     				
					
					<xsl:if test="j:PersonPhysicalDetails/j:PersonWeightMeasure">
						<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonWeightMeasure"/>
						<xsl:text>&#160;lbs</xsl:text>
					</xsl:if> 
					<!-- Height and Weight for unidentified person only -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHeightDescriptionText">
						<xsl:choose>
							<xsl:when test="contains(j:PersonPhysicalDetails/j:PersonHeightDescriptionText,'-')">
								<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightDescriptionText,1,1)" />
								<xsl:text>'</xsl:text>
								<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightDescriptionText,2,2)" />
								<xsl:text>"-</xsl:text>
								<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightDescriptionText,5,1)" />
								<xsl:text>'</xsl:text>
								<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightDescriptionText,6,2)" /> 
								<xsl:text>"</xsl:text>
							</xsl:when>
							<xsl:when test="j:PersonPhysicalDetails/j:PersonHeightDescriptionText='UNK'">
								<xsl:text>Unknown Height</xsl:text> 
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="j:PersonPhysicalDetails/j:PersonHeightDescriptionText"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>			
					<xsl:if test="j:PersonPhysicalDetails/j:PersonWeightDescriptionText">
						<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:choose>
							<xsl:when test="j:PersonPhysicalDetails/j:PersonWeightDescriptionText='UNK'">
								<xsl:text>Unknown Weight</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="j:PersonPhysicalDetails/j:PersonWeightDescriptionText"/>
								<xsl:text>&#160;lbs</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
					<!-- Eyes and hair -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonEyeColorText">
						<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonEyeColorText"/>
						<xsl:text>&#160;Eyes</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHairColorText">
						<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonHairColorText"/>
						<xsl:text>&#160;Hair</xsl:text>
					</xsl:if>
					<xsl:apply-templates select="j:Residence" />
					<xsl:apply-templates select="j:PersonAlias/j:Residence" />
					<!-- Address (WP)-->
					<xsl:apply-templates select="j:LocationAddress" mode="wp"/>
					<!-- telephone number -->
					<xsl:if test="j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID">
						<br/>
						<xsl:text>Telephone Number&#160;</xsl:text>
						<xsl:value-of select="j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
						<br/>
					</xsl:if>
					
					<!-- Sex Offender contact information -->
					<!-- phone -->
					<xsl:if test="j:PrimaryContactInformation/cib-ext:ContactTelephoneNumber">
						<br/>
						<xsl:if test="j:PrimaryContactInformation/cib-ext:ContactTelephoneNumber/cib-ext:TelephoneNumberTypeText">
							<xsl:apply-templates select="j:PrimaryContactInformation/cib-ext:ContactTelephoneNumber/cib-ext:TelephoneNumberTypeText" mode="TitleCase"/>	
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:PrimaryContactInformation/cib-ext:ContactTelephoneNumber/j:TelephoneNumberFullID">
							<xsl:value-of select="j:PrimaryContactInformation/cib-ext:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
						</xsl:if>
					</xsl:if>
					<!-- supplemental phone numbers -->
					<xsl:for-each select="j:PersonAlias/cib-ext:ContactInformation/cib-ext:ContactTelephoneNumber">
						<xsl:if test="cib-ext:TelephoneNumberTypeText">
							<xsl:text>;&#160;</xsl:text>
							<xsl:apply-templates select="cib-ext:TelephoneNumberTypeText" mode="TitleCase"/>
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:TelephoneNumberFullID">
							<xsl:value-of select="j:TelephoneNumberFullID"/>
						</xsl:if>
					</xsl:for-each>
					<!-- email addresses -->
					<xsl:if test="j:PrimaryContactInformation/j:ContactEmailID/j:ID">
						<br/>
						<xsl:value-of select="j:PrimaryContactInformation/j:ContactEmailID/j:ID"/>
					</xsl:if>
					<!-- supplemental email addresses -->
					<xsl:for-each select="j:PersonAlias/cib-ext:ContactInformation/j:ContactEmailID/j:ID">
						<xsl:text>;&#160;</xsl:text>
							<xsl:value-of select="."/>
					</xsl:for-each>
					<!-- internet identifiers -->
					<xsl:if test="j:PrimaryContactInformation/cib-ext:ContactInternetID/j:ID">
						<br/>
						<xsl:text>Internet Identifier:&#160;</xsl:text>
						<xsl:value-of select="j:PrimaryContactInformation/cib-ext:ContactInternetID/j:ID"/>
					</xsl:if>
					<!-- supplemental internet identifiers -->
					<xsl:for-each select="j:PersonAlias/cib-ext:ContactInformation/cib-ext:ContactInternetID/j:ID">
						<xsl:text>;&#160;</xsl:text>
							<xsl:value-of select="."/>
					</xsl:for-each>
				</div>
        </td>
        <xsl:variable name="width">
          <xsl:choose>
            <xsl:when test="../../cib-ext:Image">
              <xsl:text>width20percent</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>width40percent</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <td class="{$width}" align="left">
          <!-- 09/2010 per CIB display the Alias/Fraud link when the following is in the XML -->
          <xsl:if test="j:PersonAlias/j:PersonName or cib-ext:PersonStolenFraudulent">
            <a href="#alias{$responseId}">
              <img src="../../images/aliasfraudlink.jpg" alt="Link to alias info" />
            </a>
            <br/>
          </xsl:if>
          <xsl:if test="../j:ProtectionOrderRestrictedPerson">
            <a href="#petitioner{$responseId}">
              <img src="../../images/Petitioner.jpg" alt="Link to petitioner info"/>
            </a>
            <br/>
          </xsl:if>
          <xsl:if test="../j:IncidentVictim">
            <a href="#victimInfo{$responseId}">
              <img src="../../images/VictimInformation.jpg" alt="Link to victim info"/>
            </a>
             <br/>
          </xsl:if>
          <xsl:if test="../cib-ext:PersonWithInformation">
            <a href="#personWithInfo{$responseId}">
              <img src="../../images/personWithInfo.jpg" alt="Link to person with information"/>
            </a>
             <br/>
          </xsl:if>
		</td>
        <xsl:if test="//cib-ext:Image">
  			<td class="width20percent" align="left">
            	<xsl:apply-templates select="." mode="cibExtImage"/>
		  	</td>
        </xsl:if>
		</tr>
		</table>
	</xsl:template>
	<xsl:template match="j:Residence">
		<br/>
			<!-- Address (j:Residence) -->
		<xsl:if test="j:LocationAddress/j:LocationStreet/j:StreetFullText">
			<xsl:value-of select="j:LocationAddress/j:LocationStreet/j:StreetFullText"/>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationStreet/j:StreetNumberText">
			<xsl:value-of select="j:LocationAddress/j:LocationStreet/j:StreetNumberText"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationStreet/j:StreetName">
			<xsl:value-of select="j:LocationAddress/j:LocationStreet/j:StreetName"/>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationStreet">
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationCityName">
			<xsl:apply-templates select="j:LocationAddress/j:LocationCityName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationCountyName">
			<xsl:apply-templates select="j:LocationAddress/j:LocationCountyName" mode="TitleCase"/>
			<xsl:text>&#160;County,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationStateName">
			<xsl:value-of select="j:LocationAddress/j:LocationStateName"/>
		</xsl:if>
		<xsl:if test="j:LocationAddress/j:LocationPostalCodeID">
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeID"/>
			<xsl:if test="j:LocationAddress/j:LocationPostalCodeExtensionID">
				<xsl:text>-</xsl:text>
				<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeExtensionID"/>
			</xsl:if>
		</xsl:if>
		<xsl:if test="j:ResidenceTypeText">
			<br/>
			<xsl:text>Address type:&#160;</xsl:text>
			<xsl:value-of select="j:ResidenceTypeText" />
		</xsl:if>
		<xsl:if test="j:ResidenceStartDate">
			<xsl:text>&#160;Beginning:&#160;</xsl:text>
			<xsl:apply-templates select="j:ResidenceStartDate" mode="FormatFullDateAsMMDDYYYY"/>
		</xsl:if>
		<xsl:if test="j:ResidenceEndDate">
			<xsl:text>&#160;Ending:&#160;</xsl:text>
			<xsl:apply-templates select="j:ResidenceEndDate" mode="FormatFullDateAsMMDDYYYY"/>
		</xsl:if>
	</xsl:template>

	<!-- FBI, SSN, stateID, Miscellaneous #, skintone, scarmark -->
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:RegisteredSexOffender | 
	cib-ext:SupervisionSubject | cib-ext:GroupMemberDetails | cib-ext:IdentityTheftVictim | j:Victim.Person 
	| cib-ext:ProtectiveInterestPerson | cib-ext:ViolentPerson" 
		mode="FBItoSMT">
		<xsl:if test="j:PersonAssignedIDDetails or j:PersonPhysicalDetails/j:PersonSkinToneText">
			<br/>
		</xsl:if>
		<table>
			<!-- FBI ID and SSN ID -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'FBI:'"/>
				<xsl:with-param name="value1" select="j:PersonAssignedIDDetails/j:PersonFBIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width15percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width15percent'"/>
				<xsl:with-param name="label2" select="'Social Security #:'"/>
				<xsl:with-param name="value2">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
						<xsl:apply-templates select="." mode="FormatSSN"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:if test="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
						<xsl:text>; </xsl:text>
						<xsl:for-each select="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
							<xsl:apply-templates select="." mode="FormatSSN"/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#160;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>			
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width50percent'"/>
			</xsl:call-template>
			<!--  State ID and Miscellaneous# -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'State ID:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonStateID/j:ID">
						<xsl:value-of select="."/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#32;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:if test="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonStateID/j:ID">
						<xsl:text>;&#32;</xsl:text>
						<xsl:for-each select="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonStateID/j:ID">
							<xsl:value-of select="."/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#32;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>			
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width15percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width15percent'"/>
				<xsl:with-param name="label2" select="'Miscellaneous #:'"/>
				<xsl:with-param name="value2">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
						<xsl:value-of select="../cib-ext:PersonIDTypeText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="."/>
					</xsl:for-each>
					<xsl:if test="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
						<xsl:for-each select="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
							<xsl:text>;&#10;</xsl:text>
							<xsl:value-of select="../cib-ext:PersonIDTypeText"/>
							<xsl:text>-</xsl:text>
							<xsl:value-of select="."/>
						</xsl:for-each>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width50percent'"/>			
			</xsl:call-template>
			<!-- Skintone and Scarmark -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Skintone:'"/>
				<xsl:with-param name="value1" select="j:PersonPhysicalDetails/j:PersonSkinToneText"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width15percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width15percent'"/>
				<xsl:with-param name="label2" select="'Scarmark:'"/>
				<xsl:with-param name="value2">
					<xsl:for-each select="j:PersonPhysicalDetails/j:PersonPhysicalFeature">
						<xsl:value-of select="j:PhysicalFeatureTypeText"/>
						<xsl:if test="position() != last()">
							<xsl:text>; </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width50percent'"/>		
			</xsl:call-template>
		</table>
	</xsl:template>

	<!-- Driver license, SSN, stateID, Miscellaneous #, skintone, scarmark -->  
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:RegisteredSexOffender | cib-ext:SupervisionSubject |
	 cib-ext:GroupMemberDetails | cib-ext:IdentityTheftVictim | j:Victim.Person | cib-ext:ProtectiveInterestPerson | cib-ext:ViolentPerson" 
		mode="DLtoDNALoc">
		<xsl:if test="j:DriverLicense or j:PersonPhysicalDetails/j:PersonDental or j:PersonBiometricDetails or cib-ext:PersonCircumcisionText">
			<br/>
		</xsl:if>
		<table>
			<xsl:apply-templates select="." mode="DriverLicense"/>
			<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonFingerprintSet/j:BiometricValueText" />
			<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonDNA"/>
			<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonDNA/cib-ext:DNALocationInformationText"/> 
			<!--  glasses -->
			<xsl:apply-templates select="j:PersonMedicalDetails/j:PersonVisionPrescriptionText"/> <!-- missing and unidentified-->
			<xsl:apply-templates select="j:PersonPhysicalDetails/cib-ext:PersonEyeWearIndicator"/> <!-- sex offender -->
			<!--  circumcised -->
			<xsl:apply-templates select="cib-ext:PersonCircumcisionText"/> <!-- missing and unidentified -->
			<!--  dental -->
			<xsl:apply-templates select="." mode="DentalInfo"/>
		</table>
	</xsl:template>

	<xsl:template match="cib-ext:PersonCircumcisionText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Circumcision:'"/>			
			<xsl:with-param name="value1"> 
				<xsl:value-of select="."/>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>		
	</xsl:template>
	
	<xsl:template match="j:PersonVisionPrescriptionText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Glasses:'"/>			
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>		
	</xsl:template>
	
	<xsl:template match="cib-ext:PersonEyeWearIndicator">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Glasses:'"/>		 	
			<xsl:with-param name="value1">
				<xsl:apply-templates select="." mode="FormatBooleanAsYesNo"/>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>		
	</xsl:template> 
	
	<!-- Dental Information -->
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:RegisteredSexOffender | cib-ext:SupervisionSubject |
	 cib-ext:GroupMemberDetails | cib-ext:IdentityTheftVictim | j:Victim.Person | cib-ext:ProtectiveInterestPerson | cib-ext:ViolentPerson" 
		mode="DentalInfo">
		<xsl:if test="j:PersonPhysicalDetails/j:PersonDental">
			<table>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Dental X_RAY:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates 
							select="j:PersonPhysicalDetails/j:PersonDental/cib-ext:PersonDentalXRaysAvailableIndicator" 
							mode="FormatBooleanAsYesNo"/>
					</xsl:with-param> 
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
					<xsl:with-param name="label2" select="'Dental Model Available:'"/>
					<xsl:with-param name="value2">
						<xsl:apply-templates 
							select="j:PersonPhysicalDetails/j:PersonDental/cib-ext:PersonDentalModelPhotoAvailableIndicator" 
							mode="FormatBooleanAsYesNo"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
				</xsl:call-template>
				<xsl:call-template name="ConditionalRow">
					<!-- only applicable to the NCIC response (NDIR)-->
					<xsl:with-param name="label1" select="'Dental Image:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates 
							select="j:PersonPhysicalDetails/j:PersonDental/cib-ext:PersonDentalImageAvailableIndicator" 
							mode="FormatBooleanAsYesNo"/>
					</xsl:with-param> 
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				</table>
				<!-- DCH or TEETH: -->
				<table>
					<xsl:choose>
						<!-- TEETH -->
						<xsl:when test="j:PersonPhysicalDetails/j:PersonDental/j:PersonTooth"> 
							<tr>
								<td class="detaillabel uppercase width25percent">
									<xsl:text>DCH:</xsl:text>
								</td>
								<td class="detailvalue width75percent">
									<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonDental/j:PersonTooth"/>
								</td>
							</tr>
						</xsl:when>
						<!--  DCH -->
						<xsl:otherwise>
							<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonDental/j:PersonDentalCharacteristicGeneralText"/>
						</xsl:otherwise>
					</xsl:choose>
				</table>
				<!--  remarks -->
				<table>
					<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonDental/j:PersonDentalCharacteristicText"/>
				</table>
		</xsl:if>
	</xsl:template>

	<xsl:template match="j:PersonDentalCharacteristicGeneralText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'DCH:'"/>
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="j:PersonDentalCharacteristicText"> 
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Dental Remarks:'"/>
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="j:PersonTooth">
		<span class="tooth"><xsl:value-of select="j:PersonToothIDCode"/></span>
		<xsl:text>-</xsl:text>
		<!-- The status of dental codes  -->
		<xsl:for-each select="cib-ext:PersonToothStatus/cib-ext:PersonToothStatusText">	
			<xsl:value-of select="."/>
			<xsl:if test="position()!=last()">
				<xsl:text>/</xsl:text>
			</xsl:if>
		</xsl:for-each>
		<xsl:if test="position()!=last()">
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="number ( position() mod 4) = 0">
		   <br/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="aliasHeader">
		<br/>
		<a name="alias{$responseId}">
		<span class="detaillabel">ALIAS NAMES/FRAUDULENT DATA:</span>
		</a>
	</xsl:template>
		
	<!-- Caution Medical Conditions (reusable by all file types) -->
	<xsl:template match="cib-ext:SubjectCautionInformationText">
		<xsl:choose>
			<xsl:when test="position() = 1">
				<span class="medicallabel">
					<xsl:text>Caution&#160;-&#160;Medical&#160;Condition:&#160;&#160;</xsl:text>
					<xsl:apply-templates select="." mode="TitleCase"/>		 
				</span>
			</xsl:when>
			<xsl:otherwise>
				<br/>
				<span class="medicalvalue">
					<xsl:apply-templates select="." mode="TitleCase"/>	 						
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
		<!-- Caution - Violent Person Criteria Translation Text-->	
    <xsl:template match="cib-ext:ViolentPersonCriteriaTranslationText" >                  			
		<xsl:choose>
			<xsl:when test="position() = 1">
				<span class="medicallabel">
					<xsl:text>Caution&#160;-&#160;Violent&#160;Person:&#160;&#160;</xsl:text>
					<xsl:apply-templates select="." mode="TitleCase"/>		 
				</span>
			</xsl:when>
			<xsl:otherwise>
				<br/>
				<span class="medicalvalue">
					<xsl:apply-templates select="." mode="TitleCase"/>	 						
				</span>
			</xsl:otherwise>
		</xsl:choose>	

	</xsl:template>	
	
	<!-- Drivers License (1 master, n supp.in PersonAlias) -->
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:RegisteredSexOffender | 
	cib-ext:SupervisionSubject | cib-ext:GroupMemberDetails | cib-ext:IdentityTheftVictim | j:Victim.Person  
	| cib-ext:ProtectiveInterestPerson | cib-ext:ViolentPerson" 
		mode="DriverLicense">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1">
				<xsl:if test="j:DriverLicense">
					<xsl:text>Drivers License #:</xsl:text>
				</xsl:if>				
			</xsl:with-param>
			<xsl:with-param name="value1">
				<xsl:for-each select="j:DriverLicense/j:DriverAuthorizationID.Detailed">
					<xsl:value-of select="j:ID"/>
					<xsl:text>,&#160;</xsl:text>
					<xsl:value-of select="j:IDIssuingAuthorityText"/>
					<xsl:if test="j:IDIssuingAuthorityText">
						<xsl:text>,&#160;</xsl:text>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="cib-ext:IDExpirationYear='UNKN'">
						    <xsl:text>Unknown Expiration Year</xsl:text> 
						</xsl:when>
						<xsl:otherwise>
						    <xsl:value-of select="cib-ext:IDExpirationYear"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
				<xsl:for-each select="j:PersonAlias/j:DriverLicense/j:DriverAuthorizationID.Detailed">
					<xsl:text>;&#10;</xsl:text>
					<xsl:value-of select="j:ID"/>
					<xsl:text>,&#160;</xsl:text>
					<xsl:value-of select="j:IDIssuingAuthorityText"/>
					<xsl:if test="j:IDIssuingAuthorityText">
						<xsl:text>,&#160;</xsl:text>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="cib-ext:IDExpirationYear='UNKN'">
						    <xsl:text>Unknown Expiration Year</xsl:text> 
						</xsl:when>
						<xsl:otherwise>
						    <xsl:value-of select="cib-ext:IDExpirationYear"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Fingerprint (on its own line)   -->
	<xsl:template match="j:BiometricValueText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Fingerprint Class:'"/>
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>
	</xsl:template>
	
	<!-- DNA Available -->
	<xsl:template match="j:PersonDNA">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'DNA Available:'"/>
			<xsl:with-param name="value1">
				<xsl:if test="@j:commentText = 'available'">
					<xsl:text>Yes</xsl:text>
				</xsl:if>
				<xsl:if test="@j:commentText = 'unavailable'">
					<xsl:text>No</xsl:text>
				</xsl:if>				
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>	
	</xsl:template>
	
	<!-- DNA Location (on its own line)  -->
	<xsl:template match="cib-ext:DNALocationInformationText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Dna Location:'"/>
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>	
	</xsl:template>
	
	<xsl:template name="vehicle_all">
		<xsl:param name="parent" select="."/>
		<xsl:if test="$parent/cib-ext:Vehicle">
			<br/>
			<table>
				<tr>
					<td class="width25percent">
						 <img src="../../images/VehicleIcon.jpg" alt="Vehicle"/> 
					</td>
					<td class="width75percent">
						<xsl:for-each select="$parent/cib-ext:Vehicle" >
							<xsl:call-template name="Vehicle"/>
							<br/>
						</xsl:for-each>
					</td> 
				</tr>
			</table>
		</xsl:if> 
	</xsl:template>
	
	<!-- Vehicle -->
	<xsl:template name="Vehicle">
		<span class="detailvalue">
			<xsl:if test="cib-ext:VehicleOwnershipText">
				<xsl:apply-templates select="cib-ext:VehicleOwnershipText" mode="TitleCase"/>
				<xsl:text>,&#160;</xsl:text>
			</xsl:if>
			
		<!-- Year and Make were made optional in the schema due to a few NCIC records 
			We could still end up with a leading space but the stylesheet would need to be more
			complex just for a few records -->
			<xsl:if test="j:VehicleModelYearDate">
				<xsl:value-of select="j:VehicleModelYearDate"/>
				<xsl:text>&#160;</xsl:text>
			</xsl:if>
			<xsl:if test="cib-ext:VehicleMakeText">
				<!-- space already added above -->
				<xsl:value-of select="cib-ext:VehicleMakeText"/>
			</xsl:if>
			<!-- Vehicle Make Comment Text -->
			<xsl:if test="cib-ext:VehicleMakeCommentsText">
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="cib-ext:VehicleMakeCommentsText"/>
			</xsl:if>
			<xsl:if test="j:VehicleModelCodeText">
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="j:VehicleModelCodeText"/>
			</xsl:if>
			<xsl:if test="j:VehicleColorPrimaryText">
				<xsl:text>,&#160;</xsl:text>
				<xsl:value-of select="j:VehicleColorPrimaryText"/>
				<xsl:if test="j:VehicleColorSecondaryText">
					<xsl:text>/</xsl:text>
					<xsl:value-of select="j:VehicleColorSecondaryText"/>
				</xsl:if>
			</xsl:if>
			<xsl:if test="cib-ext:VehicleStyleText">
				<xsl:text>,&#160;</xsl:text>
					<xsl:value-of select="cib-ext:VehicleStyleText"/>
				</xsl:if>
				<xsl:if test="j:VehicleID/j:ID">
					<xsl:text>,&#160; VIN&#160;</xsl:text>
				<xsl:value-of select="j:VehicleID/j:ID" />
			</xsl:if>
		</span>
		<br/>
	</xsl:template>
	
	<xsl:template name="licensePlate_all">
		<xsl:param name="parent" select="."/>
		<xsl:if test="$parent/cib-ext:LicensePlate">
			<br/>
			<table>
				<tr>
					<td class="width25percent" valing="top">
						<img src="../../images/Plate1.jpg" alt="License Plate" width="100"/>
					</td>
					<td class="width75percent">
						<xsl:for-each select="$parent/cib-ext:LicensePlate" >
							<xsl:call-template name="LicensePlate"/>
						</xsl:for-each> 
					</td> 
				</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	<!-- Plates -->
	<xsl:template name="LicensePlate">
		<span class="detailvalue">
			<xsl:value-of select="j:VehicleRegistrationPlateID/j:ID"/>	
			<xsl:text>,&#160;</xsl:text>		
			<xsl:value-of select="j:RegistrationJurisdictionName"/>
			<xsl:text>&#160;</xsl:text>		
			<xsl:choose>
				<xsl:when test="cib-ext:RegistrationExpirationYear = 'NX'">
					<xsl:text>Non-Expiring</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Exp.&#160;</xsl:text>
					<xsl:value-of select="cib-ext:RegistrationExpirationYear"/> 
				</xsl:otherwise> 
			</xsl:choose>
			<xsl:apply-templates select="j:VehicleRegistrationPlateTypeText"/> 
		</span><br/>
	</xsl:template>

	<xsl:template match="j:VehicleRegistrationPlateTypeText"> 
		<xsl:text>,&#160;</xsl:text>
		<xsl:value-of select="."/>	
	</xsl:template>
	
	<!-- Alias Names -->
  <xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:SupervisionSubject | cib-ext:SupervisionSubject
     | j:RegisteredSexOffender | cib-ext:GroupMemberDetails | cib-ext:IdentityTheftVictim | j:Victim.Person   
     | cib-ext:ProtectiveInterestPerson | cib-ext:ViolentPerson" 
		mode="alias">
		<xsl:if test="j:PersonAlias/j:PersonName">
			<xsl:call-template name="aliasHeader"/>
				<table>
					<tr>
						<td class="detailsublabel width25percent">Alias Names:</td>
						<td class="width75percent">
							<xsl:call-template name="listAlias"/>
						</td>
					</tr>
				</table>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="listAlias">
		<table>
			<xsl:for-each select="j:PersonAlias/j:PersonName[position() mod 2 != 0]">
                <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                <xsl:variable name="startposition" select="((number(position())-1)*2)+1"/>
                <tr>
                    <xsl:apply-templates select="../j:PersonName" mode="aliasNames">
                         <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                         <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                         <xsl:with-param name="startposition" select="$startposition"/>
                    </xsl:apply-templates>
                </tr>
            </xsl:for-each>
          </table>
	</xsl:template>
	
	<xsl:template match="j:PersonName" mode="aliasNames">
        <xsl:param name="startposition"/>
        <xsl:if test="position() = number($startposition) or position() = number($startposition)+1">
            <td class="width50percent"><xsl:apply-templates select="." mode="alias"/></td>
        </xsl:if>
    </xsl:template>
	
	<!-- Name in format Last, First, Middle, Suffix -->
	<xsl:template match="*" mode="alias">
		<span class="detailvalue">
			<xsl:apply-templates select="j:PersonSurName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
			<xsl:apply-templates select="j:PersonGivenName" mode="TitleCase"/>
			<xsl:if test="j:PersonMiddleName or j:PersonSuffixName">
				<xsl:text>&#160;</xsl:text>
			</xsl:if>
			<xsl:apply-templates select="j:PersonMiddleName" mode="TitleCase"/>		
			<xsl:if test="j:PersonSuffixName">
				<xsl:text>&#160;</xsl:text>
				<xsl:apply-templates select="j:PersonSuffixName" mode="TitleCase"/>
			</xsl:if>
		</span>
	</xsl:template>
	
	<xsl:template name="fraudulentNames">
		<table>
			<xsl:for-each select="j:PersonName[position() mod 2 != 0]">
                <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                <xsl:variable name="startposition" select="((number(position())-1)*2)+1"/>
                    <tr>
                        <xsl:apply-templates select="../j:PersonName" mode="aliasNames">
                             <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                             <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                             <xsl:with-param name="startposition" select="$startposition"/>
                        </xsl:apply-templates>
                    </tr>
            </xsl:for-each>
          </table>
	</xsl:template>
	
	<!-- ################ -->
	<!-- Fraudulent Data  -->
	<!-- ################ -->
	<xsl:template match="cib-ext:PersonStolenFraudulent">
		<br/>
		<xsl:if test="not(../j:PersonAlias)">
			<xsl:call-template name="aliasHeader"/>
			<a name="recorddetails{$responseId}"/>
		</xsl:if>
		<table>
			<tr>
				<td class="detailsublabel width25percent"><xsl:text>Stolen/Fraudulent:</xsl:text></td>
				<td class="detailvalue width75percent">
					<!--  Alias -->
					<xsl:call-template name="fraudulentNames"/>
					<!--  Social Security # -->
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
						<xsl:apply-templates select="." mode="FormatSSN"/> 
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<!-- Birth dates -->
				   	<xsl:for-each select="cib-ext:PersonBirthDateText">
				   		<xsl:if test="position() = 1">
							<br/>
						</xsl:if>
						<xsl:apply-templates select="."/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
				  	</xsl:for-each>
				  	<!-- Miscellaenous # -->
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
						<xsl:if test="position() = 1">
							<br/>
						</xsl:if>
						<xsl:value-of select="../cib-ext:PersonIDTypeText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="."/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<!-- Drivers License -->
					<xsl:for-each select="j:DriverLicense/j:DriverAuthorizationID.Detailed">
						<xsl:if test="position() = 1">
							<br/>
						</xsl:if>
						<xsl:value-of select="j:ID"/>
						<xsl:text>,&#160;</xsl:text>
						<xsl:value-of select="j:IDIssuingAuthorityText"/>
						<xsl:if test="j:IDIssuingAuthorityText">
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="cib-ext:IDExpirationYear='UNKN'">
							    <xsl:text>Unknown Expiration Year</xsl:text> 
							</xsl:when>
							<xsl:otherwise>
							     <xsl:value-of select="cib-ext:IDExpirationYear"/>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="cib-ext:PersonFirearmProhibitedText | cib-ext:ProtectionOrderConditionText">
		<div class="caveat"><xsl:value-of select="."/></div>
	</xsl:template>
	
	<xsl:template match="cib-ext:WarrantGeographicRestrictionText | j:WarrantExtraditionLimitationText">
		<div class="extradition">
			<xsl:text>**&#160;</xsl:text>
			<xsl:apply-templates select="." mode="TitleCase"/>
			<xsl:text>&#160;**</xsl:text>
		</div>
	</xsl:template>
	
	<!-- Wanted only templates -->
	<xsl:template match="cib-ext:DetainerDetails">
	    <xsl:apply-templates select="j:CaveatText"/>
		<div class="caveat">
			<xsl:text>DATE OF DETAINER/ </xsl:text>
			<xsl:apply-templates select="j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
			<br/>
			<xsl:text>INCARCERATING AGENCY/ </xsl:text>
			<xsl:value-of select="j:SupervisionFacility/j:OrganizationName"/>
			<xsl:text>&#160;ORI/</xsl:text>
			<xsl:value-of select="j:SupervisionFacility/j:OrganizationORIID"/>
			<br/>
			<xsl:text>DATE INCARCERATION STARTS/ </xsl:text>
			<xsl:apply-templates select="cib-ext:SupervisionStartDate" mode="FormatFullDateAsMMDDYYYY"/>
			<br/>
			<xsl:text>DATE SENTENCE ENDS/</xsl:text>
			<xsl:apply-templates select="cib-ext:SupervisionEndDate" mode="FormatFullDateAsMMDDYYYY"/>
			<br/>
			<xsl:for-each select="cib-ext:MiscellaneousText">
				<xsl:if test="position()=1">
					<xsl:text>REMARKS/</xsl:text>
				</xsl:if>
				<xsl:value-of select="."/>
			</xsl:for-each>
		</div>
	</xsl:template>

	<xsl:template match="j:MissingPerson | j:Victim.Person " mode="PersonOtherInfo">
		<table>
			<!--  BPS - body part status -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Body Part Status:'"/>
				<xsl:with-param name="value1" select="cib-ext:PersonBodyPartsStatusTypeText"/> 
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>			
			</xsl:call-template>
			<!--  Blood Type and MNP -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Blood Type:'"/>
				<xsl:with-param name="value1" select="j:PersonBiometricDetails/j:PersonBloodTypeText"/> 
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>			
				<xsl:with-param name="label2" select="'MNP:'"/>
				<xsl:with-param name="value2" select="j:MissingPersonDisappearanceTypeText"/>
				<xsl:with-param name="label_class_name2" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!--  Footprints and body X-RAYS -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Footprints:'"/>
				<xsl:with-param name="value1">
					<xsl:if test="j:PersonBiometricDetails/j:PersonFootPrint/@j:commentText = 'available'">
						<xsl:text>Yes</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonBiometricDetails/j:PersonFootPrint/@j:commentText = 'unavailable'">
						<xsl:text>No</xsl:text>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Body X-RAYS:'"/>
				<xsl:with-param name="value2" select="j:PersonBiometricDetails/j:PersonBodyXRaysAvailableText"/>
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>	 		
			</xsl:call-template>
		</table>
	</xsl:template>
		
	<xsl:template match="j:MissingPerson | j:Victim.Person" mode="JewelryInfo">
		<table>
			<tr>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Jewelry Type:'"/>
					<xsl:with-param name="value1">
						<xsl:for-each select="cib-ext:Jewelry">
							<xsl:value-of select="cib-ext:JewelryTypeText"/>
							<xsl:if test="position() != last()">
								<xsl:text>,&#160;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
			</tr>
			<tr>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Jewelry Description:'"/>
					<xsl:with-param name="value1" select="j:PersonPhysicalDetails/j:PersonJewelryDescriptionText"/>
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="j:LocationAddress" mode="wp">
		<xsl:if test="position() = 1">
			<br/>
		</xsl:if>
		<xsl-if test="cib-ext:DocumentedAddressDate">
			<xsl:apply-templates select="cib-ext:DocumentedAddressDate" mode="FormatFullDateAsMMDDYYYY"/>
			<xsl:text>&#160;&#160;</xsl:text>
		</xsl-if>
		<xsl:if test="j:LocationStreet">
			<xsl:value-of select="j:LocationStreet/j:StreetNumberText"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="j:LocationStreet/j:StreetName"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationCityName">
			<xsl:apply-templates select="j:LocationCityName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="j:LocationCountyName">
			<xsl:apply-templates select="j:LocationCountyName" mode="TitleCase"/>
			<xsl:text>&#160;County,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="cib-ext:LocationStateName">
			<xsl:apply-templates select="cib-ext:LocationStateName" mode="TitleCase"/>
		</xsl:if>
		<xsl:if test="j:LocationPostalCodeID">
			<xsl:text>,&#160;</xsl:text>
			<xsl:value-of select="j:LocationPostalCodeID"/>
			<xsl:if test="j:LocationPostalCodeExtensionID">
				<xsl:text>-</xsl:text>
				<xsl:value-of select="j:LocationPostalCodeExtensionID"/>
			</xsl:if>
		</xsl:if>
		<xsl-if test="cib-ext:AddressCategoryCodeText">
			<xsl:text>&#160;&#160;</xsl:text>
			<xsl:value-of select="cib-ext:AddressCategoryCodeText"/>
		</xsl-if>
		<xsl:if test="position() != last()">
			<br/>
		</xsl:if>
	</xsl:template>
	
</xsl:transform>