<?xml version="1.0"?>

<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/> 

	<!--  NCIC - SEX OFFENDER RECORD -->
	<!-- ############## -->
	<!-- main template  -->
	<!-- ############## -->
	<xsl:template match="/doj:NCICResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Sex Offender</xsl:text>
	</xsl:template>
	

	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="subject_details_all"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="FBItoSMT"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="DLtoDNALoc"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all" >
			<xsl:with-param name="parent" select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender"/>
		</xsl:call-template>
		<xsl:call-template name="boat_all" >
			<xsl:with-param name="parent" select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender"/>
		</xsl:call-template>
		
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="alias"/>
		<xsl:call-template name="VictimPerson"/>
		<!-- Employment, occupation and school -->
		<xsl:call-template name="EmploySchoolInfo"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails"/>
		<xsl:apply-templates select="." mode="record_details_all"/>	
		<xsl:apply-templates select="." mode="record_details"/>	 		
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="fileLogoPicture">
		<xsl:text>../../images/sexOffenderNCIC.gif</xsl:text>
		<xsl:text>-</xsl:text>
		<xsl:text>Registered Sex Offender</xsl:text>
	</xsl:template>

	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender" mode="subject_caution_all"/>
		<!-- Sex Offender Details-->	
		<br/>
		<table>
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	</xsl:template>

	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!--  Registration Date and Ending Registration Date: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Registration Date:'"/>
				<xsl:with-param name="value1"> 
					<xsl:apply-templates 
						select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:RegisteredOffenderEntryDate" 
						mode="FormatFullDateAsMMDDYYYY"> 
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Ending Registration Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates 
						select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/cib-ext:RegisteredOffenderEndDate" 
						mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!--  Date of Conviction and Original Conviction -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date of Conviction:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates 
						select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:RegisteredOffenderConviction/j:ActivityDate" 
						mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Original Conviction:'"/>
				<xsl:with-param name="value2" 
					select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:RegisteredOffenderConviction/j:ActivityCrimeCase/j:CaseCharge/j:ChargeReporting/cib-ext:ChargeNCICText"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Place of Crime: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Place of Crime:'"/>
				<xsl:with-param name="value1" select="cib-ext:SexOffenderIncident/j:IncidentLocation/j:LocationAddress/j:LocationStateName"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Juvenile Offender:'"/>
				<xsl:with-param name="value1">
				<xsl:apply-templates 
						 select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/cib-ext:JuvenileOffenderIndicator" 
						mode="FormatBooleanAsYesNo">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	<xsl:template name="VictimPerson">
		<xsl:if test="cib-ext:SexOffenderIncident/j:IncidentVictim/j:Victim.Person">
			<br/>
			<a name="victimInfo{$responseId}">
				<span class="detaillabel uppercase">Victim Information:</span>
			</a>
			<table>
				<xsl:for-each select="cib-ext:SexOffenderIncident/j:IncidentVictim/j:Victim.Person">
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'Age of Victim:'"/>
						<xsl:with-param name="value1" select="j:PersonAgeMeasure"/>
						<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
						<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
						<xsl:with-param name="label2" select="'Sex of Victim:'"/>
						<xsl:with-param name="value2">
							<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonSexText" mode="TitleCase" />
						</xsl:with-param>
						<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
						<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'Relationship:'"/>
						<xsl:with-param name="value1">
								<xsl:apply-templates select="cib-ext:VictimRelationshipText" mode="TitleCase" />
						</xsl:with-param>
						<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
						<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
					</xsl:call-template>
					<tr><td><xsl:text>&#160;</xsl:text></td></tr>
				</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>		
	 
	 <xsl:template name="EmploySchoolInfo">
	 <!-- Don't need to check for ../j:PersonAlias as the base/primary is required before any supplemental data can be added -->
		<xsl:if test="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:Employment 
				or cib-ext:SexOffenderIncident/j:RegisteredSexOffender/cib-ext:SchoolName
				or cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:PersonAssignedIDDetails/j:PersonLicenseID">
			<br/>
			<span class="detaillabel uppercase">Employment, Occupation and School Info:</span> 
			<table>
				<!-- Employer name -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Employer Name:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:Employment/j:EmploymentEmployerName" mode="TitleCase"/>
						<!-- Supplemental -->
						<xsl:for-each select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:PersonAlias/j:Employment/j:EmploymentEmployerName">
							<xsl:text>;&#32;</xsl:text>
							<xsl:apply-templates select="." mode="TitleCase"/>
						</xsl:for-each>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<!-- Occupation -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Occupation:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:Employment/j:EmploymentOccupationText" mode="TitleCase"/>
						<!-- Supplemental -->
						<xsl:for-each select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:PersonAlias/j:Employment/j:EmploymentOccupationText">
							<xsl:text>;&#32;</xsl:text>
							<xsl:apply-templates select="." mode="TitleCase"/>
						</xsl:for-each>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<!-- professional license (primary) -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Professional License Type:'"/>
					<xsl:with-param name="value1" select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:PersonAssignedIDDetails/j:PersonLicenseID/j:IDTypeText"/>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Professional License #:'"/>
					<xsl:with-param name="value1" select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:PersonAssignedIDDetails/j:PersonLicenseID/j:ID"/>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<!-- professional license (supplemental) -->
				<xsl:for-each select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:PersonAlias/j:PersonAssignedIDDetails/j:PersonLicenseID">				
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'Professional License Type:'"/>
						<xsl:with-param name="value1" select="j:IDTypeText"/>
						<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
						<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'Professional License #:'"/>
						<xsl:with-param name="value1" select="j:ID"/>
						<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
						<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
					</xsl:call-template>
				</xsl:for-each>			
				<!-- School name -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'School Name:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/cib-ext:SchoolName" mode="TitleCase"/>
						<!-- Supplemental -->
						<xsl:for-each select="cib-ext:SexOffenderIncident/j:RegisteredSexOffender/j:PersonAlias/cib-ext:SchoolName">
							<xsl:text>;&#32;</xsl:text>
							<xsl:apply-templates select="." mode="TitleCase"/>
						</xsl:for-each>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
			</table>
		</xsl:if>
	</xsl:template>		
	
	<xsl:template match="cib-ext:RegisteredOffenderStatusText">
	<!-- use same display as medicallabel -->
		<xsl:choose>
			<xsl:when test="position() = 1">
				<br/>
				<span class="medicallabel">
					<xsl:text>Status:&#160;&#160;</xsl:text>
					<xsl:apply-templates select="." mode="TitleCase"/>		 
				</span>
			</xsl:when>
			<xsl:otherwise>
				<br/>
				<span class="medicalvalue">
					<xsl:apply-templates select="." mode="TitleCase"/>	 						
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="boat_all">
		<xsl:param name="parent" select="."/>
		<xsl:if test="$parent/cib-ext:Boat">
			<br/>
			<table>
				<tr>
					<td class="width25percent" valing="top">
						<img src="../../images/boat.gif" alt="Boat" width="100"/>
					</td>
					<td class="width75percent">
						<xsl:for-each select="$parent/cib-ext:Boat" >
							<xsl:call-template name="Boat"/>
							<br/>
						</xsl:for-each> 
					</td> 
				</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	<!-- Boat -->
	<xsl:template name="Boat">
		<span class="detailvalue">
			<!--  boat year -->
			<xsl:if test="j:PropertyPhysicalDetails/j:PropertyYearDate">
				<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyYearDate"/>
				<xsl:text>&#160;</xsl:text>
			</xsl:if>
			<!--  boat make -->
			<xsl:if test="cib-ext:BoatMakeText or cib-ext:BoatMakeCommentsText">
				<xsl:if test="cib-ext:BoatMakeText">
					<xsl:value-of select="cib-ext:BoatMakeText"/>
				</xsl:if>
				<!--  boat make comments -->
				<xsl:if test="cib-ext:BoatMakeCommentsText">
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="cib-ext:BoatMakeCommentsText" />
				</xsl:if>
				<xsl:text>,&#160;</xsl:text>
			</xsl:if>
			<!--  model name -->
			<xsl:if test="j:PropertyPhysicalDetails/j:PropertyModelName">
				<xsl:text>Model Name:&#160;</xsl:text>
				<xsl:apply-templates select="j:PropertyPhysicalDetails/j:PropertyModelName" mode="TitleCase" />
				<xsl:text>,&#160;</xsl:text>
			</xsl:if>
			<!--  boat length -->
			<xsl:if test="j:PropertyPhysicalDetails/j:PropertyLengthMeasure">
				<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyLengthMeasure"/>
				<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyLengthMeasure/@j:lengthUnitCode"/>
				<xsl:text>,&#160;</xsl:text>
			</xsl:if>
			<!-- boat color -->
			<xsl:if test="cib-ext:BoatColor">
				<xsl:for-each select="cib-ext:BoatColor">
					<xsl:value-of select="cib-ext:BoatColorText"/>
					<xsl:if test="position() != last()">
						<xsl:text>/</xsl:text> 
					</xsl:if>
				</xsl:for-each>
				<xsl:text>,&#160;</xsl:text>
			</xsl:if>
			<!-- boat name -->
			<xsl:if test="cib-ext:BoatName">
				<xsl:text>"</xsl:text>
				<xsl:apply-templates select="cib-ext:BoatName" mode="TitleCase"/>
				<xsl:text>"&#160;</xsl:text>
			</xsl:if>
			<!--  IDs section for hull number, OAN, coast guard -->
			<xsl:if test="j:BoatHullID/j:ID or j:PropertyOwnerAppliedID/j:ID or j:BoatRegistrationID/j:ID">
				<br/>	
				<xsl:if test="j:BoatHullID">
					<xsl:text>Hull&#160;#&#160;</xsl:text>
					<xsl:value-of select="j:BoatHullID/j:ID"/>
					<xsl:text>,&#160;</xsl:text>
				</xsl:if>
				<xsl:if test="j:PropertyOwnerAppliedID">
					<xsl:text>OAN&#160;#&#160;</xsl:text>
					<xsl:value-of select="j:PropertyOwnerAppliedID/j:ID"/>
					<xsl:text>,&#160;</xsl:text>
				</xsl:if>
				<xsl:if test="j:BoatRegistrationID">
					<xsl:text>Coast Guard&#160;#&#160;</xsl:text>
					<xsl:value-of select="j:BoatRegistrationID/j:ID"/>
				</xsl:if>
			</xsl:if>
			<!-- boat license -->
			<xsl:if test="cib-ext:BoatRegistration or cib-ext:BoatHomePortName">
				<br />
				<xsl:if test="cib-ext:BoatRegistration/j:PropertyVisibleID/j:ID">
					<xsl:value-of select="cib-ext:BoatRegistration/j:PropertyVisibleID/j:ID"/>
					<xsl:text>&#160;</xsl:text>
				</xsl:if>
				<!-- state -->
				<xsl:if test="cib-ext:BoatRegistration/j:RegistrationJurisdictionName">
					<xsl:value-of select="cib-ext:BoatRegistration/j:RegistrationJurisdictionName"/>
					<xsl:text>&#160;</xsl:text>
				</xsl:if>		
				<!-- expiration -->
				<xsl:if test="cib-ext:BoatRegistration/cib-ext:RegistrationExpirationYear">
					<xsl:choose>
						<xsl:when test="cib-ext:BoatRegistration/cib-ext:RegistrationExpirationYear = 'NX'">
							<xsl:text>Non Expiring</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="cib-ext:BoatRegistration/cib-ext:RegistrationExpirationYear"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:text>Expiration</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:text>,&#160;</xsl:text>
				</xsl:if>
				<!-- home port -->
				<xsl:if test="cib-ext:BoatHomePortName">
					<xsl:text>Home Port:&#160;</xsl:text>
					<xsl:apply-templates select="cib-ext:BoatHomePortName" mode="TitleCase"/>
				</xsl:if>
			</xsl:if>
			<xsl:if test="cib-ext:BoatTypeText or j:BoatHullMaterialText or j:BoatHullShapeText or j:BoatPropulsionText">
				<!-- boat type -->
				<xsl:if test="cib-ext:BoatTypeText">
					<br/>
					<xsl:text>Boat Type:&#160;</xsl:text>
					<xsl:value-of select="cib-ext:BoatTypeText"/>
					<xsl:text>,&#160;</xsl:text>
				</xsl:if>
				<!-- hull type -->
				<xsl:if test="j:BoatHullMaterialText">
					<xsl:text>Hull Type:&#160;</xsl:text>
					<xsl:value-of select="j:BoatHullMaterialText"/>
					<xsl:text>,&#160;</xsl:text>
				</xsl:if>
				<!-- hull material -->
				<xsl:if test="j:BoatHullShapeText">
					<xsl:text>Hull Shape:&#160;</xsl:text>
					<xsl:value-of select="j:BoatHullShapeText"/>
					<xsl:text>,&#160;</xsl:text>
				</xsl:if>
				<!-- propulsion -->
				<xsl:if test="j:BoatPropulsionText">
					<xsl:text>Propulsion:&#160;</xsl:text>
					<xsl:value-of select="j:BoatPropulsionText"/>
				</xsl:if>
			</xsl:if>
	 	  </span>
		<br/>
	</xsl:template>
	   	
</xsl:transform>