<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <!--  NCIC - STOLEN OR FELONY VEHICLE --> 
	<xsl:import href="ncic_common.xsl"/>
	
	<!-- ############## -->
	<!-- main template  -->
	<!-- ############## -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
					<xsl:choose>
						<xsl:when test="doj:Result/doj:VehicleResponse/doj:InquiryResult/cib-ext:FelonyVehicleIncident">
							<xsl:text>TIME - NCIC Felony Vehicle</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>TIME - NCIC Stolen Vehicle</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:choose>
			<xsl:when test="doj:VehicleResponse/doj:InquiryResult/cib-ext:FelonyVehicleIncident">
				<xsl:text>TIME - NCIC Felony Vehicle</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>TIME - NCIC Stolen Vehicle</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- ############### -->
	<!-- doj:InquiryResult   -->
	<!-- ############### -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="cib-ext:FelonyVehicleIncident"  />
		<xsl:apply-templates select="cib-ext:StolenVehicleIncident"  />
		<xsl:apply-templates select="." mode="property_details_all"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText"  mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogo"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'	
					or cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogo">
		<xsl:choose>
			<!--  stolen vehicle -->
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:StolenIndicator = 'true'">
				<xsl:choose>
					<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true' 
						and cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'">
						<xsl:text>../../images/stolenVehicleArmedAndHold.gif</xsl:text>
						<xsl:text>-</xsl:text>
						<xsl:text>Stolen Vehicle Armed and Hold</xsl:text>
					</xsl:when>
					<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
						<xsl:text>../../images/stolenVehicleHold.gif</xsl:text>
						<xsl:text>-</xsl:text>
						<xsl:text>Stolen Vehicle Hold</xsl:text>
					</xsl:when>
					<xsl:when test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'">
						<xsl:text>../../images/stolenVehicleArmed.gif</xsl:text>
						<xsl:text>-</xsl:text>
						<xsl:text>Stolen Vehicle Armed</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>../../images/stolenVehicle.gif</xsl:text>
						<xsl:text>-</xsl:text>
						<xsl:text>Stolen Vehicle</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- felony vehicle -->
			<xsl:otherwise>
				<xsl:choose> 
					<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true' 
						and cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'">
						<xsl:text>../../images/felonyVehicleArmedAndHold.gif</xsl:text>
						<xsl:text>-</xsl:text>
						<xsl:text>Felony Vehicle Armed and Hold</xsl:text>
					</xsl:when>
					<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
						<xsl:text>../../images/felonyVehicleHold.gif</xsl:text>
						<xsl:text>-</xsl:text>
						<xsl:text>Felony Vehicle Hold</xsl:text>
					</xsl:when>
					<xsl:when test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'">
						<xsl:text>../../images/felonyVehicleArmed.gif</xsl:text>
						<xsl:text>-</xsl:text>
						<xsl:text>Felony Vehicle Armed</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>../../images/felonyVehicle.gif</xsl:text>
						<xsl:text>-</xsl:text>
						<xsl:text>Felony Vehicle</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:template>
	
	<!-- Details about a stolen plate ...	-->
	<xsl:template match="cib-ext:StolenVehicleIncident|cib-ext:FelonyVehicleIncident">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width90percent">
					<xsl:apply-templates select="cib-ext:VehicleDetails"/>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>
	
	<!-- Details about a stolen or felony vehicle (year, model, plates, etc ...)	-->
	<xsl:template match="cib-ext:VehicleDetails">
		<table>
			<tr>
				<td>
					<span class="propertyinfo">
						<!-- Year -->
						<xsl:value-of select="j:VehicleModelYearDate"/>
						<xsl:text>&#160;</xsl:text>
						<!-- Make and Model -->
						<xsl:value-of select="cib-ext:VehicleMakeText"/>
						<!-- Vehicle Make Comment Text -->
						<xsl:if test="cib-ext:VehicleMakeCommentsText">
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="cib-ext:VehicleMakeCommentsText"/>
						</xsl:if>
						<!-- Vehicle Model -->
						<xsl:if test="j:VehicleModelCodeText">
							<xsl:text>&#32;</xsl:text>
							<xsl:value-of select="j:VehicleModelCodeText"/>
						</xsl:if>
						<xsl:text>&#32;</xsl:text>
						<!-- Vehicle Style -->
						<xsl:value-of select="cib-ext:VehicleStyleText"/>
						<xsl:text>&#32;</xsl:text>
						<!-- Vehicle color -->
						<xsl:apply-templates select="." mode="VehicleColor"/>
						<!-- VIN -->
						<xsl:if test="j:VehicleID/j:ID">
							<br/>
							<xsl:text>VIN&#160;</xsl:text>
							<xsl:value-of select="j:VehicleID/j:ID"/>
						</xsl:if>
						<!-- OAN -->
						<xsl:if test="j:PropertyOwnerAppliedID">
							<br/>
							<xsl:text>OAN&#160;</xsl:text>
							<xsl:value-of select="j:PropertyOwnerAppliedID/j:ID" />
						</xsl:if>
						<!-- License Plate -->
						<xsl:apply-templates select="cib-ext:VehicleRegistration"/>
					</span>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<!-- License plate for stolen or felony vehicle -->
	<xsl:template match="cib-ext:VehicleRegistration">
		<br/>
		<xsl:value-of select="j:VehicleRegistrationPlateID/j:ID"/>
		<xsl:text>&#160;</xsl:text>
		<xsl:value-of select="j:RegistrationJurisdictionName"/>
		<xsl:apply-templates select="cib-ext:RegistrationExpirationYear" mode="FormatYYYYorNX"/>
		<xsl:text>&#160;</xsl:text>
		<xsl:value-of select="j:VehicleRegistrationPlateTypeText"/>
	</xsl:template>

	<!-- Vehicle color for stolen or felony vehicle -->
	<xsl:template match="cib-ext:VehicleDetails" mode="VehicleColor">
		<xsl:value-of select="j:VehicleColorPrimaryText"/>
		<xsl:if test="j:VehicleColorPrimaryText and j:VehicleColorSecondaryText">/</xsl:if>
		<xsl:value-of select="j:VehicleColorSecondaryText"/>
	</xsl:template>
	
</xsl:transform>