<?xml version="1.0"?>

<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/> 
	
	<!--  NCIC - Unidentified Person -->
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# --> 
	<xsl:template match="/doj:NCICResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName"> 
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Unidentified Person</xsl:text>
	</xsl:template>
	
	<!-- ################################# -->
	<!-- main doj:InquiryResult template   -->
	<!-- ################################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="cib-ext:UnidentifiedPersonIncident/j:IncidentVictim/j:Victim.Person" mode="subject_details_all"/>
		<xsl:apply-templates select="cib-ext:UnidentifiedPersonIncident/j:IncidentVictim/j:Victim.Person" mode="FBItoSMT"/>
		<xsl:apply-templates select="cib-ext:UnidentifiedPersonIncident/j:IncidentVictim/j:Victim.Person" mode="DLtoDNALoc"/>	
		<xsl:apply-templates select="cib-ext:UnidentifiedPersonIncident/j:IncidentVictim/j:Victim.Person" mode="PersonOtherInfo"/>
		<xsl:apply-templates select="cib-ext:UnidentifiedPersonIncident/j:IncidentVictim/j:Victim.Person" mode="JewelryInfo"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="cib-ext:UnidentifiedPersonIncident/j:IncidentVictim/j:Victim.Person"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all" >
			<xsl:with-param name="parent" select="cib-ext:UnidentifiedPersonIncident/j:IncidentVictim/j:Victim.Person"/>
		</xsl:call-template>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/> 
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:UnidentifiedPersonIncident" mode="record_details"/>	 		
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>

	<!-- ##################### -->
	<!-- The File Type Header  -->
	<!-- ##################### -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file. -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="fileLogoPicture"> 
		<xsl:choose>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:DeceasedIndicator = 'true'">
				<xsl:text>../../images/unidentifiedDeceasedPerson.gif</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Unidentified Deceased Person</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LivingIndicator = 'true'">
				<xsl:text>../../images/unidentifiedLivingPerson.gif</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Unidentified Living Person</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:DisasterCatastropheVictimIndicator = 'true'">
				<xsl:text>../../images/unidentifiedCatastropheVictim.gif</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Unidentified Catastrophe Victim</xsl:text>
			</xsl:when>
			<xsl:otherwise> 
				<xsl:text>../../images/unidentifiedBody.gif</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Unidentified Body</xsl:text> 
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<xsl:apply-templates select="cib-ext:UnidentifiedPersonIncident/j:IncidentVictim/j:Victim.Person" mode="subject_caution_all"/>
		<!-- Missing Person Details-->	
		<br/>
		<table>
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>	 
		</table>
	</xsl:template>
	
	<xsl:template match="cib-ext:UnidentifiedPersonIncident" mode="record_details">
		<table>
			<!-- Date Body Found --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date Body Found:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates 
						select="j:ActivityDate" 
						mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Estimated Date of Death:'"/>
				<xsl:with-param name="value2">
  				  <xsl:apply-templates 
						select="j:IncidentVictim/j:Victim.Person/cib-ext:PersonDeathDateText" 
						mode="FormatFullDateAsMMDDYYYY">
  				  </xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
		<table>
			<!-- Cause of Death -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Cause of Death:'"/>
				<xsl:with-param name="value1" select="j:IncidentVictim/j:Victim.Person/cib-ext:PersonDeathReasonText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!-- Medical Examiner -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Medical Examiner:'"/>
				<xsl:with-param name="value1" select="j:IncidentResponse/j:IncidentResponseOrganization/j:OrganizationName"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!-- Examiner Location -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Examiner Location:'"/>
				<xsl:with-param name="value1" select="j:IncidentResponse/j:IncidentResponseOrganization/j:OrganizationLocation/j:LocationAddress/j:AddressFullText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!-- Examiner Telephone -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Examiner Telephone:'"/>
				<xsl:with-param name="value1" select="j:IncidentResponse/j:IncidentResponseOrganization/j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
</xsl:transform>