<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/>

	<!--  NCIC - WANTED PERSON RECORD -->
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:NCICResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Wanted Person</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="j:ArrestWarrant/j:CourtOrderDesignatedSubject" mode="subject_details_all"/>
		<xsl:apply-templates select="j:ArrestWarrant/j:CourtOrderDesignatedSubject" mode="FBItoSMT"/>
		<xsl:apply-templates select="j:ArrestWarrant/j:CourtOrderDesignatedSubject" mode="DLtoDNALoc"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="j:ArrestWarrant/j:CourtOrderDesignatedSubject"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all" >
			<xsl:with-param name="parent" select="j:ArrestWarrant/j:CourtOrderDesignatedSubject"/>
		</xsl:call-template>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="j:ArrestWarrant/j:CourtOrderDesignatedSubject" mode="alias"/>
		<xsl:apply-templates select="j:ArrestWarrant/j:CourtOrderDesignatedSubject/cib-ext:PersonStolenFraudulent" />
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>	 
		<xsl:apply-templates select="." mode="record_details"/>	 	
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.  -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param> 
			<xsl:with-param name="flagPic2">
				<xsl:if test="j:ArrestWarrant/cib-ext:WarrantGeographicRestrictionText or
							  j:ArrestWarrant/cib-ext:WarrantExtraditionLimitationText">
					<xsl:text>../../images/location.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Warrant Geographic Restriction</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic3">
				<xsl:if test="cib-ext:DetainerDetails">
					<xsl:text>../../images/cuffs.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Detainer Info</xsl:text>
				</xsl:if>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="fileLogoPicture">
		<xsl:if test="cib-ext:FileTypeDetails/cib-ext:LocatedIndicator = 'true'">
			<xsl:choose>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:EmancipatedIndicator = 'true'  
					and cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true'  
					and cib-ext:FileTypeDetails/cib-ext:AdjudgedIndicator = 'true'">
					<xsl:text>../../images/locatedWantedEmancipatedJuvenileAdjudged.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Located Emancipated Adjudged Juvenile</xsl:text>
				</xsl:when>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true' 
					and cib-ext:FileTypeDetails/cib-ext:AdjudgedIndicator = 'true'">
					<xsl:text>../../images/locatedWantedJuvenileAdjudged.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Located Adjudged Juvenile</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>../../images/locatedWanted.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Located</xsl:text>
				</xsl:otherwise>								
			</xsl:choose>
		</xsl:if>
		<xsl:if test="not(cib-ext:FileTypeDetails/cib-ext:LocatedIndicator)">
			<xsl:choose>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:EmancipatedIndicator = 'true' 
					and cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true' 
					and cib-ext:FileTypeDetails/cib-ext:AdjudgedIndicator = 'true'">
					<xsl:text>../../images/wantedEmancipatedJuvenileAdjudged.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Emancipated Adjudged Juvenile</xsl:text>
				</xsl:when>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true' and 
					cib-ext:FileTypeDetails/cib-ext:AdjudgedIndicator = 'true'">
					<xsl:text>../../images/wantedJuvenileAdjudged.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Adjudged Juvenile</xsl:text>
				</xsl:when>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:TemporaryIndicator = 'true'">
					<xsl:text>../../images/wantedTemporary.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Temporary</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>../../images/wanted.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Wanted</xsl:text>
				</xsl:otherwise>								
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<table>
			<tr>
				<td class="width10percent"> 
					<a href="#warrantdetails{$responseId}"><img src="../../images/WarrantDetails.jpg" alt="Warrant Details"/></a>
				</td>
				<td class="width80percent" align="center" >
					<xsl:apply-templates select="j:ArrestWarrant/j:CourtOrderDesignatedSubject/cib-ext:SubjectCautionInformationText"/>
					<xsl:apply-templates select="j:ArrestWarrant/j:WarrantExtraditionLimitationText"/>
					<xsl:apply-templates select="j:ArrestWarrant/cib-ext:WarrantGeographicRestrictionText"/>
				</td>
				<td class="width10percent"></td> <!-- on purpose left it empty -->
			</tr>
		</table>
		<br/>
		<!-- Wanted Details-->	
		<table>
			<!--  Warrant Type: --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Warrant Type:'"/>
				<xsl:with-param name="value1" select="j:ArrestWarrant/cib-ext:WarrantTypeText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<!--  Offense Code: -->
			<xsl:call-template name="ConditionalRow"> 
				<xsl:with-param name="label1" select="'Offense:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:ArrestWarrant/j:ActivityCrimeCase/j:CaseCharge/j:ChargeReporting/cib-ext:ChargeNCICText"/>
					<xsl:text>&#160;</xsl:text>
					<xsl:apply-templates select="j:ArrestWarrant/j:ActivityCrimeCase/j:CaseCharge/j:ChargeReporting/cib-ext:ChargeNCICCodeCommentText"/>
				</xsl:with-param> 
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/> 
			</xsl:call-template>

			<xsl:if test="starts-with(j:ArrestWarrant/cib-ext:AdditionalOffenseTranslationText,'Y')">
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'&#160;'"/>
					<!-- <xsl:with-param name="value1" select="j:ArrestWarrant/cib-ext:AdditionalOffenseTranslationText"/>   -->
					<xsl:with-param name="value1">
						<xsl:call-template name="left-trim">
				 			<xsl:with-param name="s" select="substring(j:ArrestWarrant/cib-ext:AdditionalOffenseTranslationText,4)"/>			
						</xsl:call-template>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
					<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
				</xsl:call-template>
			</xsl:if>
			
			<!--  Original Offense Code --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Original Offense:'"/>
				<xsl:with-param name="value1" select="j:ArrestWarrant/j:ActivityCrimeCase/j:CaseCharge/j:ChargeReporting/cib-ext:ChargeNCICOriginalText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	</xsl:template> 
	
	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!-- Warrant Number and Warrant Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Warrant Number:'"/>
				<xsl:with-param name="value1" select="j:ArrestWarrant/j:ActivityID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Warrant Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:ArrestWarrant/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Court ORI -->
			<xsl:call-template name="ConditionalRow"> 
				<xsl:with-param name="label1" select="'Court ORI:'"/>
				<xsl:with-param name="value1" select="j:ArrestWarrant/j:CourtOrderIssuingCourt/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
		
</xsl:stylesheet>